package Acme::MITHALDU::BleedingOpenGL;

#  Copyright (c) 1998,1999 Kenneth Albanowski. All rights reserved.
#  Copyright (c) 2007 Bob Free. All rights reserved.
#  Copyright (c) 2009 Christopher Marshall. All rights reserved.
#  Copyright (c) 2015 Bob Free. All rights reserved.
#  Copyright (c) 2016 Chris Marshall. All rights reserved.
#  This program is free software; you can redistribute it and/or
#  modify it under the same terms as Perl itself.

=head1 NAME

Acme::MITHALDU::BleedingOpenG - bleeding edge OpenGL experiments - you WILL get cut

=head1 DESCRIPTION

This is a fork of the official L<OpenGL> in which i implement modern OpenGL
functions not available in L<OpenGL> crudely, cluelessly and without any error
checking. The only reason this is on CPAN is to make development of
L<Microidium|https://github.com/wchristian/Microidium> a little easier.

You'd be insane to use this. I make no guarantees to not break this horribly at
any point.

Seriously, just use L<OpenGL>.

(PS: I'll probably be force-pushing the repo at various points too.)

=cut

require Exporter;
require DynaLoader;

use Carp;

$VERSION = '0.67047';
$BUILD_VERSION = $XS_VERSION = $VERSION;
$VERSION = eval($VERSION);

@ISA = qw(Exporter AutoLoader DynaLoader);

our $gl_version;
our $glext_installed = {};

# Implemented extensions and their dependencies
our $glext_dependencies =
{
   GL_ARB_color_buffer_float=>'2.0', #39
   GL_ARB_depth_texture=>'1.1', #22
   GL_ARB_draw_buffers=>'1.3', #37
   GL_ARB_fragment_program=>'1.4;ARB_vertex_program', #27
   GL_ARB_fragment_program_shadow=>'1.4;ARB_fragment_program,ARB_shadow', #36
   GL_ARB_fragment_shader=>'1.4;ARB_shader_objects', #32
   GL_ARB_half_float_pixel=>'1.5', #40
   GL_ARB_multisample=>'1.0', #5
   GL_ARB_multitexture=>'1.1', # Moved to 1.2.1
   GL_ARB_pixel_buffer_object=>'1.5', #42
   GL_ARB_point_parameters=>'1.0', #14
   GL_ARB_point_sprite=>'1.4', #35
   GL_ARB_shading_language_100=>'1.4;ARB_shader_objects,ARB_fragment_shader,ARB_vertex_shader', #33
   GL_ARB_shader_objects=>'1.4', #30
   GL_ARB_shadow=>'1.1;ARB_depth_texture', #23
   GL_ARB_shadow_ambient=>'1.1;ARB_shadow,ARB_depth_texture', #23
   GL_ARB_texture_border_clamp=>'1.0', #13
   GL_ARB_texture_cube_map=>'1.0', #7
   GL_ARB_texture_env_add=>'1.0', #6
   GL_ARB_texture_env_combine=>'1.1;ARB_multitexture', #17
   GL_ARB_texture_env_dot3=>'1.1;ARB_multitexture,ARB_texture_env_combine', #19
   GL_ARB_texture_float=>'1.1', #41
   GL_ARB_texture_mirrored_repeat=>'1.0', #21
   GL_ARB_texture_non_power_of_two=>'1.4', #34
   GL_ARB_texture_rectangle=>'1.1', #38
   GL_ARB_vertex_buffer_object=>'1.4', #28
   GL_ARB_vertex_program=>'1.3', #26
   GL_ARB_vertex_shader=>'1.4;ARB_shader_objects', #31
   GL_ATI_texture_float=>'1.1', #280
   GL_ATI_texture_mirror_once=>'1.0;EXT_texture3D', #221
   GL_EXT_abgr=>'1.0', #1
   GL_EXT_bgra=>'1.0', #129
   GL_EXT_blend_color=>'1.0', #2
   GL_EXT_blend_subtract=>'1.0', #38
   GL_EXT_Cg_shader=>'1.0;ARB_shader_objects', #???
   GL_EXT_copy_texture=>'1.0', #10
   GL_EXT_framebuffer_object=>'1.1', #310
   GL_EXT_packed_pixels=>'1.0', #23
   GL_EXT_pixel_buffer_object=>'1.0', #???
   GL_EXT_rescale_normal=>'1.0', #27
   GL_EXT_separate_specular_color=>'1.0', #144
   GL_EXT_shadow_funcs=>'1.1;ARB_depth_texture,ARB_shadow', #267
   GL_EXT_stencil_wrap=>'1.0', #176
   GL_EXT_subtexture=>'1.0', #9
   GL_EXT_texture=>'1.0', #4
   GL_EXT_texture3D=>'1.1;EXT_abgr', #6
   GL_EXT_texture_cube_map=>'1.0', #6
   GL_EXT_texture_env_combine=>'1.0', #158
   GL_EXT_texture_env_dot3=>'1.0;EXT_texture_env_combine', #220
   GL_EXT_texture_filter_anisotropic=>'1.0', #187
   GL_EXT_texture_lod_bias=>'1.0', #186
   GL_EXT_texture_mirror_clamp=>'1.0', #298
   GL_EXT_vertex_array=>'1.0', #30
   GL_HP_occlusion_test=>'1.0', #137
   GL_IBM_rasterpos_clip=>'1.0', #110
   GL_NV_blend_square=>'1.0', #194
   GL_NV_copy_depth_to_color=>'1.0;NV_packed_depth_stencil', #243
   GL_NV_depth_clamp=>'1.0', #260
   GL_NV_fog_distance=>'1.0', #192
   GL_NV_fragment_program_option=>'1.0;ARB_fragment_program', #303
   GL_NV_fragment_program2=>'1.0;ARB_fragment_program,NV_fragment_program_option', #304
   GL_NV_light_max_exponent=>'1.0', #189
   GL_NV_multisample_filter_hint=>'1.0;ARB_multisample', #259
   GL_NV_packed_depth_stencil=>'1.0', #226
   GL_NV_texgen_reflection=>'1.0', #179
   GL_NV_texture_compression_vtc=>'1.0;ARB_texture_compression,EXT_texture_compression_s3tc,ARB_texture_non_power_of_two', #228
   GL_NV_texture_expand_normal=>'1.1', #286
   GL_NV_texture_rectangle=>'1.0', #229
   GL_NV_texture_shader=>'1.0;ARB_multitexture,ARB_texture_cube_map', #230
   GL_NV_texture_shader2=>'1.0;NV_texture_shader', #231
   GL_NV_texture_shader3=>'1.0;NV_texture_shader2', #265
   GL_NV_vertex_program1_1=>'1.0;NV_vertex_program', #266
   GL_NV_vertex_program2=>'1.0;NV_vertex_program', #287
   GL_NV_vertex_program2_option=>'1.0;ARB_vertex_program', #305
   GL_NV_vertex_program3=>'1.0;ARB_vertex_program,NV_vertex_program2_option', #306
   GL_S3_s3tc=>'1.1', #276
   GL_SGIS_generate_mipmap=>'1.1', #32
   GL_SGIS_texture_lod=>'1.1', #24
   GL_SGIX_depth_texture=>'1.1', #63
   GL_SGIX_shadow=>'1.0', #34
   GL_SUN_slice_accum=>'1.0' #258
};


@gl_func = qw(
   glAccum
   glAlphaFunc
   glAreTexturesResident_s
   glAreTexturesResident_c
   glAreTexturesResident_p
   glArrayElement
   glBegin
   glEnd
   glBindTexture
   glBitmap_s
   glBitmap_c
   glBitmap_p
   glBlendFunc
   glCallList
   glCallLists_s
   glCallLists_c
   glCallLists_p
   glClear
   glClearAccum
   glClearColor
   glClearDepth
   glClearIndex
   glClearStencil
   glClipPlane_p
   glClipPlane_s
   glClipPlane_c
   glColorMask
   glColorMaterial
   glColorPointer_c
   glColorPointer_s
   glColorPointer_p
   glCopyPixels
   glCopyTexImage1D
   glCopyTexImage2D
   glCopyTexSubImage1D
   glCopyTexSubImage2D
   glCopyTexSubImage3D
   glCullFace
   glDeleteLists
   glDeleteTextures_s
   glDeleteTextures_c
   glDeleteTextures_p
   glDepthFunc
   glDepthMask
   glDepthRange
   glDrawArrays
   glDrawBuffer
   glDrawBuffers_s
   glDrawBuffers_c
   glDrawBuffers_p
   glDrawBuffersARB_s
   glDrawBuffersARB_c
   glDrawBuffersARB_p
   glDrawElements_s
   glDrawElements_c
   glDrawElements_p
   glDrawPixels_s
   glDrawPixels_c
   glDrawPixels_p
   glDrawRangeElements_s
   glDrawRangeElements_c
   glDrawRangeElements_p
   glEdgeFlag
   glEdgeFlagPointer_c
   glEdgeFlagPointer_s
   glEdgeFlagPointer_p
   glEnable
   glDisable
   glEnableClientState
   glDisableClientState
   glEvalCoord1d
   glEvalCoord1f
   glEvalCoord2d
   glEvalCoord2f
   glEvalMesh1
   glEvalMesh2
   glEvalPoint1
   glEvalPoint2
   glFeedbackBuffer_c
   glFinish
   glFlush
   glFogf
   glFogi
   glFogfv_p
   glFogiv_p
   glFogfv_s
   glFogiv_s
   glFogfv_c
   glFogiv_c
   glFrontFace
   glFrustum
   glGenLists
   glGenTextures_s
   glGenTextures_c
   glGenTextures_p
   glGetDoublev_s
   glGetDoublev_c
   glGetBooleanv_s
   glGetBooleanv_c
   glGetIntegerv_s
   glGetIntegerv_c
   glGetFloatv_s
   glGetFloatv_c
   glGetDoublev_p
   glGetBooleanv_p
   glGetIntegerv_p
   glGetFloatv_p
   glGetClipPlane_p
   glGetClipPlane_s
   glGetClipPlane_c
   glGetError
   glGetLightfv_p
   glGetLightiv_p
   glGetLightfv_c
   glGetLightiv_c
   glGetLightfv_s
   glGetLightiv_s
   glGetMapfv_p
   glGetMapdv_p
   glGetMapiv_p
   glGetMapiv_c
   glGetMapfv_c
   glGetMapdv_c
   glGetMapdv_s
   glGetMapfv_s
   glGetMapiv_s
   glGetMaterialfv_p
   glGetMaterialiv_p
   glGetMaterialfv_c
   glGetMaterialiv_c
   glGetMaterialfv_s
   glGetMaterialiv_s
   glGetPixelMapfv_p
   glGetPixelMapuiv_p
   glGetPixelMapusv_p
   glGetPixelMapfv_c
   glGetPixelMapuiv_c
   glGetPixelMapusv_c
   glGetPixelMapfv_s
   glGetPixelMapuiv_s
   glGetPixelMapusv_s
   glGetPolygonStipple_s
   glGetPolygonStipple_c
   glGetPolygonStipple_p
   glGetPointerv_c
   glGetPointerv_s
   glGetPointerv_p
   glGetString
   glGetTexEnvfv_p
   glGetTexEnviv_p
   glGetTexEnvfv_c
   glGetTexEnviv_c
   glGetTexEnvfv_s
   glGetTexEnviv_s
   glGetTexGenfv_p
   glGetTexGendv_p
   glGetTexGeniv_p
   glGetTexGenfv_c
   glGetTexGendv_c
   glGetTexGeniv_c
   glGetTexGendv_s
   glGetTexGenfv_s
   glGetTexGeniv_s
   glGetTexImage_s
   glGetTexImage_c
   glGetTexImage_p
   glGetTexLevelParameterfv_p
   glGetTexLevelParameteriv_p
   glGetTexLevelParameterfv_s
   glGetTexLevelParameteriv_s
   glGetTexLevelParameterfv_c
   glGetTexLevelParameteriv_c
   glGetTexParameterfv_p
   glGetTexParameteriv_p
   glGetTexParameterfv_s
   glGetTexParameteriv_s
   glGetTexParameterfv_c
   glGetTexParameteriv_c
   glHint
   glIndexd
   glIndexi
   glIndexMask
   glIndexPointer_c
   glIndexPointer_s
   glIndexPointer_p
   glInitNames
   glInterleavedArrays_c
   glIsEnabled
   glIsList
   glIsTexture
   glLightf
   glLighti
   glLightfv_p
   glLightiv_p
   glLightfv_c
   glLightiv_c
   glLightfv_s
   glLightiv_s
   glLightModelf
   glLightModeli
   glLightModelfv_p
   glLightModeliv_p
   glLightModeliv_c
   glLightModelfv_c
   glLightModeliv_s
   glLightModelfv_s
   glLineStipple
   glLineWidth
   glListBase
   glLoadIdentity
   glLoadMatrixd_p
   glLoadMatrixf_p
   glLoadMatrixf_c
   glLoadMatrixd_c
   glLoadMatrixf_s
   glLoadMatrixd_s
   glLoadName
   glLogicOp
   glMap1d_p
   glMap1f_p
   glMap1d_c
   glMap1f_c
   glMap1d_s
   glMap1f_s
   glMap2d_p
   glMap2f_p
   glMap2d_c
   glMap2f_c
   glMap2d_s
   glMap2f_s
   glMapGrid1d
   glMapGrid1f
   glMapGrid2d
   glMapGrid2f
   glMaterialf
   glMateriali
   glMaterialfv_p
   glMaterialiv_p
   glMaterialfv_s
   glMaterialiv_s
   glMaterialfv_c
   glMaterialiv_c
   glMatrixMode
   glMultMatrixd_p
   glMultMatrixf_p
   glNewList
   glEndList
   glNormalPointer_c
   glNormalPointer_s
   glNormalPointer_p
   glOrtho
   glPassThrough
   glPixelMapfv_p
   glPixelMapuiv_p
   glPixelMapusv_p
   glPixelMapfv_c
   glPixelMapuiv_c
   glPixelMapusv_c
   glPixelMapfv_s
   glPixelMapuiv_s
   glPixelMapusv_s
   glPixelStoref
   glPixelStorei
   glPixelTransferf
   glPixelTransferi
   glPixelZoom
   glPointSize
   glPolygonMode
   glPolygonOffset
   glPolygonStipple_s
   glPolygonStipple_c
   glPolygonStipple_p
   glPrioritizeTextures_s
   glPrioritizeTextures_c
   glPrioritizeTextures_p
   glPushAttrib
   glPopAttrib
   glPushClientAttrib
   glPopClientAttrib
   glPushMatrix
   glPopMatrix
   glPushName
   glPopName
   glReadBuffer
   glReadPixels_s
   glReadPixels_c
   glReadPixels_p
   glRecti
   glRects
   glRectd
   glRectf
   glRectsv_c
   glRectiv_c
   glRectfv_c
   glRectdv_c
   glRectdv_s
   glRectfv_s
   glRectiv_s
   glRectsv_s
   glRenderMode
   glRotated
   glRotatef
   glScaled
   glScalef
   glScissor
   glSelectBuffer_c
   glShadeModel
   glStencilFunc
   glStencilMask
   glStencilOp
   glTexCoordPointer_c
   glTexCoordPointer_s
   glTexCoordPointer_p
   glTexEnvf
   glTexEnvi
   glTexEnvfv_p
   glTexEnviv_p
   glTexEnvfv_s
   glTexEnviv_s
   glTexGend
   glTexGenf
   glTexGeni
   glTexGendv_p
   glTexGenfv_p
   glTexGeniv_p
   glTexGendv_s
   glTexGenfv_s
   glTexGeniv_s
   glTexGendv_c
   glTexGenfv_c
   glTexGeniv_c
   glTexImage1D_s
   glTexImage1D_c
   glTexImage1D_p
   glTexImage2D_s
   glTexImage2D_c
   glTexImage2D_p
   glTexImage3D_s
   glTexImage3D_c
   glTexImage3D_p
   glTexImage3DEXT_c
   glTexImage3DEXT_s
   glTexImage3DEXT_p
   glTexParameterf
   glTexParameteri
   glTexParameterfv_p
   glTexParameteriv_p
   glTexParameterfv_s
   glTexParameteriv_s
   glTexParameterfv_c
   glTexParameteriv_c
   glTexSubImage1D_c
   glTexSubImage1D_s
   glTexSubImage1D_p
   glTexSubImage2D_s
   glTexSubImage2D_c
   glTexSubImage2D_p
   glTexSubImage3D_s
   glTexSubImage3D_c
   glTexSubImage3D_p
   glTexSubImage1DEXT_c
   glTexSubImage1DEXT_s
   glTexSubImage1DEXT_p
   glTexSubImage2DEXT_c
   glTexSubImage2DEXT_s
   glTexSubImage2DEXT_p
   glTranslated
   glTranslatef
   glVertexPointer_c
   glVertexPointer_s
   glVertexPointer_p
   glViewport
   glVertex2d
   glVertex2dv_p
   glVertex2dv_s
   glVertex2dv_c
   glVertex2f
   glVertex2fv_p
   glVertex2fv_s
   glVertex2fv_c
   glVertex2i
   glVertex2iv_p
   glVertex2iv_s
   glVertex2iv_c
   glVertex2s
   glVertex2sv_p
   glVertex2sv_s
   glVertex2sv_c
   glVertex3d
   glVertex3dv_p
   glVertex3dv_s
   glVertex3dv_c
   glVertex3f
   glVertex3fv_p
   glVertex3fv_s
   glVertex3fv_c
   glVertex3i
   glVertex3iv_p
   glVertex3iv_s
   glVertex3iv_c
   glVertex3s
   glVertex3sv_p
   glVertex3sv_s
   glVertex3sv_c
   glVertex4d
   glVertex4dv_p
   glVertex4dv_s
   glVertex4dv_c
   glVertex4f
   glVertex4fv_p
   glVertex4fv_s
   glVertex4fv_c
   glVertex4i
   glVertex4iv_p
   glVertex4iv_s
   glVertex4iv_c
   glVertex4s
   glVertex4sv_p
   glVertex4sv_s
   glVertex4sv_c
   glNormal3b
   glNormal3bv_p
   glNormal3bv_s
   glNormal3bv_c
   glNormal3d
   glNormal3dv_p
   glNormal3dv_s
   glNormal3dv_c
   glNormal3f
   glNormal3fv_p
   glNormal3fv_s
   glNormal3fv_c
   glNormal3i
   glNormal3iv_p
   glNormal3iv_s
   glNormal3iv_c
   glNormal3s
   glNormal3sv_p
   glNormal3sv_s
   glNormal3sv_c
   glColor3b
   glColor3bv_p
   glColor3bv_s
   glColor3bv_c
   glColor3d
   glColor3dv_p
   glColor3dv_s
   glColor3dv_c
   glColor3f
   glColor3fv_p
   glColor3fv_s
   glColor3fv_c
   glColor3i
   glColor3iv_p
   glColor3iv_s
   glColor3iv_c
   glColor3s
   glColor3sv_p
   glColor3sv_s
   glColor3sv_c
   glColor3ub
   glColor3ubv_p
   glColor3ubv_s
   glColor3ubv_c
   glColor3ui
   glColor3uiv_p
   glColor3uiv_s
   glColor3uiv_c
   glColor3us
   glColor3usv_p
   glColor3usv_s
   glColor3usv_c
   glColor4b
   glColor4bv_p
   glColor4bv_s
   glColor4bv_c
   glColor4d
   glColor4dv_p
   glColor4dv_s
   glColor4dv_c
   glColor4f
   glColor4fv_p
   glColor4fv_s
   glColor4fv_c
   glColor4i
   glColor4iv_p
   glColor4iv_s
   glColor4iv_c
   glColor4s
   glColor4sv_p
   glColor4sv_s
   glColor4sv_c
   glColor4ub
   glColor4ubv_p
   glColor4ubv_s
   glColor4ubv_c
   glColor4ui
   glColor4uiv_p
   glColor4uiv_s
   glColor4uiv_c
   glColor4us
   glColor4usv_p
   glColor4usv_s
   glColor4usv_c
   glTexCoord1d
   glTexCoord1dv_p
   glTexCoord1dv_s
   glTexCoord1dv_c
   glTexCoord1f
   glTexCoord1fv_p
   glTexCoord1fv_s
   glTexCoord1fv_c
   glTexCoord1i
   glTexCoord1iv_p
   glTexCoord1iv_s
   glTexCoord1iv_c
   glTexCoord1s
   glTexCoord1sv_p
   glTexCoord1sv_s
   glTexCoord1sv_c
   glTexCoord2d
   glTexCoord2dv_p
   glTexCoord2dv_s
   glTexCoord2dv_c
   glTexCoord2f
   glTexCoord2fv_p
   glTexCoord2fv_s
   glTexCoord2fv_c
   glTexCoord2i
   glTexCoord2iv_p
   glTexCoord2iv_s
   glTexCoord2iv_c
   glTexCoord2s
   glTexCoord2sv_p
   glTexCoord2sv_s
   glTexCoord2sv_c
   glTexCoord3d
   glTexCoord3dv_p
   glTexCoord3dv_s
   glTexCoord3dv_c
   glTexCoord3f
   glTexCoord3fv_p
   glTexCoord3fv_s
   glTexCoord3fv_c
   glTexCoord3i
   glTexCoord3iv_p
   glTexCoord3iv_s
   glTexCoord3iv_c
   glTexCoord3s
   glTexCoord3sv_p
   glTexCoord3sv_s
   glTexCoord3sv_c
   glTexCoord4d
   glTexCoord4dv_p
   glTexCoord4dv_s
   glTexCoord4dv_c
   glTexCoord4f
   glTexCoord4fv_p
   glTexCoord4fv_s
   glTexCoord4fv_c
   glTexCoord4i
   glTexCoord4iv_p
   glTexCoord4iv_s
   glTexCoord4iv_c
   glTexCoord4s
   glTexCoord4sv_p
   glTexCoord4sv_s
   glTexCoord4sv_c
   glRasterPos2d
   glRasterPos2dv_p
   glRasterPos2dv_s
   glRasterPos2dv_c
   glRasterPos2f
   glRasterPos2fv_p
   glRasterPos2fv_s
   glRasterPos2fv_c
   glRasterPos2i
   glRasterPos2iv_p
   glRasterPos2iv_s
   glRasterPos2iv_c
   glRasterPos2s
   glRasterPos2sv_p
   glRasterPos2sv_s
   glRasterPos2sv_c
   glRasterPos3d
   glRasterPos3dv_p
   glRasterPos3dv_s
   glRasterPos3dv_c
   glRasterPos3f
   glRasterPos3fv_p
   glRasterPos3fv_s
   glRasterPos3fv_c
   glRasterPos3i
   glRasterPos3iv_p
   glRasterPos3iv_s
   glRasterPos3iv_c
   glRasterPos3s
   glRasterPos3sv_p
   glRasterPos3sv_s
   glRasterPos3sv_c
   glRasterPos4d
   glRasterPos4dv_p
   glRasterPos4dv_s
   glRasterPos4dv_c
   glRasterPos4f
   glRasterPos4fv_p
   glRasterPos4fv_s
   glRasterPos4fv_c
   glRasterPos4i
   glRasterPos4iv_p
   glRasterPos4iv_s
   glRasterPos4iv_c
   glRasterPos4s
   glRasterPos4sv_p
   glRasterPos4sv_s
   glRasterPos4sv_c

   glActiveTexture
   glClientActiveTexture
   glMultiTexCoord1d
   glMultiTexCoord1dv_c
   glMultiTexCoord1dv_s
   glMultiTexCoord1dv_p
   glMultiTexCoord1f
   glMultiTexCoord1fv_c
   glMultiTexCoord1fv_s
   glMultiTexCoord1fv_p
   glMultiTexCoord1i
   glMultiTexCoord1iv_c
   glMultiTexCoord1iv_s
   glMultiTexCoord1iv_p
   glMultiTexCoord1s
   glMultiTexCoord1sv_c
   glMultiTexCoord1sv_s
   glMultiTexCoord1sv_p
   glMultiTexCoord2d
   glMultiTexCoord2dv_c
   glMultiTexCoord2dv_s
   glMultiTexCoord2dv_p
   glMultiTexCoord2f
   glMultiTexCoord2fv_c
   glMultiTexCoord2fv_s
   glMultiTexCoord2fv_p
   glMultiTexCoord2i
   glMultiTexCoord2iv_c
   glMultiTexCoord2iv_s
   glMultiTexCoord2iv_p
   glMultiTexCoord2s
   glMultiTexCoord2sv_c
   glMultiTexCoord2sv_s
   glMultiTexCoord2sv_p
   glMultiTexCoord3d
   glMultiTexCoord3dv_c
   glMultiTexCoord3dv_s
   glMultiTexCoord3dv_p
   glMultiTexCoord3f
   glMultiTexCoord3fv_c
   glMultiTexCoord3fv_s
   glMultiTexCoord3fv_p
   glMultiTexCoord3i
   glMultiTexCoord3iv_c
   glMultiTexCoord3iv_s
   glMultiTexCoord3iv_p
   glMultiTexCoord3s
   glMultiTexCoord3sv_c
   glMultiTexCoord3sv_s
   glMultiTexCoord3sv_p
   glMultiTexCoord4d
   glMultiTexCoord4dv_c
   glMultiTexCoord4dv_s
   glMultiTexCoord4dv_p
   glMultiTexCoord4f
   glMultiTexCoord4fv_c
   glMultiTexCoord4fv_s
   glMultiTexCoord4fv_p
   glMultiTexCoord4i
   glMultiTexCoord4iv_c
   glMultiTexCoord4iv_s
   glMultiTexCoord4iv_p
   glMultiTexCoord4s
   glMultiTexCoord4sv_c
   glMultiTexCoord4sv_s
   glMultiTexCoord4sv_p
   
   glPolygonOffsetEXT
   glIsTextureEXT
   glPrioritizeTexturesEXT_p
   glBindTextureEXT
   glDeleteTexturesEXT_p
   glGenTexturesEXT_p
   glAreTexturesResidentEXT_p
   glCopyTexImage1DEXT
   glCopyTexImage2DEXT
   glCopyTexSubImage1DEXT
   glCopyTexSubImage2DEXT
   glCopyTexSubImage3DEXT
   glBlendEquationEXT
   glBlendColorEXT
   glArrayElementEXT
   glDrawArraysEXT
   glVertexPointerEXT_c
   glVertexPointerEXT_s
   glVertexPointerEXT_p
   glNormalPointerEXT_c
   glNormalPointerEXT_s
   glNormalPointerEXT_p
   glColorPointerEXT_c
   glColorPointerEXT_s
   glColorPointerEXT_p
   glIndexPointerEXT_c
   glIndexPointerEXT_s
   glIndexPointerEXT_p
   glTexCoordPointerEXT_c
   glTexCoordPointerEXT_s
   glTexCoordPointerEXT_p
   glEdgeFlagPointerEXT_c
   glEdgeFlagPointerEXT_s
   glEdgeFlagPointerEXT_p
   glWindowPos2iMESA
   glWindowPos2dMESA
   glWindowPos3iMESA
   glWindowPos3dMESA
   glWindowPos4iMESA
   glWindowPos4dMESA
   glResizeBuffersMESA
   glIsRenderbufferEXT
   glBindRenderbufferEXT
   glDeleteRenderbuffersEXT_c
   glDeleteRenderbuffersEXT_s
   glDeleteRenderbuffersEXT_p
   glGenRenderbuffersEXT_c
   glGenRenderbuffersEXT_s
   glGenRenderbuffersEXT_p
   glRenderbufferStorageEXT
   glGetRenderbufferParameterivEXT_c
   glGetRenderbufferParameterivEXT_s
   glIsFramebufferEXT
   glBindFramebufferEXT
   glDeleteFramebuffersEXT_c
   glDeleteFramebuffersEXT_s
   glDeleteFramebuffersEXT_p
   glGenFramebuffersEXT_c
   glGenFramebuffersEXT_s
   glGenFramebuffersEXT_p
   glCheckFramebufferStatusEXT
   glFramebufferTexture1DEXT
   glFramebufferTexture2DEXT
   glFramebufferTexture3DEXT
   glFramebufferRenderbufferEXT
   glGetFramebufferAttachmentParameterivEXT_c
   glGetFramebufferAttachmentParameterivEXT_s
   glGenerateMipmapEXT
   glVertexAttrib1dARB
   glVertexAttrib1dvARB_c
   glVertexAttrib1dvARB_s
   glVertexAttrib1dvARB_p
   glVertexAttrib1fARB
   glVertexAttrib1fvARB_c
   glVertexAttrib1fvARB_s
   glVertexAttrib1fvARB_p
   glVertexAttrib1sARB
   glVertexAttrib1svARB_c
   glVertexAttrib1svARB_s
   glVertexAttrib1svARB_p
   glVertexAttrib2dARB
   glVertexAttrib2dvARB_c
   glVertexAttrib2dvARB_s
   glVertexAttrib2dvARB_p
   glVertexAttrib2fARB
   glVertexAttrib2fvARB_c
   glVertexAttrib2fvARB_s
   glVertexAttrib2fvARB_p
   glVertexAttrib2sARB
   glVertexAttrib2svARB_c
   glVertexAttrib2svARB_s
   glVertexAttrib2svARB_p
   glVertexAttrib3dARB
   glVertexAttrib3dvARB_c
   glVertexAttrib3dvARB_s
   glVertexAttrib3dvARB_p
   glVertexAttrib3fARB
   glVertexAttrib3fvARB_c
   glVertexAttrib3fvARB_s
   glVertexAttrib3fvARB_p
   glVertexAttrib3sARB
   glVertexAttrib3svARB_c
   glVertexAttrib3svARB_s
   glVertexAttrib3svARB_p
   glVertexAttrib4NbvARB_c
   glVertexAttrib4NbvARB_s
   glVertexAttrib4NbvARB_p
   glVertexAttrib4NivARB_c
   glVertexAttrib4NivARB_s
   glVertexAttrib4NivARB_p
   glVertexAttrib4NsvARB_c
   glVertexAttrib4NsvARB_s
   glVertexAttrib4NsvARB_p
   glVertexAttrib4NubARB
   glVertexAttrib4NubvARB_c
   glVertexAttrib4NubvARB_s
   glVertexAttrib4NubvARB_p
   glVertexAttrib4NuivARB_c
   glVertexAttrib4NuivARB_s
   glVertexAttrib4NuivARB_p
   glVertexAttrib4NusvARB_c
   glVertexAttrib4NusvARB_s
   glVertexAttrib4NusvARB_p
   glVertexAttrib4bvARB_c
   glVertexAttrib4bvARB_s
   glVertexAttrib4bvARB_p
   glVertexAttrib4dARB
   glVertexAttrib4dvARB_c
   glVertexAttrib4dvARB_s
   glVertexAttrib4dvARB_p
   glVertexAttrib4fARB
   glVertexAttrib4fvARB_c
   glVertexAttrib4fvARB_s
   glVertexAttrib4fvARB_p
   glVertexAttrib4ivARB_s
   glVertexAttrib4ivARB_c
   glVertexAttrib4ivARB_p
   glVertexAttrib4sARB
   glVertexAttrib4svARB_c
   glVertexAttrib4svARB_s
   glVertexAttrib4svARB_p
   glVertexAttrib4ubvARB_c
   glVertexAttrib4ubvARB_s
   glVertexAttrib4ubvARB_p
   glVertexAttrib4uivARB_c
   glVertexAttrib4uivARB_s
   glVertexAttrib4uivARB_p
   glVertexAttrib4usvARB_c
   glVertexAttrib4usvARB_s
   glVertexAttrib4usvARB_p
   glVertexAttribPointerARB_c
   glVertexAttribPointerARB_p
   glEnableVertexAttribArrayARB
   glDisableVertexAttribArrayARB
   glProgramStringARB_c
   glProgramStringARB_s
   glProgramStringARB_p
   glBindProgramARB
   glDeleteProgramsARB_c
   glDeleteProgramsARB_s
   glDeleteProgramsARB_p
   glGenProgramsARB_c
   glGenProgramsARB_s
   glGenProgramsARB_p
   glProgramEnvParameter4dARB
   glProgramEnvParameter4dvARB_c
   glProgramEnvParameter4dvARB_s
   glProgramEnvParameter4dvARB_p
   glProgramEnvParameter4fARB
   glProgramEnvParameter4fvARB_c
   glProgramEnvParameter4fvARB_s
   glProgramEnvParameter4fvARB_p
   glProgramLocalParameter4dARB
   glProgramLocalParameter4dvARB_c
   glProgramLocalParameter4dvARB_s
   glProgramLocalParameter4dvARB_p
   glProgramLocalParameter4fARB
   glProgramLocalParameter4fvARB_c
   glProgramLocalParameter4fvARB_s
   glProgramLocalParameter4fvARB_p
   glGetProgramEnvParameterdvARB_c
   glGetProgramEnvParameterdvARB_s
   glGetProgramEnvParameterdvARB_p
   glGetProgramEnvParameterfvARB_c
   glGetProgramEnvParameterfvARB_s
   glGetProgramEnvParameterfvARB_p
   glGetProgramLocalParameterdvARB_c
   glGetProgramLocalParameterdvARB_s
   glGetProgramLocalParameterdvARB_p
   glGetProgramLocalParameterfvARB_c
   glGetProgramLocalParameterfvARB_s
   glGetProgramLocalParameterfvARB_p
   glGetProgramivARB_c
   glGetProgramivARB_s
   glGetProgramivARB_p
   glGetProgramStringARB_c
   glGetProgramStringARB_s
   glGetProgramStringARB_p
   glGetVertexAttribdvARB_c
   glGetVertexAttribdvARB_s
   glGetVertexAttribdvARB_p
   glGetVertexAttribfvARB_c
   glGetVertexAttribfvARB_s
   glGetVertexAttribfvARB_p
   glGetVertexAttribivARB_c
   glGetVertexAttribivARB_s
   glGetVertexAttribivARB_p
   glGetVertexAttribPointervARB_c
   glGetVertexAttribPointervARB_p
   glIsProgramARB
   glBindBufferARB
   glDeleteBuffersARB_c
   glDeleteBuffersARB_s
   glDeleteBuffersARB_p
   glGenBuffersARB_c
   glGenBuffersARB_s
   glGenBuffersARB_p
   glIsBufferARB
   glBufferDataARB_c
   glBufferDataARB_s
   glBufferDataARB_p
   glBufferSubDataARB_c
   glBufferSubDataARB_s
   glBufferSubDataARB_p
   glGetBufferSubDataARB_c
   glGetBufferSubDataARB_s
   glGetBufferSubDataARB_p
   glMapBufferARB_c
   glMapBufferARB_p
   glUnmapBufferARB
   glGetBufferParameterivARB_c
   glGetBufferParameterivARB_s
   glGetBufferParameterivARB_p
   glGetBufferPointervARB_c
   glGetBufferPointervARB_s
   glGetBufferPointervARB_p
   glActiveTextureARB
   glClientActiveTextureARB
   glMultiTexCoord1dARB
   glMultiTexCoord1dvARB_c
   glMultiTexCoord1dvARB_s
   glMultiTexCoord1dvARB_p
   glMultiTexCoord1fARB
   glMultiTexCoord1fvARB_c
   glMultiTexCoord1fvARB_s
   glMultiTexCoord1fvARB_p
   glMultiTexCoord1iARB
   glMultiTexCoord1ivARB_c
   glMultiTexCoord1ivARB_s
   glMultiTexCoord1ivARB_p
   glMultiTexCoord1sARB
   glMultiTexCoord1svARB_c
   glMultiTexCoord1svARB_s
   glMultiTexCoord1svARB_p
   glMultiTexCoord2dARB
   glMultiTexCoord2dvARB_c
   glMultiTexCoord2dvARB_s
   glMultiTexCoord2dvARB_p
   glMultiTexCoord2fARB
   glMultiTexCoord2fvARB_c
   glMultiTexCoord2fvARB_s
   glMultiTexCoord2fvARB_p
   glMultiTexCoord2iARB
   glMultiTexCoord2ivARB_c
   glMultiTexCoord2ivARB_s
   glMultiTexCoord2ivARB_p
   glMultiTexCoord2sARB
   glMultiTexCoord2svARB_c
   glMultiTexCoord2svARB_s
   glMultiTexCoord2svARB_p
   glMultiTexCoord3dARB
   glMultiTexCoord3dvARB_c
   glMultiTexCoord3dvARB_s
   glMultiTexCoord3dvARB_p
   glMultiTexCoord3fARB
   glMultiTexCoord3fvARB_c
   glMultiTexCoord3fvARB_s
   glMultiTexCoord3fvARB_p
   glMultiTexCoord3iARB
   glMultiTexCoord3ivARB_c
   glMultiTexCoord3ivARB_s
   glMultiTexCoord3ivARB_p
   glMultiTexCoord3sARB
   glMultiTexCoord3svARB_c
   glMultiTexCoord3svARB_s
   glMultiTexCoord3svARB_p
   glMultiTexCoord4dARB
   glMultiTexCoord4dvARB_c
   glMultiTexCoord4dvARB_s
   glMultiTexCoord4dvARB_p
   glMultiTexCoord4fARB
   glMultiTexCoord4fvARB_c
   glMultiTexCoord4fvARB_s
   glMultiTexCoord4fvARB_p
   glMultiTexCoord4iARB
   glMultiTexCoord4ivARB_c
   glMultiTexCoord4ivARB_s
   glMultiTexCoord4ivARB_p
   glMultiTexCoord4sARB
   glMultiTexCoord4svARB_c
   glMultiTexCoord4svARB_s
   glMultiTexCoord4svARB_p
   glDeleteObjectARB
   glGetGLhandleARB
   glDetachObjectARB
   glCreateShaderObjectARB
   glShaderSourceARB_c
   glShaderSourceARB_p
   glCompileShaderARB
   glCreateProgramObjectARB
   glAttachObjectARB
   glLinkProgramARB
   glUseProgramObjectARB
   glValidateProgramARB
   glUniform1fARB
   glUniform2fARB
   glUniform3fARB
   glUniform4fARB
   glUniform1iARB
   glUniform2iARB
   glUniform3iARB
   glUniform4iARB
   glUniform1fvARB_c
   glUniform1fvARB_s
   glUniform1fvARB_p
   glUniform2fvARB_c
   glUniform2fvARB_s
   glUniform2fvARB_p
   glUniform3fvARB_c
   glUniform3fvARB_s
   glUniform3fvARB_p
   glUniform4fvARB_c
   glUniform4fvARB_s
   glUniform4fvARB_p
   glUniform1ivARB_c
   glUniform1ivARB_s
   glUniform1ivARB_p
   glUniform2ivARB_c
   glUniform2ivARB_s
   glUniform2ivARB_p
   glUniform3ivARB_c
   glUniform3ivARB_s
   glUniform3ivARB_p
   glUniform4ivARB_c
   glUniform4ivARB_s
   glUniform4ivARB_p
   glUniformMatrix2fvARB_c
   glUniformMatrix2fvARB_s
   glUniformMatrix2fvARB_p
   glUniformMatrix3fvARB_c
   glUniformMatrix3fvARB_s
   glUniformMatrix3fvARB_p
   glUniformMatrix4fvARB_c
   glUniformMatrix4fvARB_s
   glUniformMatrix4fvARB_p
   glGetObjectParameterfvARB_c
   glGetObjectParameterfvARB_s
   glGetObjectParameterfvARB_p
   glGetObjectParameterivARB_c
   glGetObjectParameterivARB_s
   glGetObjectParameterivARB_p
   glGetInfoLogARB_c
   glGetInfoLogARB_p
   glGetAttachedObjectsARB_c
   glGetAttachedObjectsARB_s
   glGetAttachedObjectsARB_p
   glGetUniformLocationARB_c
   glGetUniformLocationARB_p
   glGetActiveUniformARB_c
   glGetActiveUniformARB_s
   glGetActiveUniformARB_p
   glGetUniformfvARB_c
   glGetUniformfvARB_p
   glGetUniformivARB_c
   glGetUniformivARB_p
   glGetShaderSourceARB_c
   glGetShaderSourceARB_p
   glBindAttribLocationARB
   glGetActiveAttribARB_c
   glGetActiveAttribARB_s
   glGetActiveAttribARB_p
   glGetAttribLocationARB_c
   glGetAttribLocationARB_p
   glPointParameterfARB
   glPointParameterfvARB_c
   glPointParameterfvARB_s
   glPointParameterfvARB_p
   glSampleCoverageARB
   glClampColorARB
   
   glpHasGLUT
   glpCheckExtension
   glpFullScreen
   glpRestoreScreen
);
# gl_func

# gltut
push @gl_func, qw(
   glGenVertexArrays_p
   glBindVertexArray
   glAttachShader
   glDeleteShader
   glGetShaderiv_p
   glGetShaderInfoLog_p
   glGetProgramiv_p
   glDrawElementsBaseVertex_c

   glGenQueries_p
   glDeleteQueries
   glBeginQuery
   glEndQuery
   glGetQueryObjectiv
   glGetQueryObjectuiv
   glGetQueryiv

);

@glu_func = qw(
   gluBeginCurve
   gluBeginPolygon
   gluBeginSurface
   gluBeginTrim
   gluBuild1DMipmaps_c
   gluBuild1DMipmaps_s
   gluBuild2DMipmaps_c
   gluBuild2DMipmaps_s
   gluCylinder
   gluDeleteNurbsRenderer
   gluDeleteQuadric
   gluDeleteTess
   gluDisk
   gluEndCurve
   gluEndPolygon
   gluEndSurface
   gluEndTrim
   gluErrorString
   gluGetNurbsProperty_p
   gluGetString
   gluGetTessProperty_p
   gluLoadSamplingMatrices_p
   gluLookAt
   gluNewNurbsRenderer
   gluNewQuadric
   gluNewTess
   gluNextContour
   gluNurbsCurve_c
   gluNurbsSurface_c
   gluOrtho2D
   gluPartialDisk
   gluPerspective
   gluPickMatrix_p
   gluProject_p
   gluPwlCurve_c
   gluQuadricDrawStyle
   gluQuadricNormals
   gluQuadricOrientation
   gluQuadricTexture
   gluScaleImage_s
   gluSphere
   gluTessBeginContour
   gluTessBeginPolygon
   gluTessCallback
   gluTessEndContour
   gluTessEndPolygon
   gluTessNormal
   gluTessProperty
   gluTessVertex_p
   gluUnProject_p
);

@glut_func = qw(
   done_glutInit
   glutAddMenuEntry
   glutAddSubMenu
   glutAttachMenu
   glutBitmapCharacter
   glutBitmapHeight
   glutBitmapLength
   glutBitmapString
   glutBitmapWidth
   glutButtonBoxFunc
   glutChangeToMenuEntry
   glutChangeToSubMenu
   glutCloseFunc
   glutCopyColormap
   glutCreateMenu
   glutCreateSubWindow
   glutCreateWindow
   glutDestroyMenu
   glutDestroyWindow
   glutDetachMenu
   glutDeviceGet
   glutDialsFunc
   glutDisplayFunc
   glutEnterGameMode
   glutEntryFunc
   glutEstablishOverlay
   glutExtensionSupported
   glutForceJoystickFunc
   glutFullScreen
   glutGameModeGet
   glutGameModeString
   glutGet
   glutGetColor
   glutGetMenu
   glutGetModifiers
   glutGetWindow
   glutHideOverlay
   glutHideWindow
   glutIconifyWindow
   glutIdleFunc
   glutIgnoreKeyRepeat
   glutInit
   glutInitDisplayMode
   glutInitDisplayString
   glutInitWindowPosition
   glutInitWindowSize
   glutKeyboardFunc
   glutKeyboardUpFunc
   glutLayerGet
   glutLeaveGameMode
   glutLeaveMainLoop
   glutMainLoop
   glutMainLoopEvent
   glutMenuDestroyFunc
   glutMenuStateFunc
   glutMenuStatusFunc
   glutMotionFunc
   glutMouseFunc
   glutMouseWheelFunc
   glutOverlayDisplayFunc
   glutPassiveMotionFunc
   glutPopWindow
   glutPositionWindow
   glutPostOverlayRedisplay
   glutPostRedisplay
   glutPostWindowOverlayRedisplay
   glutPostWindowRedisplay
   glutPushWindow
   glutRemoveMenuItem
   glutRemoveOverlay
   glutReportErrors
   glutReshapeFunc
   glutReshapeWindow
   glutSetColor
   glutSetCursor
   glutSetIconTitle
   glutSetKeyRepeat
   glutSetMenu
   glutSetOption
   glutSetWindow
   glutSetWindowTitle
   glutShowOverlay
   glutShowWindow
   glutSolidCone
   glutSolidCube
   glutSolidCylinder
   glutSolidDodecahedron
   glutSolidIcosahedron
   glutSolidOctahedron
   glutSolidRhombicDodecahedron
   glutSolidSphere
   glutSolidTeapot
   glutSolidTetrahedron
   glutSolidTorus
   glutSpaceballButtonFunc
   glutSpaceballMotionFunc
   glutSpaceballRotateFunc
   glutSpecialFunc
   glutSpecialUpFunc
   glutStrokeCharacter
   glutStrokeHeight
   glutStrokeLength
   glutStrokeString
   glutStrokeWidth
   glutSwapBuffers
   glutTabletButtonFunc
   glutTabletMotionFunc
   glutTimerFunc
   glutUseLayer
   glutVisibilityFunc
   glutWarpPointer
   glutWindowStatusFunc
   glutWireCone
   glutWireCube
   glutWireCylinder
   glutWireDodecahedron
   glutWireIcosahedron
   glutWireOctahedron
   glutWireRhombicDodecahedron
   glutWireSphere
   glutWireTeapot
   glutWireTetrahedron
   glutWireTorus
);

# gltut
push @glut_func, qw(
   glutInitContextVersion
   glutInitContextFlags
   glutInitContextProfile
);

##------------------------------------------------------------------------
## FreeGLUT not implemented yet       -chm 2009-08-31
##------------------------------------------------------------------------
##
## Need to determine desired/useful interface
## glutGetProcAddress (const char *procName)
##
## Need to add pollInterval argument to glutJoystickFunc() call
## glutJoystickFunc (void(*callback)(unsigned int buttons, int xaxis, int yaxis, int zaxis), int pollInterval)
##
##------------------------------------------------------------------------

@glx_func = qw(
   glXSwapBuffers
   XPending
   glpXNextEvent
   glpXQueryPointer
);

@gl_const = qw(
   GL_FALSE
   GL_TRUE
   GL_BYTE
   GL_UNSIGNED_BYTE
   GL_SHORT
   GL_UNSIGNED_SHORT
   GL_INT
   GL_UNSIGNED_INT
   GL_FLOAT
   GL_DOUBLE
   GL_2_BYTES
   GL_3_BYTES
   GL_4_BYTES
   GL_LINES
   GL_POINTS
   GL_LINE_STRIP
   GL_LINE_LOOP
   GL_TRIANGLES
   GL_TRIANGLE_STRIP
   GL_TRIANGLE_FAN
   GL_QUADS
   GL_QUAD_STRIP
   GL_POLYGON
   GL_EDGE_FLAG
   GL_V2F
   GL_V3F
   GL_C4UB_V2F
   GL_C4UB_V3F
   GL_C3F_V3F
   GL_N3F_V3F
   GL_C4F_N3F_V3F
   GL_T2F_V3F
   GL_T4F_V4F
   GL_T2F_C4UB_V3F
   GL_T2F_C3F_V3F
   GL_T2F_N3F_V3F
   GL_T2F_C4F_N3F_V3F
   GL_T4F_C4F_N3F_V4F
   GL_MATRIX_MODE
   GL_MODELVIEW
   GL_PROJECTION
   GL_TEXTURE
   GL_POINT_SMOOTH
   GL_POINT_SIZE
   GL_POINT_SIZE_GRANULARITY
   GL_POINT_SIZE_RANGE
   GL_LINE_SMOOTH
   GL_LINE_STIPPLE
   GL_LINE_STIPPLE_PATTERN
   GL_LINE_STIPPLE_REPEAT
   GL_LINE_WIDTH
   GL_LINE_WIDTH_GRANULARITY
   GL_LINE_WIDTH_RANGE
   GL_POINT
   GL_LINE
   GL_FILL
   GL_CCW
   GL_CW
   GL_FRONT
   GL_BACK
   GL_CULL_FACE
   GL_CULL_FACE_MODE
   GL_POLYGON_SMOOTH
   GL_POLYGON_STIPPLE
   GL_FRONT_FACE
   GL_POLYGON_MODE
   GL_COMPILE
   GL_COMPILE_AND_EXECUTE
   GL_LIST_BASE
   GL_LIST_INDEX
   GL_LIST_MODE
   GL_NEVER
   GL_LESS
   GL_GEQUAL
   GL_LEQUAL
   GL_GREATER
   GL_NOTEQUAL
   GL_EQUAL
   GL_ALWAYS
   GL_DEPTH_TEST
   GL_DEPTH_BITS
   GL_DEPTH_CLEAR_VALUE
   GL_DEPTH_FUNC
   GL_DEPTH_RANGE
   GL_DEPTH_WRITEMASK
   GL_DEPTH_COMPONENT
   GL_LIGHTING
   GL_LIGHT0
   GL_LIGHT1
   GL_LIGHT2
   GL_LIGHT3
   GL_LIGHT4
   GL_LIGHT5
   GL_LIGHT6
   GL_LIGHT7
   GL_SPOT_EXPONENT
   GL_SPOT_CUTOFF
   GL_CONSTANT_ATTENUATION
   GL_LINEAR_ATTENUATION
   GL_QUADRATIC_ATTENUATION
   GL_AMBIENT
   GL_DIFFUSE
   GL_SPECULAR
   GL_SHININESS
   GL_EMISSION
   GL_POSITION
   GL_SPOT_DIRECTION
   GL_AMBIENT_AND_DIFFUSE
   GL_COLOR_INDEXES
   GL_LIGHT_MODEL_TWO_SIDE
   GL_LIGHT_MODEL_LOCAL_VIEWER
   GL_LIGHT_MODEL_AMBIENT
   GL_FRONT_AND_BACK
   GL_SHADE_MODEL
   GL_FLAT
   GL_SMOOTH
   GL_COLOR_MATERIAL
   GL_COLOR_MATERIAL_FACE
   GL_COLOR_MATERIAL_PARAMETER
   GL_NORMALIZE
   GL_CLIP_PLANE0
   GL_CLIP_PLANE1
   GL_CLIP_PLANE2
   GL_CLIP_PLANE3
   GL_CLIP_PLANE4
   GL_CLIP_PLANE5
   GL_ACCUM_RED_BITS
   GL_ACCUM_GREEN_BITS
   GL_ACCUM_BLUE_BITS
   GL_ACCUM_ALPHA_BITS
   GL_ACCUM_CLEAR_VALUE
   GL_ACCUM
   GL_ADD
   GL_LOAD
   GL_MULT
   GL_RETURN
   GL_ALPHA_TEST
   GL_ALPHA_TEST_REF
   GL_ALPHA_TEST_FUNC
   GL_BLEND
   GL_BLEND_SRC
   GL_BLEND_DST
   GL_ZERO
   GL_ONE
   GL_SRC_COLOR
   GL_ONE_MINUS_SRC_COLOR
   GL_DST_COLOR
   GL_ONE_MINUS_DST_COLOR
   GL_SRC_ALPHA
   GL_ONE_MINUS_SRC_ALPHA
   GL_DST_ALPHA
   GL_ONE_MINUS_DST_ALPHA
   GL_SRC_ALPHA_SATURATE
   GL_CONSTANT_COLOR
   GL_ONE_MINUS_CONSTANT_COLOR
   GL_CONSTANT_ALPHA
   GL_ONE_MINUS_CONSTANT_ALPHA
   GL_FEEDBACK
   GL_RENDER
   GL_SELECT
   GL_2D
   GL_3D
   GL_3D_COLOR
   GL_3D_COLOR_TEXTURE
   GL_4D_COLOR_TEXTURE
   GL_POINT_TOKEN
   GL_LINE_TOKEN
   GL_LINE_RESET_TOKEN
   GL_POLYGON_TOKEN
   GL_BITMAP_TOKEN
   GL_DRAW_PIXEL_TOKEN
   GL_COPY_PIXEL_TOKEN
   GL_PASS_THROUGH_TOKEN
   GL_FEEDBACK_BUFFER_SIZE
   GL_FEEDBACK_BUFFER_TYPE
   GL_FOG
   GL_FOG_MODE
   GL_FOG_DENSITY
   GL_FOG_COLOR
   GL_FOG_INDEX
   GL_FOG_START
   GL_FOG_END
   GL_LINEAR
   GL_EXP
   GL_EXP2
   GL_LOGIC_OP
   GL_LOGIC_OP_MODE
   GL_CLEAR
   GL_SET
   GL_COPY
   GL_COPY_INVERTED
   GL_NOOP
   GL_INVERT
   GL_AND
   GL_NAND
   GL_OR
   GL_NOR
   GL_XOR
   GL_EQUIV
   GL_AND_REVERSE
   GL_AND_INVERTED
   GL_OR_REVERSE
   GL_OR_INVERTED
   GL_STENCIL_TEST
   GL_STENCIL_WRITEMASK
   GL_STENCIL_BITS
   GL_STENCIL_FUNC
   GL_STENCIL_VALUE_MASK
   GL_STENCIL_REF
   GL_STENCIL_FAIL
   GL_STENCIL_PASS_DEPTH_PASS
   GL_STENCIL_PASS_DEPTH_FAIL
   GL_STENCIL_CLEAR_VALUE
   GL_STENCIL_INDEX
   GL_KEEP
   GL_REPLACE
   GL_INCR
   GL_DECR
   GL_NONE
   GL_LEFT
   GL_RIGHT
   GL_FRONT
   GL_BACK
   GL_FRONT_AND_BACK
   GL_FRONT_LEFT
   GL_FRONT_RIGHT
   GL_BACK_LEFT
   GL_BACK_RIGHT
   GL_AUX0
   GL_AUX1
   GL_AUX2
   GL_AUX3
   GL_COLOR_INDEX
   GL_RED
   GL_GREEN
   GL_BLUE
   GL_ALPHA
   GL_LUMINANCE
   GL_LUMINANCE_ALPHA
   GL_ALPHA_BITS
   GL_RED_BITS
   GL_GREEN_BITS
   GL_BLUE_BITS
   GL_INDEX_BITS
   GL_SUBPIXEL_BITS
   GL_AUX_BUFFERS
   GL_READ_BUFFER
   GL_DRAW_BUFFER
   GL_DOUBLEBUFFER
   GL_STEREO
   GL_BITMAP
   GL_COLOR
   GL_DEPTH
   GL_STENCIL
   GL_DITHER
   GL_RGB
   GL_RGBA
   GL_MAX_LIST_NESTING
   GL_MAX_ATTRIB_STACK_DEPTH
   GL_MAX_MODELVIEW_STACK_DEPTH
   GL_MAX_NAME_STACK_DEPTH
   GL_MAX_PROJECTION_STACK_DEPTH
   GL_MAX_TEXTURE_STACK_DEPTH
   GL_MAX_EVAL_ORDER
   GL_MAX_LIGHTS
   GL_MAX_CLIP_PLANES
   GL_MAX_TEXTURE_SIZE
   GL_MAX_PIXEL_MAP_TABLE
   GL_MAX_VIEWPORT_DIMS
   GL_ATTRIB_STACK_DEPTH
   GL_CLIENT_ATTRIB_STACK_DEPTH
   GL_COLOR_CLEAR_VALUE
   GL_COLOR_WRITEMASK
   GL_CURRENT_INDEX
   GL_CURRENT_COLOR
   GL_CURRENT_NORMAL
   GL_CURRENT_RASTER_COLOR
   GL_CURRENT_RASTER_DISTANCE
   GL_CURRENT_RASTER_INDEX
   GL_CURRENT_RASTER_POSITION
   GL_CURRENT_RASTER_TEXTURE_COORDS
   GL_CURRENT_RASTER_POSITION_VALID
   GL_CURRENT_TEXTURE_COORDS
   GL_INDEX_CLEAR_VALUE
   GL_INDEX_MODE
   GL_INDEX_WRITEMASK
   GL_MODELVIEW_MATRIX
   GL_MODELVIEW_STACK_DEPTH
   GL_NAME_STACK_DEPTH
   GL_PROJECTION_MATRIX
   GL_PROJECTION_STACK_DEPTH
   GL_RENDER_MODE
   GL_RGBA_MODE
   GL_TEXTURE_MATRIX
   GL_TEXTURE_STACK_DEPTH
   GL_VIEWPORT
   GL_AUTO_NORMAL
   GL_MAP1_COLOR_4
   GL_MAP1_GRID_DOMAIN
   GL_MAP1_GRID_SEGMENTS
   GL_MAP1_INDEX
   GL_MAP1_NORMAL
   GL_MAP1_TEXTURE_COORD_1
   GL_MAP1_TEXTURE_COORD_2
   GL_MAP1_TEXTURE_COORD_3
   GL_MAP1_TEXTURE_COORD_4
   GL_MAP1_VERTEX_3
   GL_MAP1_VERTEX_4
   GL_MAP2_COLOR_4
   GL_MAP2_GRID_DOMAIN
   GL_MAP2_GRID_SEGMENTS
   GL_MAP2_INDEX
   GL_MAP2_NORMAL
   GL_MAP2_TEXTURE_COORD_1
   GL_MAP2_TEXTURE_COORD_2
   GL_MAP2_TEXTURE_COORD_3
   GL_MAP2_TEXTURE_COORD_4
   GL_MAP2_VERTEX_3
   GL_MAP2_VERTEX_4
   GL_COEFF
   GL_DOMAIN
   GL_ORDER
   GL_FOG_HINT
   GL_LINE_SMOOTH_HINT
   GL_PERSPECTIVE_CORRECTION_HINT
   GL_POINT_SMOOTH_HINT
   GL_POLYGON_SMOOTH_HINT
   GL_DONT_CARE
   GL_FASTEST
   GL_NICEST
   GL_SCISSOR_TEST
   GL_SCISSOR_BOX
   GL_MAP_COLOR
   GL_MAP_STENCIL
   GL_INDEX_SHIFT
   GL_INDEX_OFFSET
   GL_RED_SCALE
   GL_RED_BIAS
   GL_GREEN_SCALE
   GL_GREEN_BIAS
   GL_BLUE_SCALE
   GL_BLUE_BIAS
   GL_ALPHA_SCALE
   GL_ALPHA_BIAS
   GL_DEPTH_SCALE
   GL_DEPTH_BIAS
   GL_PIXEL_MAP_S_TO_S_SIZE
   GL_PIXEL_MAP_I_TO_I_SIZE
   GL_PIXEL_MAP_I_TO_R_SIZE
   GL_PIXEL_MAP_I_TO_G_SIZE
   GL_PIXEL_MAP_I_TO_B_SIZE
   GL_PIXEL_MAP_I_TO_A_SIZE
   GL_PIXEL_MAP_R_TO_R_SIZE
   GL_PIXEL_MAP_G_TO_G_SIZE
   GL_PIXEL_MAP_B_TO_B_SIZE
   GL_PIXEL_MAP_A_TO_A_SIZE
   GL_PIXEL_MAP_S_TO_S
   GL_PIXEL_MAP_I_TO_I
   GL_PIXEL_MAP_I_TO_R
   GL_PIXEL_MAP_I_TO_G
   GL_PIXEL_MAP_I_TO_B
   GL_PIXEL_MAP_I_TO_A
   GL_PIXEL_MAP_R_TO_R
   GL_PIXEL_MAP_G_TO_G
   GL_PIXEL_MAP_B_TO_B
   GL_PIXEL_MAP_A_TO_A
   GL_PACK_ALIGNMENT
   GL_PACK_LSB_FIRST
   GL_PACK_ROW_LENGTH
   GL_PACK_SKIP_PIXELS
   GL_PACK_SKIP_ROWS
   GL_PACK_SWAP_BYTES
   GL_UNPACK_ALIGNMENT
   GL_UNPACK_LSB_FIRST
   GL_UNPACK_ROW_LENGTH
   GL_UNPACK_SKIP_PIXELS
   GL_UNPACK_SKIP_ROWS
   GL_UNPACK_SWAP_BYTES
   GL_ZOOM_X
   GL_ZOOM_Y
   GL_TEXTURE_ENV
   GL_TEXTURE_ENV_MODE
   GL_TEXTURE_1D
   GL_TEXTURE_2D
   GL_TEXTURE_WRAP_S
   GL_TEXTURE_WRAP_T
   GL_TEXTURE_MAG_FILTER
   GL_TEXTURE_MIN_FILTER
   GL_TEXTURE_ENV_COLOR
   GL_TEXTURE_GEN_S
   GL_TEXTURE_GEN_T
   GL_TEXTURE_GEN_MODE
   GL_TEXTURE_BORDER_COLOR
   GL_TEXTURE_WIDTH
   GL_TEXTURE_HEIGHT
   GL_TEXTURE_BORDER
   GL_TEXTURE_COMPONENTS
   GL_TEXTURE_RED_SIZE
   GL_TEXTURE_GREEN_SIZE
   GL_TEXTURE_BLUE_SIZE
   GL_TEXTURE_ALPHA_SIZE
   GL_TEXTURE_LUMINANCE_SIZE
   GL_TEXTURE_INTENSITY_SIZE
   GL_NEAREST_MIPMAP_NEAREST
   GL_NEAREST_MIPMAP_LINEAR
   GL_LINEAR_MIPMAP_NEAREST
   GL_LINEAR_MIPMAP_LINEAR
   GL_OBJECT_LINEAR
   GL_OBJECT_PLANE
   GL_EYE_LINEAR
   GL_EYE_PLANE
   GL_SPHERE_MAP
   GL_DECAL
   GL_MODULATE
   GL_NEAREST
   GL_REPEAT
   GL_CLAMP
   GL_S
   GL_T
   GL_R
   GL_Q
   GL_TEXTURE_GEN_R
   GL_TEXTURE_GEN_Q
   GL_VENDOR
   GL_RENDERER
   GL_VERSION
   GL_EXTENSIONS
   GL_INVALID_VALUE
   GL_INVALID_ENUM
   GL_INVALID_OPERATION
   GL_STACK_OVERFLOW
   GL_STACK_UNDERFLOW
   GL_OUT_OF_MEMORY
   GL_TEXTURE_RESIDENT
   GL_TEXTURE_BINDING_1D
   GL_TEXTURE_BINDING_2D
   GL_TEXTURE_PRIORITY
   GL_PROXY_TEXTURE_1D
   GL_PROXY_TEXTURE_2D
   GL_FEEDBACK_BUFFER_POINTER
   GL_VERTEX_ARRAY
   GL_NORMAL_ARRAY
   GL_COLOR_ARRAY
   GL_INDEX_ARRAY
   GL_TEXTURE_COORD_ARRAY
   GL_EDGE_FLAG_ARRAY
   GL_VERTEX_ARRAY_SIZE
   GL_VERTEX_ARRAY_TYPE
   GL_VERTEX_ARRAY_STRIDE
   GL_NORMAL_ARRAY_TYPE
   GL_NORMAL_ARRAY_STRIDE
   GL_COLOR_ARRAY_SIZE
   GL_COLOR_ARRAY_TYPE
   GL_COLOR_ARRAY_STRIDE
   GL_INDEX_ARRAY_TYPE
   GL_INDEX_ARRAY_STRIDE
   GL_TEXTURE_COORD_ARRAY_SIZE
   GL_TEXTURE_COORD_ARRAY_TYPE
   GL_TEXTURE_COORD_ARRAY_STRIDE
   GL_EDGE_FLAG_ARRAY_STRIDE
   GL_VERTEX_ARRAY_POINTER
   GL_NORMAL_ARRAY_POINTER
   GL_COLOR_ARRAY_POINTER
   GL_INDEX_ARRAY_POINTER
   GL_TEXTURE_COORD_ARRAY_POINTER
   GL_EDGE_FLAG_ARRAY_POINTER
   GL_POLYGON_OFFSET_FACTOR
   GL_POLYGON_OFFSET_UNITS
   GL_POLYGON_OFFSET_POINT
   GL_POLYGON_OFFSET_LINE
   GL_POLYGON_OFFSET_FILL
   GL_INDEX_LOGIC_OP
   GL_COLOR_LOGIC_OP
   GL_ALPHA4
   GL_ALPHA8
   GL_ALPHA12
   GL_ALPHA16
   GL_LUMINANCE4
   GL_LUMINANCE8
   GL_LUMINANCE12
   GL_LUMINANCE16
   GL_LUMINANCE4_ALPHA4
   GL_LUMINANCE6_ALPHA2
   GL_LUMINANCE8_ALPHA8
   GL_LUMINANCE12_ALPHA4
   GL_LUMINANCE12_ALPHA12
   GL_LUMINANCE16_ALPHA16
   GL_INTENSITY
   GL_INTENSITY4
   GL_INTENSITY8
   GL_INTENSITY12
   GL_INTENSITY16
   GL_R3_G3_B2
   GL_RGB4
   GL_RGB5
   GL_RGB8
   GL_RGB10
   GL_RGB12
   GL_RGB16
   GL_RGBA2
   GL_RGBA4
   GL_RGB5_A1
   GL_RGBA8
   GL_RGB10_A2
   GL_RGBA12
   GL_RGBA16
   GL_PACK_SKIP_IMAGES
   GL_PACK_IMAGE_HEIGHT
   GL_UNPACK_SKIP_IMAGES
   GL_UNPACK_IMAGE_HEIGHT
   GL_TEXTURE_3D
   GL_PROXY_TEXTURE_3D
   GL_TEXTURE_DEPTH
   GL_TEXTURE_WRAP_R
   GL_MAX_3D_TEXTURE_SIZE
   GL_TEXTURE_BINDING_3D
   GL_BGR
   GL_BGRA
   GL_UNSIGNED_BYTE_3_3_2
   GL_UNSIGNED_BYTE_2_3_3_REV
   GL_UNSIGNED_SHORT_5_6_5
   GL_UNSIGNED_SHORT_5_6_5_REV
   GL_UNSIGNED_SHORT_4_4_4_4
   GL_UNSIGNED_SHORT_4_4_4_4_REV
   GL_UNSIGNED_SHORT_5_5_5_1
   GL_UNSIGNED_SHORT_1_5_5_5_REV
   GL_UNSIGNED_INT_8_8_8_8
   GL_UNSIGNED_INT_8_8_8_8_REV
   GL_UNSIGNED_INT_10_10_10_2
   GL_UNSIGNED_INT_2_10_10_10_REV
   GL_RESCALE_NORMAL
   GL_LIGHT_MODEL_COLOR_CONTROL
   GL_SINGLE_COLOR
   GL_SEPARATE_SPECULAR_COLOR
   GL_CLAMP_TO_EDGE
   GL_TEXTURE_MIN_LOD
   GL_TEXTURE_MAX_LOD
   GL_TEXTURE_BASE_LEVEL
   GL_TEXTURE_MAX_LEVEL
   GL_MAX_ELEMENTS_VERTICES
   GL_MAX_ELEMENTS_INDICES
   GL_NO_ERROR
   GL_MAX_CLIENT_ATTRIB_STACK_DEPTH
   GL_SELECTION_BUFFER_POINTER
   GL_SELECTION_BUFFER_SIZE
   GL_TEXTURE_INTERNAL_FORMAT
   GL_BLEND_COLOR
   GL_FUNC_ADD
   GL_MIN
   GL_MAX
   GL_BLEND_EQUATION
   GL_FUNC_SUBTRACT
   GL_FUNC_REVERSE_SUBTRACT
   GL_COLOR_MATRIX
   GL_COLOR_MATRIX_STACK_DEPTH
   GL_MAX_COLOR_MATRIX_STACK_DEPTH
   GL_POST_COLOR_MATRIX_RED_SCALE
   GL_POST_COLOR_MATRIX_GREEN_SCALE
   GL_POST_COLOR_MATRIX_BLUE_SCALE
   GL_POST_COLOR_MATRIX_ALPHA_SCALE
   GL_POST_COLOR_MATRIX_RED_BIAS
   GL_POST_COLOR_MATRIX_GREEN_BIAS
   GL_POST_COLOR_MATRIX_BLUE_BIAS
   GL_POST_COLOR_MATRIX_ALPHA_BIAS
   GL_COLOR_TABLE
   GL_POST_CONVOLUTION_COLOR_TABLE
   GL_POST_COLOR_MATRIX_COLOR_TABLE
   GL_PROXY_COLOR_TABLE
   GL_PROXY_POST_CONVOLUTION_COLOR_TABLE
   GL_PROXY_POST_COLOR_MATRIX_COLOR_TABLE
   GL_COLOR_TABLE_SCALE
   GL_COLOR_TABLE_BIAS
   GL_COLOR_TABLE_FORMAT
   GL_COLOR_TABLE_WIDTH
   GL_COLOR_TABLE_RED_SIZE
   GL_COLOR_TABLE_GREEN_SIZE
   GL_COLOR_TABLE_BLUE_SIZE
   GL_COLOR_TABLE_ALPHA_SIZE
   GL_COLOR_TABLE_LUMINANCE_SIZE
   GL_COLOR_TABLE_INTENSITY_SIZE
   GL_CONVOLUTION_1D
   GL_CONVOLUTION_2D
   GL_SEPARABLE_2D
   GL_CONVOLUTION_BORDER_MODE
   GL_CONVOLUTION_FILTER_SCALE
   GL_CONVOLUTION_FILTER_BIAS
   GL_REDUCE
   GL_CONVOLUTION_FORMAT
   GL_CONVOLUTION_WIDTH
   GL_CONVOLUTION_HEIGHT
   GL_MAX_CONVOLUTION_WIDTH
   GL_MAX_CONVOLUTION_HEIGHT
   GL_POST_CONVOLUTION_RED_SCALE
   GL_POST_CONVOLUTION_GREEN_SCALE
   GL_POST_CONVOLUTION_BLUE_SCALE
   GL_POST_CONVOLUTION_ALPHA_SCALE
   GL_POST_CONVOLUTION_RED_BIAS
   GL_POST_CONVOLUTION_GREEN_BIAS
   GL_POST_CONVOLUTION_BLUE_BIAS
   GL_POST_CONVOLUTION_ALPHA_BIAS
   GL_CONSTANT_BORDER
   GL_REPLICATE_BORDER
   GL_CONVOLUTION_BORDER_COLOR
   GL_HISTOGRAM
   GL_PROXY_HISTOGRAM
   GL_HISTOGRAM_WIDTH
   GL_HISTOGRAM_FORMAT
   GL_HISTOGRAM_RED_SIZE
   GL_HISTOGRAM_GREEN_SIZE
   GL_HISTOGRAM_BLUE_SIZE
   GL_HISTOGRAM_ALPHA_SIZE
   GL_HISTOGRAM_LUMINANCE_SIZE
   GL_HISTOGRAM_SINK
   GL_MINMAX
   GL_MINMAX_FORMAT
   GL_MINMAX_SINK
   GL_TABLE_TOO_LARGE
   GL_SMOOTH_POINT_SIZE_RANGE
   GL_SMOOTH_POINT_SIZE_GRANULARITY
   GL_SMOOTH_LINE_WIDTH_RANGE
   GL_SMOOTH_LINE_WIDTH_GRANULARITY
   GL_ALIASED_POINT_SIZE_RANGE
   GL_ALIASED_LINE_WIDTH_RANGE
   GL_TEXTURE0_ARB
   GL_TEXTURE1_ARB
   GL_TEXTURE2_ARB
   GL_TEXTURE3_ARB
   GL_TEXTURE4_ARB
   GL_TEXTURE5_ARB
   GL_TEXTURE6_ARB
   GL_TEXTURE7_ARB
   GL_TEXTURE8_ARB
   GL_TEXTURE9_ARB
   GL_TEXTURE10_ARB
   GL_TEXTURE11_ARB
   GL_TEXTURE12_ARB
   GL_TEXTURE13_ARB
   GL_TEXTURE14_ARB
   GL_TEXTURE15_ARB
   GL_TEXTURE16_ARB
   GL_TEXTURE17_ARB
   GL_TEXTURE18_ARB
   GL_TEXTURE19_ARB
   GL_TEXTURE20_ARB
   GL_TEXTURE21_ARB
   GL_TEXTURE22_ARB
   GL_TEXTURE23_ARB
   GL_TEXTURE24_ARB
   GL_TEXTURE25_ARB
   GL_TEXTURE26_ARB
   GL_TEXTURE27_ARB
   GL_TEXTURE28_ARB
   GL_TEXTURE29_ARB
   GL_TEXTURE30_ARB
   GL_TEXTURE31_ARB
   GL_ACTIVE_TEXTURE_ARB
   GL_CLIENT_ACTIVE_TEXTURE_ARB
   GL_MAX_TEXTURE_UNITS_ARB
   GL_POLYGON_OFFSET_EXT
   GL_POLYGON_OFFSET_FACTOR_EXT
   GL_POLYGON_OFFSET_BIAS_EXT
   GL_ALPHA4_EXT
   GL_ALPHA8_EXT
   GL_ALPHA12_EXT
   GL_ALPHA16_EXT
   GL_LUMINANCE4_EXT
   GL_LUMINANCE8_EXT
   GL_LUMINANCE12_EXT
   GL_LUMINANCE16_EXT
   GL_LUMINANCE4_ALPHA4_EXT
   GL_LUMINANCE6_ALPHA2_EXT
   GL_LUMINANCE8_ALPHA8_EXT
   GL_LUMINANCE12_ALPHA4_EXT
   GL_LUMINANCE12_ALPHA12_EXT
   GL_LUMINANCE16_ALPHA16_EXT
   GL_INTENSITY_EXT
   GL_INTENSITY4_EXT
   GL_INTENSITY8_EXT
   GL_INTENSITY12_EXT
   GL_INTENSITY16_EXT
   GL_R3_G3_B2_EXT
   GL_RGB4_EXT
   GL_RGB5_EXT
   GL_RGB8_EXT
   GL_RGB10_EXT
   GL_RGB12_EXT
   GL_RGB16_EXT
   GL_RGBA2_EXT
   GL_RGBA4_EXT
   GL_RGB5_A1_EXT
   GL_RGBA8_EXT
   GL_RGB10_A2_EXT
   GL_RGBA12_EXT
   GL_RGBA16_EXT
   GL_TEXTURE_RED_SIZE_EXT
   GL_TEXTURE_GREEN_SIZE_EXT
   GL_TEXTURE_BLUE_SIZE_EXT
   GL_TEXTURE_ALPHA_SIZE_EXT
   GL_TEXTURE_LUMINANCE_SIZE_EXT
   GL_TEXTURE_INTENSITY_SIZE_EXT
   GL_REPLACE_EXT
   GL_PROXY_TEXTURE_1D
   GL_PROXY_TEXTURE_2D
   GL_TEXTURE_TOO_LARGE_EXT
   GL_CMYK_EXT
   GL_CMYKA_EXT
   GL_PACK_CMYK_HINT_EXT
   GL_UNPACK_CMYK_HINT_EXT
   GL_CMYK
   GL_CMYKA
   GL_PACK_CMYK_HINT
   GL_UNPACK_CMYK_HINT
   GL_TEXTURE_PRIORITY_EXT
   GL_TEXTURE_RESIDENT_EXT
   GL_TEXTURE_1D_BINDING_EXT
   GL_TEXTURE_2D_BINDING_EXT
   GL_TEXTURE_3D_BINDING_EXT
   GL_VERTEX_ARRAY_EXT
   GL_NORMAL_ARRAY_EXT
   GL_COLOR_ARRAY_EXT
   GL_INDEX_ARRAY_EXT
   GL_TEXTURE_COORD_ARRAY_EXT
   GL_EDGE_FLAG_ARRAY_EXT
   GL_VERTEX_ARRAY_SIZE_EXT
   GL_VERTEX_ARRAY_TYPE_EXT
   GL_VERTEX_ARRAY_STRIDE_EXT
   GL_NORMAL_ARRAY_TYPE_EXT
   GL_NORMAL_ARRAY_STRIDE_EXT
   GL_COLOR_ARRAY_SIZE_EXT
   GL_COLOR_ARRAY_TYPE_EXT
   GL_COLOR_ARRAY_STRIDE_EXT
   GL_INDEX_ARRAY_TYPE_EXT
   GL_INDEX_ARRAY_STRIDE_EXT
   GL_TEXTURE_COORD_ARRAY_SIZE_EXT
   GL_TEXTURE_COORD_ARRAY_TYPE_EXT
   GL_TEXTURE_COORD_ARRAY_STRIDE_EXT
   GL_EDGE_FLAG_ARRAY_STRIDE_EXT
   GL_VERTEX_ARRAY_POINTER_EXT
   GL_NORMAL_ARRAY_POINTER_EXT
   GL_COLOR_ARRAY_POINTER_EXT
   GL_INDEX_ARRAY_POINTER_EXT
   GL_TEXTURE_COORD_ARRAY_POINTER_EXT
   GL_EDGE_FLAG_ARRAY_POINTER_EXT
   GL_VERTEX_ARRAY_COUNT_EXT
   GL_NORMAL_ARRAY_COUNT_EXT
   GL_COLOR_ARRAY_COUNT_EXT
   GL_INDEX_ARRAY_COUNT_EXT
   GL_TEXTURE_COORD_ARRAY_COUNT_EXT
   GL_EDGE_FLAG_ARRAY_COUNT_EXT
   GL_MISC_BIT_EXT
   GL_CONSTANT_COLOR_EXT
   GL_ONE_MINUS_CONSTANT_COLOR_EXT
   GL_CONSTANT_ALPHA_EXT
   GL_ONE_MINUS_CONSTANT_ALPHA_EXT
   GL_BLEND_EQUATION_EXT
   GL_MIN_EXT
   GL_MAX_EXT
   GL_FUNC_ADD_EXT
   GL_FUNC_SUBTRACT_EXT
   GL_FUNC_REVERSE_SUBTRACT_EXT
   GL_BLEND_COLOR_EXT
   GL_ABGR_EXT
   GL_VOLUME_CLIPPING_HINT_EXT
   GL_TEXTURE_PRIORITY_EXT
   GL_TEXTURE_RESIDENT_EXT
   GL_TEXTURE_1D_BINDING_EXT
   GL_TEXTURE_2D_BINDING_EXT
   GL_PACK_SKIP_IMAGES_EXT
   GL_PACK_IMAGE_HEIGHT_EXT
   GL_UNPACK_SKIP_IMAGES_EXT
   GL_UNPACK_IMAGE_HEIGHT_EXT
   GL_TEXTURE_3D_EXT
   GL_PROXY_TEXTURE_3D_EXT
   GL_TEXTURE_DEPTH_EXT
   GL_TEXTURE_WRAP_R_EXT
   GL_MAX_3D_TEXTURE_SIZE_EXT
   GL_TEXTURE_3D_BINDING_EXT
   GL_TABLE_TOO_LARGE_EXT
   GL_COLOR_TABLE_FORMAT_EXT
   GL_COLOR_TABLE_WIDTH_EXT
   GL_COLOR_TABLE_RED_SIZE_EXT
   GL_COLOR_TABLE_GREEN_SIZE_EXT
   GL_COLOR_TABLE_BLUE_SIZE_EXT
   GL_COLOR_TABLE_ALPHA_SIZE_EXT
   GL_COLOR_TABLE_LUMINANCE_SIZE_EXT
   GL_COLOR_TABLE_INTENSITY_SIZE_EXT
   GL_TEXTURE_INDEX_SIZE_EXT
   GL_COLOR_INDEX1_EXT
   GL_COLOR_INDEX2_EXT
   GL_COLOR_INDEX4_EXT
   GL_COLOR_INDEX8_EXT
   GL_COLOR_INDEX12_EXT
   GL_COLOR_INDEX16_EXT
   GL_SHARED_TEXTURE_PALETTE_EXT
   GL_POINT_SIZE_MIN_EXT
   GL_POINT_SIZE_MAX_EXT
   GL_POINT_FADE_THRESHOLD_SIZE_EXT
   GL_DISTANCE_ATTENUATION_EXT
   GL_COMBINE_EXT
   GL_COMBINE_RGB_EXT
   GL_COMBINE_ALPHA_EXT
   GL_RGB_SCALE_EXT
   GL_ADD_SIGNED_EXT
   GL_INTERPOLATE_EXT
   GL_CONSTANT_EXT
   GL_PRIMARY_COLOR_EXT
   GL_PREVIOUS_EXT
   GL_SOURCE0_RGB_EXT
   GL_SOURCE1_RGB_EXT
   GL_SOURCE2_RGB_EXT
   GL_SOURCE0_ALPHA_EXT
   GL_SOURCE1_ALPHA_EXT
   GL_SOURCE2_ALPHA_EXT
   GL_OPERAND0_RGB_EXT
   GL_OPERAND1_RGB_EXT
   GL_OPERAND2_RGB_EXT
   GL_OPERAND0_ALPHA_EXT
   GL_OPERAND1_ALPHA_EXT
   GL_OPERAND2_ALPHA_EXT
   GL_GLEXT_VERSION
   GL_SMOOTH_POINT_SIZE_RANGE
   GL_SMOOTH_POINT_SIZE_GRANULARITY
   GL_SMOOTH_LINE_WIDTH_RANGE
   GL_SMOOTH_LINE_WIDTH_GRANULARITY
   GL_ALIASED_POINT_SIZE_RANGE
   GL_ALIASED_LINE_WIDTH_RANGE
   GL_BLEND_COLOR
   GL_FUNC_ADD
   GL_MIN
   GL_MAX
   GL_BLEND_EQUATION
   GL_FUNC_SUBTRACT
   GL_FUNC_REVERSE_SUBTRACT
   GL_CONVOLUTION_1D
   GL_CONVOLUTION_2D
   GL_SEPARABLE_2D
   GL_CONVOLUTION_BORDER_MODE
   GL_CONVOLUTION_FILTER_SCALE
   GL_CONVOLUTION_FILTER_BIAS
   GL_REDUCE
   GL_CONVOLUTION_FORMAT
   GL_CONVOLUTION_WIDTH
   GL_CONVOLUTION_HEIGHT
   GL_MAX_CONVOLUTION_WIDTH
   GL_MAX_CONVOLUTION_HEIGHT
   GL_POST_CONVOLUTION_RED_SCALE
   GL_POST_CONVOLUTION_GREEN_SCALE
   GL_POST_CONVOLUTION_BLUE_SCALE
   GL_POST_CONVOLUTION_ALPHA_SCALE
   GL_POST_CONVOLUTION_RED_BIAS
   GL_POST_CONVOLUTION_GREEN_BIAS
   GL_POST_CONVOLUTION_BLUE_BIAS
   GL_POST_CONVOLUTION_ALPHA_BIAS
   GL_HISTOGRAM
   GL_PROXY_HISTOGRAM
   GL_HISTOGRAM_WIDTH
   GL_HISTOGRAM_FORMAT
   GL_HISTOGRAM_RED_SIZE
   GL_HISTOGRAM_GREEN_SIZE
   GL_HISTOGRAM_BLUE_SIZE
   GL_HISTOGRAM_ALPHA_SIZE
   GL_HISTOGRAM_LUMINANCE_SIZE
   GL_HISTOGRAM_SINK
   GL_MINMAX
   GL_MINMAX_FORMAT
   GL_MINMAX_SINK
   GL_TABLE_TOO_LARGE
   GL_COLOR_MATRIX
   GL_COLOR_MATRIX_STACK_DEPTH
   GL_MAX_COLOR_MATRIX_STACK_DEPTH
   GL_POST_COLOR_MATRIX_RED_SCALE
   GL_POST_COLOR_MATRIX_GREEN_SCALE
   GL_POST_COLOR_MATRIX_BLUE_SCALE
   GL_POST_COLOR_MATRIX_ALPHA_SCALE
   GL_POST_COLOR_MATRIX_RED_BIAS
   GL_POST_COLOR_MATRIX_GREEN_BIAS
   GL_POST_COLOR_MATRIX_BLUE_BIAS
   GL_POST_COLOR_MATRIX_ALPHA_BIAS
   GL_COLOR_TABLE
   GL_POST_CONVOLUTION_COLOR_TABLE
   GL_POST_COLOR_MATRIX_COLOR_TABLE
   GL_PROXY_COLOR_TABLE
   GL_PROXY_POST_CONVOLUTION_COLOR_TABLE
   GL_PROXY_POST_COLOR_MATRIX_COLOR_TABLE
   GL_COLOR_TABLE_SCALE
   GL_COLOR_TABLE_BIAS
   GL_COLOR_TABLE_FORMAT
   GL_COLOR_TABLE_WIDTH
   GL_COLOR_TABLE_RED_SIZE
   GL_COLOR_TABLE_GREEN_SIZE
   GL_COLOR_TABLE_BLUE_SIZE
   GL_COLOR_TABLE_ALPHA_SIZE
   GL_COLOR_TABLE_LUMINANCE_SIZE
   GL_COLOR_TABLE_INTENSITY_SIZE
   GL_CONSTANT_BORDER
   GL_REPLICATE_BORDER
   GL_CONVOLUTION_BORDER_COLOR
   GL_TEXTURE0
   GL_TEXTURE1
   GL_TEXTURE2
   GL_TEXTURE3
   GL_TEXTURE4
   GL_TEXTURE5
   GL_TEXTURE6
   GL_TEXTURE7
   GL_TEXTURE8
   GL_TEXTURE9
   GL_TEXTURE10
   GL_TEXTURE11
   GL_TEXTURE12
   GL_TEXTURE13
   GL_TEXTURE14
   GL_TEXTURE15
   GL_TEXTURE16
   GL_TEXTURE17
   GL_TEXTURE18
   GL_TEXTURE19
   GL_TEXTURE20
   GL_TEXTURE21
   GL_TEXTURE22
   GL_TEXTURE23
   GL_TEXTURE24
   GL_TEXTURE25
   GL_TEXTURE26
   GL_TEXTURE27
   GL_TEXTURE28
   GL_TEXTURE29
   GL_TEXTURE30
   GL_TEXTURE31
   GL_ACTIVE_TEXTURE
   GL_CLIENT_ACTIVE_TEXTURE
   GL_MAX_TEXTURE_UNITS
   GL_TRANSPOSE_MODELVIEW_MATRIX
   GL_TRANSPOSE_PROJECTION_MATRIX
   GL_TRANSPOSE_TEXTURE_MATRIX
   GL_TRANSPOSE_COLOR_MATRIX
   GL_MULTISAMPLE
   GL_SAMPLE_ALPHA_TO_COVERAGE
   GL_SAMPLE_ALPHA_TO_ONE
   GL_SAMPLE_COVERAGE
   GL_SAMPLE_BUFFERS
   GL_SAMPLES
   GL_SAMPLE_COVERAGE_VALUE
   GL_SAMPLE_COVERAGE_INVERT
   GL_MULTISAMPLE_BIT
   GL_NORMAL_MAP
   GL_REFLECTION_MAP
   GL_TEXTURE_CUBE_MAP
   GL_TEXTURE_BINDING_CUBE_MAP
   GL_TEXTURE_CUBE_MAP_POSITIVE_X
   GL_TEXTURE_CUBE_MAP_NEGATIVE_X
   GL_TEXTURE_CUBE_MAP_POSITIVE_Y
   GL_TEXTURE_CUBE_MAP_NEGATIVE_Y
   GL_TEXTURE_CUBE_MAP_POSITIVE_Z
   GL_TEXTURE_CUBE_MAP_NEGATIVE_Z
   GL_PROXY_TEXTURE_CUBE_MAP
   GL_MAX_CUBE_MAP_TEXTURE_SIZE
   GL_COMPRESSED_ALPHA
   GL_COMPRESSED_LUMINANCE
   GL_COMPRESSED_LUMINANCE_ALPHA
   GL_COMPRESSED_INTENSITY
   GL_COMPRESSED_RGB
   GL_COMPRESSED_RGBA
   GL_TEXTURE_COMPRESSION_HINT
   GL_TEXTURE_COMPRESSED_IMAGE_SIZE
   GL_TEXTURE_COMPRESSED
   GL_NUM_COMPRESSED_TEXTURE_FORMATS
   GL_COMPRESSED_TEXTURE_FORMATS
   GL_CLAMP_TO_BORDER
   GL_COMBINE
   GL_COMBINE_RGB
   GL_COMBINE_ALPHA
   GL_SOURCE0_RGB
   GL_SOURCE1_RGB
   GL_SOURCE2_RGB
   GL_SOURCE0_ALPHA
   GL_SOURCE1_ALPHA
   GL_SOURCE2_ALPHA
   GL_OPERAND0_RGB
   GL_OPERAND1_RGB
   GL_OPERAND2_RGB
   GL_OPERAND0_ALPHA
   GL_OPERAND1_ALPHA
   GL_OPERAND2_ALPHA
   GL_RGB_SCALE
   GL_ADD_SIGNED
   GL_INTERPOLATE
   GL_SUBTRACT
   GL_CONSTANT
   GL_PRIMARY_COLOR
   GL_PREVIOUS
   GL_DOT3_RGB
   GL_DOT3_RGBA
   GL_BLEND_DST_RGB
   GL_BLEND_SRC_RGB
   GL_BLEND_DST_ALPHA
   GL_BLEND_SRC_ALPHA
   GL_POINT_SIZE_MIN
   GL_POINT_SIZE_MAX
   GL_POINT_FADE_THRESHOLD_SIZE
   GL_POINT_DISTANCE_ATTENUATION
   GL_GENERATE_MIPMAP
   GL_GENERATE_MIPMAP_HINT
   GL_DEPTH_COMPONENT16
   GL_DEPTH_COMPONENT24
   GL_DEPTH_COMPONENT32
   GL_MIRRORED_REPEAT
   GL_FOG_COORDINATE_SOURCE
   GL_FOG_COORDINATE
   GL_FRAGMENT_DEPTH
   GL_CURRENT_FOG_COORDINATE
   GL_FOG_COORDINATE_ARRAY_TYPE
   GL_FOG_COORDINATE_ARRAY_STRIDE
   GL_FOG_COORDINATE_ARRAY_POINTER
   GL_FOG_COORDINATE_ARRAY
   GL_COLOR_SUM
   GL_CURRENT_SECONDARY_COLOR
   GL_SECONDARY_COLOR_ARRAY_SIZE
   GL_SECONDARY_COLOR_ARRAY_TYPE
   GL_SECONDARY_COLOR_ARRAY_STRIDE
   GL_SECONDARY_COLOR_ARRAY_POINTER
   GL_SECONDARY_COLOR_ARRAY
   GL_MAX_TEXTURE_LOD_BIAS
   GL_TEXTURE_FILTER_CONTROL
   GL_TEXTURE_LOD_BIAS
   GL_INCR_WRAP
   GL_DECR_WRAP
   GL_TEXTURE_DEPTH_SIZE
   GL_DEPTH_TEXTURE_MODE
   GL_TEXTURE_COMPARE_MODE
   GL_TEXTURE_COMPARE_FUNC
   GL_COMPARE_R_TO_TEXTURE
   GL_BUFFER_SIZE
   GL_BUFFER_USAGE
   GL_QUERY_COUNTER_BITS
   GL_CURRENT_QUERY
   GL_QUERY_RESULT
   GL_QUERY_RESULT_AVAILABLE
   GL_ARRAY_BUFFER
   GL_ELEMENT_ARRAY_BUFFER
   GL_ARRAY_BUFFER_BINDING
   GL_ELEMENT_ARRAY_BUFFER_BINDING
   GL_VERTEX_ARRAY_BUFFER_BINDING
   GL_NORMAL_ARRAY_BUFFER_BINDING
   GL_COLOR_ARRAY_BUFFER_BINDING
   GL_INDEX_ARRAY_BUFFER_BINDING
   GL_TEXTURE_COORD_ARRAY_BUFFER_BINDING
   GL_EDGE_FLAG_ARRAY_BUFFER_BINDING
   GL_SECONDARY_COLOR_ARRAY_BUFFER_BINDING
   GL_FOG_COORDINATE_ARRAY_BUFFER_BINDING
   GL_WEIGHT_ARRAY_BUFFER_BINDING
   GL_VERTEX_ATTRIB_ARRAY_BUFFER_BINDING
   GL_READ_ONLY
   GL_WRITE_ONLY
   GL_READ_WRITE
   GL_BUFFER_ACCESS
   GL_BUFFER_MAPPED
   GL_BUFFER_MAP_POINTER
   GL_STREAM_DRAW
   GL_STREAM_READ
   GL_STREAM_COPY
   GL_STATIC_DRAW
   GL_STATIC_READ
   GL_STATIC_COPY
   GL_DYNAMIC_DRAW
   GL_DYNAMIC_READ
   GL_DYNAMIC_COPY
   GL_SAMPLES_PASSED
   GL_FOG_COORD_SRC
   GL_FOG_COORD
   GL_CURRENT_FOG_COORD
   GL_FOG_COORD_ARRAY_TYPE
   GL_FOG_COORD_ARRAY_STRIDE
   GL_FOG_COORD_ARRAY_POINTER
   GL_FOG_COORD_ARRAY
   GL_FOG_COORD_ARRAY_BUFFER_BINDING
   GL_SRC0_RGB
   GL_SRC1_RGB
   GL_SRC2_RGB
   GL_SRC0_ALPHA
   GL_SRC1_ALPHA
   GL_SRC2_ALPHA
   GL_BLEND_EQUATION_RGB
   GL_VERTEX_ATTRIB_ARRAY_ENABLED
   GL_VERTEX_ATTRIB_ARRAY_SIZE
   GL_VERTEX_ATTRIB_ARRAY_STRIDE
   GL_VERTEX_ATTRIB_ARRAY_TYPE
   GL_CURRENT_VERTEX_ATTRIB
   GL_VERTEX_PROGRAM_POINT_SIZE
   GL_VERTEX_PROGRAM_TWO_SIDE
   GL_VERTEX_ATTRIB_ARRAY_POINTER
   GL_STENCIL_BACK_FUNC
   GL_STENCIL_BACK_FAIL
   GL_STENCIL_BACK_PASS_DEPTH_FAIL
   GL_STENCIL_BACK_PASS_DEPTH_PASS
   GL_MAX_DRAW_BUFFERS
   GL_DRAW_BUFFER0
   GL_DRAW_BUFFER1
   GL_DRAW_BUFFER2
   GL_DRAW_BUFFER3
   GL_DRAW_BUFFER4
   GL_DRAW_BUFFER5
   GL_DRAW_BUFFER6
   GL_DRAW_BUFFER7
   GL_DRAW_BUFFER8
   GL_DRAW_BUFFER9
   GL_DRAW_BUFFER10
   GL_DRAW_BUFFER11
   GL_DRAW_BUFFER12
   GL_DRAW_BUFFER13
   GL_DRAW_BUFFER14
   GL_DRAW_BUFFER15
   GL_BLEND_EQUATION_ALPHA
   GL_POINT_SPRITE
   GL_COORD_REPLACE
   GL_MAX_VERTEX_ATTRIBS
   GL_VERTEX_ATTRIB_ARRAY_NORMALIZED
   GL_MAX_TEXTURE_COORDS
   GL_MAX_TEXTURE_IMAGE_UNITS
   GL_FRAGMENT_SHADER
   GL_VERTEX_SHADER
   GL_GEOMETRY_SHADER
   GL_MAX_FRAGMENT_UNIFORM_COMPONENTS
   GL_MAX_VERTEX_UNIFORM_COMPONENTS
   GL_MAX_VARYING_FLOATS
   GL_MAX_VERTEX_TEXTURE_IMAGE_UNITS
   GL_MAX_COMBINED_TEXTURE_IMAGE_UNITS
   GL_SHADER_TYPE
   GL_FLOAT_VEC2
   GL_FLOAT_VEC3
   GL_FLOAT_VEC4
   GL_INT_VEC2
   GL_INT_VEC3
   GL_INT_VEC4
   GL_BOOL
   GL_BOOL_VEC2
   GL_BOOL_VEC3
   GL_BOOL_VEC4
   GL_FLOAT_MAT2
   GL_FLOAT_MAT3
   GL_FLOAT_MAT4
   GL_SAMPLER_1D
   GL_SAMPLER_2D
   GL_SAMPLER_3D
   GL_SAMPLER_CUBE
   GL_SAMPLER_1D_SHADOW
   GL_SAMPLER_2D_SHADOW
   GL_DELETE_STATUS
   GL_COMPILE_STATUS
   GL_LINK_STATUS
   GL_VALIDATE_STATUS
   GL_INFO_LOG_LENGTH
   GL_ATTACHED_SHADERS
   GL_ACTIVE_UNIFORMS
   GL_ACTIVE_UNIFORM_MAX_LENGTH
   GL_SHADER_SOURCE_LENGTH
   GL_ACTIVE_ATTRIBUTES
   GL_ACTIVE_ATTRIBUTE_MAX_LENGTH
   GL_FRAGMENT_SHADER_DERIVATIVE_HINT
   GL_SHADING_LANGUAGE_VERSION
   GL_CURRENT_PROGRAM
   GL_POINT_SPRITE_COORD_ORIGIN
   GL_LOWER_LEFT
   GL_UPPER_LEFT
   GL_STENCIL_BACK_REF
   GL_STENCIL_BACK_VALUE_MASK
   GL_STENCIL_BACK_WRITEMASK
   GL_TEXTURE0_ARB
   GL_TEXTURE1_ARB
   GL_TEXTURE2_ARB
   GL_TEXTURE3_ARB
   GL_TEXTURE4_ARB
   GL_TEXTURE5_ARB
   GL_TEXTURE6_ARB
   GL_TEXTURE7_ARB
   GL_TEXTURE8_ARB
   GL_TEXTURE9_ARB
   GL_TEXTURE10_ARB
   GL_TEXTURE11_ARB
   GL_TEXTURE12_ARB
   GL_TEXTURE13_ARB
   GL_TEXTURE14_ARB
   GL_TEXTURE15_ARB
   GL_TEXTURE16_ARB
   GL_TEXTURE17_ARB
   GL_TEXTURE18_ARB
   GL_TEXTURE19_ARB
   GL_TEXTURE20_ARB
   GL_TEXTURE21_ARB
   GL_TEXTURE22_ARB
   GL_TEXTURE23_ARB
   GL_TEXTURE24_ARB
   GL_TEXTURE25_ARB
   GL_TEXTURE26_ARB
   GL_TEXTURE27_ARB
   GL_TEXTURE28_ARB
   GL_TEXTURE29_ARB
   GL_TEXTURE30_ARB
   GL_TEXTURE31_ARB
   GL_ACTIVE_TEXTURE_ARB
   GL_CLIENT_ACTIVE_TEXTURE_ARB
   GL_MAX_TEXTURE_UNITS_ARB
   GL_TRANSPOSE_MODELVIEW_MATRIX_ARB
   GL_TRANSPOSE_PROJECTION_MATRIX_ARB
   GL_TRANSPOSE_TEXTURE_MATRIX_ARB
   GL_TRANSPOSE_COLOR_MATRIX_ARB
   GL_MULTISAMPLE_ARB
   GL_SAMPLE_ALPHA_TO_COVERAGE_ARB
   GL_SAMPLE_ALPHA_TO_ONE_ARB
   GL_SAMPLE_COVERAGE_ARB
   GL_SAMPLE_BUFFERS_ARB
   GL_SAMPLES_ARB
   GL_SAMPLE_COVERAGE_VALUE_ARB
   GL_SAMPLE_COVERAGE_INVERT_ARB
   GL_MULTISAMPLE_BIT_ARB
   GL_NORMAL_MAP_ARB
   GL_REFLECTION_MAP_ARB
   GL_TEXTURE_CUBE_MAP_ARB
   GL_TEXTURE_BINDING_CUBE_MAP_ARB
   GL_TEXTURE_CUBE_MAP_POSITIVE_X_ARB
   GL_TEXTURE_CUBE_MAP_NEGATIVE_X_ARB
   GL_TEXTURE_CUBE_MAP_POSITIVE_Y_ARB
   GL_TEXTURE_CUBE_MAP_NEGATIVE_Y_ARB
   GL_TEXTURE_CUBE_MAP_POSITIVE_Z_ARB
   GL_TEXTURE_CUBE_MAP_NEGATIVE_Z_ARB
   GL_PROXY_TEXTURE_CUBE_MAP_ARB
   GL_MAX_CUBE_MAP_TEXTURE_SIZE_ARB
   GL_COMPRESSED_ALPHA_ARB
   GL_COMPRESSED_LUMINANCE_ARB
   GL_COMPRESSED_LUMINANCE_ALPHA_ARB
   GL_COMPRESSED_INTENSITY_ARB
   GL_COMPRESSED_RGB_ARB
   GL_COMPRESSED_RGBA_ARB
   GL_TEXTURE_COMPRESSION_HINT_ARB
   GL_TEXTURE_COMPRESSED_IMAGE_SIZE_ARB
   GL_TEXTURE_COMPRESSED_ARB
   GL_NUM_COMPRESSED_TEXTURE_FORMATS_ARB
   GL_COMPRESSED_TEXTURE_FORMATS_ARB
   GL_CLAMP_TO_BORDER_ARB
   GL_POINT_SIZE_MIN_ARB
   GL_POINT_SIZE_MAX_ARB
   GL_POINT_FADE_THRESHOLD_SIZE_ARB
   GL_POINT_DISTANCE_ATTENUATION_ARB
   GL_MAX_VERTEX_UNITS_ARB
   GL_ACTIVE_VERTEX_UNITS_ARB
   GL_WEIGHT_SUM_UNITY_ARB
   GL_VERTEX_BLEND_ARB
   GL_CURRENT_WEIGHT_ARB
   GL_WEIGHT_ARRAY_TYPE_ARB
   GL_WEIGHT_ARRAY_STRIDE_ARB
   GL_WEIGHT_ARRAY_SIZE_ARB
   GL_WEIGHT_ARRAY_POINTER_ARB
   GL_WEIGHT_ARRAY_ARB
   GL_MODELVIEW0_ARB
   GL_MODELVIEW1_ARB
   GL_MODELVIEW2_ARB
   GL_MODELVIEW3_ARB
   GL_MODELVIEW4_ARB
   GL_MODELVIEW5_ARB
   GL_MODELVIEW6_ARB
   GL_MODELVIEW7_ARB
   GL_MODELVIEW8_ARB
   GL_MODELVIEW9_ARB
   GL_MODELVIEW10_ARB
   GL_MODELVIEW11_ARB
   GL_MODELVIEW12_ARB
   GL_MODELVIEW13_ARB
   GL_MODELVIEW14_ARB
   GL_MODELVIEW15_ARB
   GL_MODELVIEW16_ARB
   GL_MODELVIEW17_ARB
   GL_MODELVIEW18_ARB
   GL_MODELVIEW19_ARB
   GL_MODELVIEW20_ARB
   GL_MODELVIEW21_ARB
   GL_MODELVIEW22_ARB
   GL_MODELVIEW23_ARB
   GL_MODELVIEW24_ARB
   GL_MODELVIEW25_ARB
   GL_MODELVIEW26_ARB
   GL_MODELVIEW27_ARB
   GL_MODELVIEW28_ARB
   GL_MODELVIEW29_ARB
   GL_MODELVIEW30_ARB
   GL_MODELVIEW31_ARB
   GL_MATRIX_PALETTE_ARB
   GL_MAX_MATRIX_PALETTE_STACK_DEPTH_ARB
   GL_MAX_PALETTE_MATRICES_ARB
   GL_CURRENT_PALETTE_MATRIX_ARB
   GL_MATRIX_INDEX_ARRAY_ARB
   GL_CURRENT_MATRIX_INDEX_ARB
   GL_MATRIX_INDEX_ARRAY_SIZE_ARB
   GL_MATRIX_INDEX_ARRAY_TYPE_ARB
   GL_MATRIX_INDEX_ARRAY_STRIDE_ARB
   GL_MATRIX_INDEX_ARRAY_POINTER_ARB
   GL_COMBINE_ARB
   GL_COMBINE_RGB_ARB
   GL_COMBINE_ALPHA_ARB
   GL_SOURCE0_RGB_ARB
   GL_SOURCE1_RGB_ARB
   GL_SOURCE2_RGB_ARB
   GL_SOURCE0_ALPHA_ARB
   GL_SOURCE1_ALPHA_ARB
   GL_SOURCE2_ALPHA_ARB
   GL_OPERAND0_RGB_ARB
   GL_OPERAND1_RGB_ARB
   GL_OPERAND2_RGB_ARB
   GL_OPERAND0_ALPHA_ARB
   GL_OPERAND1_ALPHA_ARB
   GL_OPERAND2_ALPHA_ARB
   GL_RGB_SCALE_ARB
   GL_ADD_SIGNED_ARB
   GL_INTERPOLATE_ARB
   GL_SUBTRACT_ARB
   GL_CONSTANT_ARB
   GL_PRIMARY_COLOR_ARB
   GL_PREVIOUS_ARB
   GL_DOT3_RGB_ARB
   GL_DOT3_RGBA_ARB
   GL_MIRRORED_REPEAT_ARB
   GL_DEPTH_COMPONENT16_ARB
   GL_DEPTH_COMPONENT24_ARB
   GL_DEPTH_COMPONENT32_ARB
   GL_TEXTURE_DEPTH_SIZE_ARB
   GL_DEPTH_TEXTURE_MODE_ARB
   GL_TEXTURE_COMPARE_MODE_ARB
   GL_TEXTURE_COMPARE_FUNC_ARB
   GL_COMPARE_R_TO_TEXTURE_ARB
   GL_TEXTURE_COMPARE_FAIL_VALUE_ARB
   GL_COLOR_SUM_ARB
   GL_VERTEX_PROGRAM_ARB
   GL_VERTEX_ATTRIB_ARRAY_ENABLED_ARB
   GL_VERTEX_ATTRIB_ARRAY_SIZE_ARB
   GL_VERTEX_ATTRIB_ARRAY_STRIDE_ARB
   GL_VERTEX_ATTRIB_ARRAY_TYPE_ARB
   GL_CURRENT_VERTEX_ATTRIB_ARB
   GL_PROGRAM_LENGTH_ARB
   GL_PROGRAM_STRING_ARB
   GL_MAX_PROGRAM_MATRIX_STACK_DEPTH_ARB
   GL_MAX_PROGRAM_MATRICES_ARB
   GL_CURRENT_MATRIX_STACK_DEPTH_ARB
   GL_CURRENT_MATRIX_ARB
   GL_VERTEX_PROGRAM_POINT_SIZE_ARB
   GL_VERTEX_PROGRAM_TWO_SIDE_ARB
   GL_VERTEX_ATTRIB_ARRAY_POINTER_ARB
   GL_PROGRAM_ERROR_POSITION_ARB
   GL_PROGRAM_BINDING_ARB
   GL_MAX_VERTEX_ATTRIBS_ARB
   GL_VERTEX_ATTRIB_ARRAY_NORMALIZED_ARB
   GL_PROGRAM_ERROR_STRING_ARB
   GL_PROGRAM_FORMAT_ASCII_ARB
   GL_PROGRAM_FORMAT_ARB
   GL_PROGRAM_INSTRUCTIONS_ARB
   GL_MAX_PROGRAM_INSTRUCTIONS_ARB
   GL_PROGRAM_NATIVE_INSTRUCTIONS_ARB
   GL_MAX_PROGRAM_NATIVE_INSTRUCTIONS_ARB
   GL_PROGRAM_TEMPORARIES_ARB
   GL_MAX_PROGRAM_TEMPORARIES_ARB
   GL_PROGRAM_NATIVE_TEMPORARIES_ARB
   GL_MAX_PROGRAM_NATIVE_TEMPORARIES_ARB
   GL_PROGRAM_PARAMETERS_ARB
   GL_MAX_PROGRAM_PARAMETERS_ARB
   GL_PROGRAM_NATIVE_PARAMETERS_ARB
   GL_MAX_PROGRAM_NATIVE_PARAMETERS_ARB
   GL_PROGRAM_ATTRIBS_ARB
   GL_MAX_PROGRAM_ATTRIBS_ARB
   GL_PROGRAM_NATIVE_ATTRIBS_ARB
   GL_MAX_PROGRAM_NATIVE_ATTRIBS_ARB
   GL_PROGRAM_ADDRESS_REGISTERS_ARB
   GL_MAX_PROGRAM_ADDRESS_REGISTERS_ARB
   GL_PROGRAM_NATIVE_ADDRESS_REGISTERS_ARB
   GL_MAX_PROGRAM_NATIVE_ADDRESS_REGISTERS_ARB
   GL_MAX_PROGRAM_LOCAL_PARAMETERS_ARB
   GL_MAX_PROGRAM_ENV_PARAMETERS_ARB
   GL_PROGRAM_UNDER_NATIVE_LIMITS_ARB
   GL_TRANSPOSE_CURRENT_MATRIX_ARB
   GL_MATRIX0_ARB
   GL_MATRIX1_ARB
   GL_MATRIX2_ARB
   GL_MATRIX3_ARB
   GL_MATRIX4_ARB
   GL_MATRIX5_ARB
   GL_MATRIX6_ARB
   GL_MATRIX7_ARB
   GL_MATRIX8_ARB
   GL_MATRIX9_ARB
   GL_MATRIX10_ARB
   GL_MATRIX11_ARB
   GL_MATRIX12_ARB
   GL_MATRIX13_ARB
   GL_MATRIX14_ARB
   GL_MATRIX15_ARB
   GL_MATRIX16_ARB
   GL_MATRIX17_ARB
   GL_MATRIX18_ARB
   GL_MATRIX19_ARB
   GL_MATRIX20_ARB
   GL_MATRIX21_ARB
   GL_MATRIX22_ARB
   GL_MATRIX23_ARB
   GL_MATRIX24_ARB
   GL_MATRIX25_ARB
   GL_MATRIX26_ARB
   GL_MATRIX27_ARB
   GL_MATRIX28_ARB
   GL_MATRIX29_ARB
   GL_MATRIX30_ARB
   GL_MATRIX31_ARB
   GL_FRAGMENT_PROGRAM_ARB
   GL_PROGRAM_ALU_INSTRUCTIONS_ARB
   GL_PROGRAM_TEX_INSTRUCTIONS_ARB
   GL_PROGRAM_TEX_INDIRECTIONS_ARB
   GL_PROGRAM_NATIVE_ALU_INSTRUCTIONS_ARB
   GL_PROGRAM_NATIVE_TEX_INSTRUCTIONS_ARB
   GL_PROGRAM_NATIVE_TEX_INDIRECTIONS_ARB
   GL_MAX_PROGRAM_ALU_INSTRUCTIONS_ARB
   GL_MAX_PROGRAM_TEX_INSTRUCTIONS_ARB
   GL_MAX_PROGRAM_TEX_INDIRECTIONS_ARB
   GL_MAX_PROGRAM_NATIVE_ALU_INSTRUCTIONS_ARB
   GL_MAX_PROGRAM_NATIVE_TEX_INSTRUCTIONS_ARB
   GL_MAX_PROGRAM_NATIVE_TEX_INDIRECTIONS_ARB
   GL_MAX_TEXTURE_COORDS_ARB
   GL_MAX_TEXTURE_IMAGE_UNITS_ARB
   GL_BUFFER_SIZE_ARB
   GL_BUFFER_USAGE_ARB
   GL_ARRAY_BUFFER_ARB
   GL_ELEMENT_ARRAY_BUFFER_ARB
   GL_ARRAY_BUFFER_BINDING_ARB
   GL_ELEMENT_ARRAY_BUFFER_BINDING_ARB
   GL_VERTEX_ARRAY_BUFFER_BINDING_ARB
   GL_NORMAL_ARRAY_BUFFER_BINDING_ARB
   GL_COLOR_ARRAY_BUFFER_BINDING_ARB
   GL_INDEX_ARRAY_BUFFER_BINDING_ARB
   GL_TEXTURE_COORD_ARRAY_BUFFER_BINDING_ARB
   GL_EDGE_FLAG_ARRAY_BUFFER_BINDING_ARB
   GL_SECONDARY_COLOR_ARRAY_BUFFER_BINDING_ARB
   GL_FOG_COORDINATE_ARRAY_BUFFER_BINDING_ARB
   GL_WEIGHT_ARRAY_BUFFER_BINDING_ARB
   GL_VERTEX_ATTRIB_ARRAY_BUFFER_BINDING_ARB
   GL_READ_ONLY_ARB
   GL_WRITE_ONLY_ARB
   GL_READ_WRITE_ARB
   GL_BUFFER_ACCESS_ARB
   GL_BUFFER_MAPPED_ARB
   GL_BUFFER_MAP_POINTER_ARB
   GL_STREAM_DRAW_ARB
   GL_STREAM_READ_ARB
   GL_STREAM_COPY_ARB
   GL_STATIC_DRAW_ARB
   GL_STATIC_READ_ARB
   GL_STATIC_COPY_ARB
   GL_DYNAMIC_DRAW_ARB
   GL_DYNAMIC_READ_ARB
   GL_DYNAMIC_COPY_ARB
   GL_QUERY_COUNTER_BITS_ARB
   GL_CURRENT_QUERY_ARB
   GL_QUERY_RESULT_ARB
   GL_QUERY_RESULT_AVAILABLE_ARB
   GL_SAMPLES_PASSED_ARB
   GL_PROGRAM_OBJECT_ARB
   GL_SHADER_OBJECT_ARB
   GL_OBJECT_TYPE_ARB
   GL_OBJECT_SUBTYPE_ARB
   GL_FLOAT_VEC2_ARB
   GL_FLOAT_VEC3_ARB
   GL_FLOAT_VEC4_ARB
   GL_INT_VEC2_ARB
   GL_INT_VEC3_ARB
   GL_INT_VEC4_ARB
   GL_BOOL_ARB
   GL_BOOL_VEC2_ARB
   GL_BOOL_VEC3_ARB
   GL_BOOL_VEC4_ARB
   GL_FLOAT_MAT2_ARB
   GL_FLOAT_MAT3_ARB
   GL_FLOAT_MAT4_ARB
   GL_SAMPLER_1D_ARB
   GL_SAMPLER_2D_ARB
   GL_SAMPLER_3D_ARB
   GL_SAMPLER_CUBE_ARB
   GL_SAMPLER_1D_SHADOW_ARB
   GL_SAMPLER_2D_SHADOW_ARB
   GL_SAMPLER_2D_RECT_ARB
   GL_SAMPLER_2D_RECT_SHADOW_ARB
   GL_OBJECT_DELETE_STATUS_ARB
   GL_OBJECT_COMPILE_STATUS_ARB
   GL_OBJECT_LINK_STATUS_ARB
   GL_OBJECT_VALIDATE_STATUS_ARB
   GL_OBJECT_INFO_LOG_LENGTH_ARB
   GL_OBJECT_ATTACHED_OBJECTS_ARB
   GL_OBJECT_ACTIVE_UNIFORMS_ARB
   GL_OBJECT_ACTIVE_UNIFORM_MAX_LENGTH_ARB
   GL_OBJECT_SHADER_SOURCE_LENGTH_ARB
   GL_VERTEX_SHADER_ARB
   GL_MAX_VERTEX_UNIFORM_COMPONENTS_ARB
   GL_MAX_VARYING_FLOATS_ARB
   GL_MAX_VERTEX_TEXTURE_IMAGE_UNITS_ARB
   GL_MAX_COMBINED_TEXTURE_IMAGE_UNITS_ARB
   GL_OBJECT_ACTIVE_ATTRIBUTES_ARB
   GL_OBJECT_ACTIVE_ATTRIBUTE_MAX_LENGTH_ARB
   GL_FRAGMENT_SHADER_ARB
   GL_MAX_FRAGMENT_UNIFORM_COMPONENTS_ARB
   GL_FRAGMENT_SHADER_DERIVATIVE_HINT_ARB
   GL_SHADING_LANGUAGE_VERSION_ARB
   GL_POINT_SPRITE_ARB
   GL_COORD_REPLACE_ARB
   GL_MAX_DRAW_BUFFERS_ARB
   GL_DRAW_BUFFER0_ARB
   GL_DRAW_BUFFER1_ARB
   GL_DRAW_BUFFER2_ARB
   GL_DRAW_BUFFER3_ARB
   GL_DRAW_BUFFER4_ARB
   GL_DRAW_BUFFER5_ARB
   GL_DRAW_BUFFER6_ARB
   GL_DRAW_BUFFER7_ARB
   GL_DRAW_BUFFER8_ARB
   GL_DRAW_BUFFER9_ARB
   GL_DRAW_BUFFER10_ARB
   GL_DRAW_BUFFER11_ARB
   GL_DRAW_BUFFER12_ARB
   GL_DRAW_BUFFER13_ARB
   GL_DRAW_BUFFER14_ARB
   GL_DRAW_BUFFER15_ARB
   GL_TEXTURE_RECTANGLE_ARB
   GL_TEXTURE_BINDING_RECTANGLE_ARB
   GL_PROXY_TEXTURE_RECTANGLE_ARB
   GL_MAX_RECTANGLE_TEXTURE_SIZE_ARB
   GL_RGBA_FLOAT_MODE_ARB
   GL_CLAMP_VERTEX_COLOR_ARB
   GL_CLAMP_FRAGMENT_COLOR_ARB
   GL_CLAMP_READ_COLOR_ARB
   GL_FIXED_ONLY_ARB
   GL_HALF_FLOAT_ARB
   GL_TEXTURE_RED_TYPE_ARB
   GL_TEXTURE_GREEN_TYPE_ARB
   GL_TEXTURE_BLUE_TYPE_ARB
   GL_TEXTURE_ALPHA_TYPE_ARB
   GL_TEXTURE_LUMINANCE_TYPE_ARB
   GL_TEXTURE_INTENSITY_TYPE_ARB
   GL_TEXTURE_DEPTH_TYPE_ARB
   GL_UNSIGNED_NORMALIZED_ARB
   GL_RGBA32F_ARB
   GL_RGB32F_ARB
   GL_ALPHA32F_ARB
   GL_INTENSITY32F_ARB
   GL_LUMINANCE32F_ARB
   GL_LUMINANCE_ALPHA32F_ARB
   GL_RGBA16F_ARB
   GL_RGB16F_ARB
   GL_ALPHA16F_ARB
   GL_INTENSITY16F_ARB
   GL_LUMINANCE16F_ARB
   GL_LUMINANCE_ALPHA16F_ARB
   GL_PIXEL_PACK_BUFFER_ARB
   GL_PIXEL_UNPACK_BUFFER_ARB
   GL_PIXEL_PACK_BUFFER_BINDING_ARB
   GL_PIXEL_UNPACK_BUFFER_BINDING_ARB
   GL_RGB2_EXT
   GL_PROXY_TEXTURE_1D_EXT
   GL_PROXY_TEXTURE_2D_EXT
   GL_FILTER4_SGIS
   GL_TEXTURE_FILTER4_SIZE_SGIS
   GL_HISTOGRAM_EXT
   GL_PROXY_HISTOGRAM_EXT
   GL_HISTOGRAM_WIDTH_EXT
   GL_HISTOGRAM_FORMAT_EXT
   GL_HISTOGRAM_RED_SIZE_EXT
   GL_HISTOGRAM_GREEN_SIZE_EXT
   GL_HISTOGRAM_BLUE_SIZE_EXT
   GL_HISTOGRAM_ALPHA_SIZE_EXT
   GL_HISTOGRAM_LUMINANCE_SIZE_EXT
   GL_HISTOGRAM_SINK_EXT
   GL_MINMAX_EXT
   GL_MINMAX_FORMAT_EXT
   GL_MINMAX_SINK_EXT
   GL_CONVOLUTION_1D_EXT
   GL_CONVOLUTION_2D_EXT
   GL_SEPARABLE_2D_EXT
   GL_CONVOLUTION_BORDER_MODE_EXT
   GL_CONVOLUTION_FILTER_SCALE_EXT
   GL_CONVOLUTION_FILTER_BIAS_EXT
   GL_REDUCE_EXT
   GL_CONVOLUTION_FORMAT_EXT
   GL_CONVOLUTION_WIDTH_EXT
   GL_CONVOLUTION_HEIGHT_EXT
   GL_MAX_CONVOLUTION_WIDTH_EXT
   GL_MAX_CONVOLUTION_HEIGHT_EXT
   GL_POST_CONVOLUTION_RED_SCALE_EXT
   GL_POST_CONVOLUTION_GREEN_SCALE_EXT
   GL_POST_CONVOLUTION_BLUE_SCALE_EXT
   GL_POST_CONVOLUTION_ALPHA_SCALE_EXT
   GL_POST_CONVOLUTION_RED_BIAS_EXT
   GL_POST_CONVOLUTION_GREEN_BIAS_EXT
   GL_POST_CONVOLUTION_BLUE_BIAS_EXT
   GL_POST_CONVOLUTION_ALPHA_BIAS_EXT
   GL_COLOR_MATRIX_SGI
   GL_COLOR_MATRIX_STACK_DEPTH_SGI
   GL_MAX_COLOR_MATRIX_STACK_DEPTH_SGI
   GL_POST_COLOR_MATRIX_RED_SCALE_SGI
   GL_POST_COLOR_MATRIX_GREEN_SCALE_SGI
   GL_POST_COLOR_MATRIX_BLUE_SCALE_SGI
   GL_POST_COLOR_MATRIX_ALPHA_SCALE_SGI
   GL_POST_COLOR_MATRIX_RED_BIAS_SGI
   GL_POST_COLOR_MATRIX_GREEN_BIAS_SGI
   GL_POST_COLOR_MATRIX_BLUE_BIAS_SGI
   GL_POST_COLOR_MATRIX_ALPHA_BIAS_SGI
   GL_COLOR_TABLE_SGI
   GL_POST_CONVOLUTION_COLOR_TABLE_SGI
   GL_POST_COLOR_MATRIX_COLOR_TABLE_SGI
   GL_PROXY_COLOR_TABLE_SGI
   GL_PROXY_POST_CONVOLUTION_COLOR_TABLE_SGI
   GL_PROXY_POST_COLOR_MATRIX_COLOR_TABLE_SGI
   GL_COLOR_TABLE_SCALE_SGI
   GL_COLOR_TABLE_BIAS_SGI
   GL_COLOR_TABLE_FORMAT_SGI
   GL_COLOR_TABLE_WIDTH_SGI
   GL_COLOR_TABLE_RED_SIZE_SGI
   GL_COLOR_TABLE_GREEN_SIZE_SGI
   GL_COLOR_TABLE_BLUE_SIZE_SGI
   GL_COLOR_TABLE_ALPHA_SIZE_SGI
   GL_COLOR_TABLE_LUMINANCE_SIZE_SGI
   GL_COLOR_TABLE_INTENSITY_SIZE_SGI
   GL_PIXEL_TEXTURE_SGIS
   GL_PIXEL_FRAGMENT_RGB_SOURCE_SGIS
   GL_PIXEL_FRAGMENT_ALPHA_SOURCE_SGIS
   GL_PIXEL_GROUP_COLOR_SGIS
   GL_PIXEL_TEX_GEN_SGIX
   GL_PIXEL_TEX_GEN_MODE_SGIX
   GL_PACK_SKIP_VOLUMES_SGIS
   GL_PACK_IMAGE_DEPTH_SGIS
   GL_UNPACK_SKIP_VOLUMES_SGIS
   GL_UNPACK_IMAGE_DEPTH_SGIS
   GL_TEXTURE_4D_SGIS
   GL_PROXY_TEXTURE_4D_SGIS
   GL_TEXTURE_4DSIZE_SGIS
   GL_TEXTURE_WRAP_Q_SGIS
   GL_MAX_4D_TEXTURE_SIZE_SGIS
   GL_TEXTURE_4D_BINDING_SGIS
   GL_TEXTURE_COLOR_TABLE_SGI
   GL_PROXY_TEXTURE_COLOR_TABLE_SGI
   GL_DETAIL_TEXTURE_2D_SGIS
   GL_DETAIL_TEXTURE_2D_BINDING_SGIS
   GL_LINEAR_DETAIL_SGIS
   GL_LINEAR_DETAIL_ALPHA_SGIS
   GL_LINEAR_DETAIL_COLOR_SGIS
   GL_DETAIL_TEXTURE_LEVEL_SGIS
   GL_DETAIL_TEXTURE_MODE_SGIS
   GL_DETAIL_TEXTURE_FUNC_POINTS_SGIS
   GL_LINEAR_SHARPEN_SGIS
   GL_LINEAR_SHARPEN_ALPHA_SGIS
   GL_LINEAR_SHARPEN_COLOR_SGIS
   GL_SHARPEN_TEXTURE_FUNC_POINTS_SGIS
   GL_UNSIGNED_BYTE_3_3_2_EXT
   GL_UNSIGNED_SHORT_4_4_4_4_EXT
   GL_UNSIGNED_SHORT_5_5_5_1_EXT
   GL_UNSIGNED_INT_8_8_8_8_EXT
   GL_UNSIGNED_INT_10_10_10_2_EXT
   GL_TEXTURE_MIN_LOD_SGIS
   GL_TEXTURE_MAX_LOD_SGIS
   GL_TEXTURE_BASE_LEVEL_SGIS
   GL_TEXTURE_MAX_LEVEL_SGIS
   GL_MULTISAMPLE_SGIS
   GL_SAMPLE_ALPHA_TO_MASK_SGIS
   GL_SAMPLE_ALPHA_TO_ONE_SGIS
   GL_SAMPLE_MASK_SGIS
   GL_1PASS_SGIS
   GL_2PASS_0_SGIS
   GL_2PASS_1_SGIS
   GL_4PASS_0_SGIS
   GL_4PASS_1_SGIS
   GL_4PASS_2_SGIS
   GL_4PASS_3_SGIS
   GL_SAMPLE_BUFFERS_SGIS
   GL_SAMPLES_SGIS
   GL_SAMPLE_MASK_VALUE_SGIS
   GL_SAMPLE_MASK_INVERT_SGIS
   GL_SAMPLE_PATTERN_SGIS
   GL_RESCALE_NORMAL_EXT
   GL_GENERATE_MIPMAP_SGIS
   GL_GENERATE_MIPMAP_HINT_SGIS
   GL_LINEAR_CLIPMAP_LINEAR_SGIX
   GL_TEXTURE_CLIPMAP_CENTER_SGIX
   GL_TEXTURE_CLIPMAP_FRAME_SGIX
   GL_TEXTURE_CLIPMAP_OFFSET_SGIX
   GL_TEXTURE_CLIPMAP_VIRTUAL_DEPTH_SGIX
   GL_TEXTURE_CLIPMAP_LOD_OFFSET_SGIX
   GL_TEXTURE_CLIPMAP_DEPTH_SGIX
   GL_MAX_CLIPMAP_DEPTH_SGIX
   GL_MAX_CLIPMAP_VIRTUAL_DEPTH_SGIX
   GL_NEAREST_CLIPMAP_NEAREST_SGIX
   GL_NEAREST_CLIPMAP_LINEAR_SGIX
   GL_LINEAR_CLIPMAP_NEAREST_SGIX
   GL_TEXTURE_COMPARE_SGIX
   GL_TEXTURE_COMPARE_OPERATOR_SGIX
   GL_TEXTURE_LEQUAL_R_SGIX
   GL_TEXTURE_GEQUAL_R_SGIX
   GL_CLAMP_TO_EDGE_SGIS
   GL_CLAMP_TO_BORDER_SGIS
   GL_INTERLACE_SGIX
   GL_PIXEL_TILE_BEST_ALIGNMENT_SGIX
   GL_PIXEL_TILE_CACHE_INCREMENT_SGIX
   GL_PIXEL_TILE_WIDTH_SGIX
   GL_PIXEL_TILE_HEIGHT_SGIX
   GL_PIXEL_TILE_GRID_WIDTH_SGIX
   GL_PIXEL_TILE_GRID_HEIGHT_SGIX
   GL_PIXEL_TILE_GRID_DEPTH_SGIX
   GL_PIXEL_TILE_CACHE_SIZE_SGIX
   GL_DUAL_ALPHA4_SGIS
   GL_DUAL_ALPHA8_SGIS
   GL_DUAL_ALPHA12_SGIS
   GL_DUAL_ALPHA16_SGIS
   GL_DUAL_LUMINANCE4_SGIS
   GL_DUAL_LUMINANCE8_SGIS
   GL_DUAL_LUMINANCE12_SGIS
   GL_DUAL_LUMINANCE16_SGIS
   GL_DUAL_INTENSITY4_SGIS
   GL_DUAL_INTENSITY8_SGIS
   GL_DUAL_INTENSITY12_SGIS
   GL_DUAL_INTENSITY16_SGIS
   GL_DUAL_LUMINANCE_ALPHA4_SGIS
   GL_DUAL_LUMINANCE_ALPHA8_SGIS
   GL_QUAD_ALPHA4_SGIS
   GL_QUAD_ALPHA8_SGIS
   GL_QUAD_LUMINANCE4_SGIS
   GL_QUAD_LUMINANCE8_SGIS
   GL_QUAD_INTENSITY4_SGIS
   GL_QUAD_INTENSITY8_SGIS
   GL_DUAL_TEXTURE_SELECT_SGIS
   GL_QUAD_TEXTURE_SELECT_SGIS
   GL_SPRITE_SGIX
   GL_SPRITE_MODE_SGIX
   GL_SPRITE_AXIS_SGIX
   GL_SPRITE_TRANSLATION_SGIX
   GL_SPRITE_AXIAL_SGIX
   GL_SPRITE_OBJECT_ALIGNED_SGIX
   GL_SPRITE_EYE_ALIGNED_SGIX
   GL_TEXTURE_MULTI_BUFFER_HINT_SGIX
   GL_POINT_SIZE_MIN_SGIS
   GL_POINT_SIZE_MAX_SGIS
   GL_POINT_FADE_THRESHOLD_SIZE_SGIS
   GL_DISTANCE_ATTENUATION_SGIS
   GL_INSTRUMENT_BUFFER_POINTER_SGIX
   GL_INSTRUMENT_MEASUREMENTS_SGIX
   GL_POST_TEXTURE_FILTER_BIAS_SGIX
   GL_POST_TEXTURE_FILTER_SCALE_SGIX
   GL_POST_TEXTURE_FILTER_BIAS_RANGE_SGIX
   GL_POST_TEXTURE_FILTER_SCALE_RANGE_SGIX
   GL_FRAMEZOOM_SGIX
   GL_FRAMEZOOM_FACTOR_SGIX
   GL_MAX_FRAMEZOOM_FACTOR_SGIX
   GL_TEXTURE_DEFORMATION_BIT_SGIX
   GL_GEOMETRY_DEFORMATION_BIT_SGIX
   GL_GEOMETRY_DEFORMATION_SGIX
   GL_TEXTURE_DEFORMATION_SGIX
   GL_DEFORMATIONS_MASK_SGIX
   GL_MAX_DEFORMATION_ORDER_SGIX
   GL_REFERENCE_PLANE_SGIX
   GL_REFERENCE_PLANE_EQUATION_SGIX
   GL_DEPTH_COMPONENT16_SGIX
   GL_DEPTH_COMPONENT24_SGIX
   GL_DEPTH_COMPONENT32_SGIX
   GL_FOG_FUNC_SGIS
   GL_FOG_FUNC_POINTS_SGIS
   GL_MAX_FOG_FUNC_POINTS_SGIS
   GL_FOG_OFFSET_SGIX
   GL_FOG_OFFSET_VALUE_SGIX
   GL_IMAGE_SCALE_X_HP
   GL_IMAGE_SCALE_Y_HP
   GL_IMAGE_TRANSLATE_X_HP
   GL_IMAGE_TRANSLATE_Y_HP
   GL_IMAGE_ROTATE_ANGLE_HP
   GL_IMAGE_ROTATE_ORIGIN_X_HP
   GL_IMAGE_ROTATE_ORIGIN_Y_HP
   GL_IMAGE_MAG_FILTER_HP
   GL_IMAGE_MIN_FILTER_HP
   GL_IMAGE_CUBIC_WEIGHT_HP
   GL_CUBIC_HP
   GL_AVERAGE_HP
   GL_IMAGE_TRANSFORM_2D_HP
   GL_POST_IMAGE_TRANSFORM_COLOR_TABLE_HP
   GL_PROXY_POST_IMAGE_TRANSFORM_COLOR_TABLE_HP
   GL_IGNORE_BORDER_HP
   GL_CONSTANT_BORDER_HP
   GL_REPLICATE_BORDER_HP
   GL_CONVOLUTION_BORDER_COLOR_HP
   GL_TEXTURE_ENV_BIAS_SGIX
   GL_VERTEX_DATA_HINT_PGI
   GL_VERTEX_CONSISTENT_HINT_PGI
   GL_MATERIAL_SIDE_HINT_PGI
   GL_MAX_VERTEX_HINT_PGI
   GL_COLOR3_BIT_PGI
   GL_COLOR4_BIT_PGI
   GL_EDGEFLAG_BIT_PGI
   GL_INDEX_BIT_PGI
   GL_MAT_AMBIENT_BIT_PGI
   GL_MAT_AMBIENT_AND_DIFFUSE_BIT_PGI
   GL_MAT_DIFFUSE_BIT_PGI
   GL_MAT_EMISSION_BIT_PGI
   GL_MAT_COLOR_INDEXES_BIT_PGI
   GL_MAT_SHININESS_BIT_PGI
   GL_MAT_SPECULAR_BIT_PGI
   GL_NORMAL_BIT_PGI
   GL_TEXCOORD1_BIT_PGI
   GL_TEXCOORD2_BIT_PGI
   GL_TEXCOORD3_BIT_PGI
   GL_TEXCOORD4_BIT_PGI
   GL_VERTEX23_BIT_PGI
   GL_VERTEX4_BIT_PGI
   GL_PREFER_DOUBLEBUFFER_HINT_PGI
   GL_CONSERVE_MEMORY_HINT_PGI
   GL_RECLAIM_MEMORY_HINT_PGI
   GL_NATIVE_GRAPHICS_HANDLE_PGI
   GL_NATIVE_GRAPHICS_BEGIN_HINT_PGI
   GL_NATIVE_GRAPHICS_END_HINT_PGI
   GL_ALWAYS_FAST_HINT_PGI
   GL_ALWAYS_SOFT_HINT_PGI
   GL_ALLOW_DRAW_OBJ_HINT_PGI
   GL_ALLOW_DRAW_WIN_HINT_PGI
   GL_ALLOW_DRAW_FRG_HINT_PGI
   GL_ALLOW_DRAW_MEM_HINT_PGI
   GL_STRICT_DEPTHFUNC_HINT_PGI
   GL_STRICT_LIGHTING_HINT_PGI
   GL_STRICT_SCISSOR_HINT_PGI
   GL_FULL_STIPPLE_HINT_PGI
   GL_CLIP_NEAR_HINT_PGI
   GL_CLIP_FAR_HINT_PGI
   GL_WIDE_LINE_HINT_PGI
   GL_BACK_NORMALS_HINT_PGI
   GL_CLIP_VOLUME_CLIPPING_HINT_EXT
   GL_LIST_PRIORITY_SGIX
   GL_IR_INSTRUMENT1_SGIX
   GL_CALLIGRAPHIC_FRAGMENT_SGIX
   GL_TEXTURE_LOD_BIAS_S_SGIX
   GL_TEXTURE_LOD_BIAS_T_SGIX
   GL_TEXTURE_LOD_BIAS_R_SGIX
   GL_SHADOW_AMBIENT_SGIX
   GL_INDEX_MATERIAL_EXT
   GL_INDEX_MATERIAL_PARAMETER_EXT
   GL_INDEX_MATERIAL_FACE_EXT
   GL_INDEX_TEST_EXT
   GL_INDEX_TEST_FUNC_EXT
   GL_INDEX_TEST_REF_EXT
   GL_IUI_V2F_EXT
   GL_IUI_V3F_EXT
   GL_IUI_N3F_V2F_EXT
   GL_IUI_N3F_V3F_EXT
   GL_T2F_IUI_V2F_EXT
   GL_T2F_IUI_V3F_EXT
   GL_T2F_IUI_N3F_V2F_EXT
   GL_T2F_IUI_N3F_V3F_EXT
   GL_ARRAY_ELEMENT_LOCK_FIRST_EXT
   GL_ARRAY_ELEMENT_LOCK_COUNT_EXT
   GL_CULL_VERTEX_EXT
   GL_CULL_VERTEX_EYE_POSITION_EXT
   GL_CULL_VERTEX_OBJECT_POSITION_EXT
   GL_YCRCB_422_SGIX
   GL_YCRCB_444_SGIX
   GL_FRAGMENT_LIGHTING_SGIX
   GL_FRAGMENT_COLOR_MATERIAL_SGIX
   GL_FRAGMENT_COLOR_MATERIAL_FACE_SGIX
   GL_FRAGMENT_COLOR_MATERIAL_PARAMETER_SGIX
   GL_MAX_FRAGMENT_LIGHTS_SGIX
   GL_MAX_ACTIVE_LIGHTS_SGIX
   GL_CURRENT_RASTER_NORMAL_SGIX
   GL_LIGHT_ENV_MODE_SGIX
   GL_FRAGMENT_LIGHT_MODEL_LOCAL_VIEWER_SGIX
   GL_FRAGMENT_LIGHT_MODEL_TWO_SIDE_SGIX
   GL_FRAGMENT_LIGHT_MODEL_AMBIENT_SGIX
   GL_FRAGMENT_LIGHT_MODEL_NORMAL_INTERPOLATION_SGIX
   GL_FRAGMENT_LIGHT0_SGIX
   GL_FRAGMENT_LIGHT1_SGIX
   GL_FRAGMENT_LIGHT2_SGIX
   GL_FRAGMENT_LIGHT3_SGIX
   GL_FRAGMENT_LIGHT4_SGIX
   GL_FRAGMENT_LIGHT5_SGIX
   GL_FRAGMENT_LIGHT6_SGIX
   GL_FRAGMENT_LIGHT7_SGIX
   GL_RASTER_POSITION_UNCLIPPED_IBM
   GL_TEXTURE_LIGHTING_MODE_HP
   GL_TEXTURE_POST_SPECULAR_HP
   GL_TEXTURE_PRE_SPECULAR_HP
   GL_MAX_ELEMENTS_VERTICES_EXT
   GL_MAX_ELEMENTS_INDICES_EXT
   GL_PHONG_WIN
   GL_PHONG_HINT_WIN
   GL_FOG_SPECULAR_TEXTURE_WIN
   GL_FRAGMENT_MATERIAL_EXT
   GL_FRAGMENT_NORMAL_EXT
   GL_FRAGMENT_COLOR_EXT
   GL_ATTENUATION_EXT
   GL_SHADOW_ATTENUATION_EXT
   GL_TEXTURE_APPLICATION_MODE_EXT
   GL_TEXTURE_LIGHT_EXT
   GL_TEXTURE_MATERIAL_FACE_EXT
   GL_TEXTURE_MATERIAL_PARAMETER_EXT
   GL_ALPHA_MIN_SGIX
   GL_ALPHA_MAX_SGIX
   GL_PIXEL_TEX_GEN_Q_CEILING_SGIX
   GL_PIXEL_TEX_GEN_Q_ROUND_SGIX
   GL_PIXEL_TEX_GEN_Q_FLOOR_SGIX
   GL_PIXEL_TEX_GEN_ALPHA_REPLACE_SGIX
   GL_PIXEL_TEX_GEN_ALPHA_NO_REPLACE_SGIX
   GL_PIXEL_TEX_GEN_ALPHA_LS_SGIX
   GL_PIXEL_TEX_GEN_ALPHA_MS_SGIX
   GL_BGR_EXT
   GL_BGRA_EXT
   GL_ASYNC_MARKER_SGIX
   GL_ASYNC_TEX_IMAGE_SGIX
   GL_ASYNC_DRAW_PIXELS_SGIX
   GL_ASYNC_READ_PIXELS_SGIX
   GL_MAX_ASYNC_TEX_IMAGE_SGIX
   GL_MAX_ASYNC_DRAW_PIXELS_SGIX
   GL_MAX_ASYNC_READ_PIXELS_SGIX
   GL_ASYNC_HISTOGRAM_SGIX
   GL_MAX_ASYNC_HISTOGRAM_SGIX
   GL_PARALLEL_ARRAYS_INTEL
   GL_VERTEX_ARRAY_PARALLEL_POINTERS_INTEL
   GL_NORMAL_ARRAY_PARALLEL_POINTERS_INTEL
   GL_COLOR_ARRAY_PARALLEL_POINTERS_INTEL
   GL_TEXTURE_COORD_ARRAY_PARALLEL_POINTERS_INTEL
   GL_OCCLUSION_TEST_HP
   GL_OCCLUSION_TEST_RESULT_HP
   GL_PIXEL_TRANSFORM_2D_EXT
   GL_PIXEL_MAG_FILTER_EXT
   GL_PIXEL_MIN_FILTER_EXT
   GL_PIXEL_CUBIC_WEIGHT_EXT
   GL_CUBIC_EXT
   GL_AVERAGE_EXT
   GL_PIXEL_TRANSFORM_2D_STACK_DEPTH_EXT
   GL_MAX_PIXEL_TRANSFORM_2D_STACK_DEPTH_EXT
   GL_PIXEL_TRANSFORM_2D_MATRIX_EXT
   GL_LIGHT_MODEL_COLOR_CONTROL_EXT
   GL_SINGLE_COLOR_EXT
   GL_SEPARATE_SPECULAR_COLOR_EXT
   GL_COLOR_SUM_EXT
   GL_CURRENT_SECONDARY_COLOR_EXT
   GL_SECONDARY_COLOR_ARRAY_SIZE_EXT
   GL_SECONDARY_COLOR_ARRAY_TYPE_EXT
   GL_SECONDARY_COLOR_ARRAY_STRIDE_EXT
   GL_SECONDARY_COLOR_ARRAY_POINTER_EXT
   GL_SECONDARY_COLOR_ARRAY_EXT
   GL_PERTURB_EXT
   GL_TEXTURE_NORMAL_EXT
   GL_FOG_COORDINATE_SOURCE_EXT
   GL_FOG_COORDINATE_EXT
   GL_FRAGMENT_DEPTH_EXT
   GL_CURRENT_FOG_COORDINATE_EXT
   GL_FOG_COORDINATE_ARRAY_TYPE_EXT
   GL_FOG_COORDINATE_ARRAY_STRIDE_EXT
   GL_FOG_COORDINATE_ARRAY_POINTER_EXT
   GL_FOG_COORDINATE_ARRAY_EXT
   GL_SCREEN_COORDINATES_REND
   GL_INVERTED_SCREEN_W_REND
   GL_TANGENT_ARRAY_EXT
   GL_BINORMAL_ARRAY_EXT
   GL_CURRENT_TANGENT_EXT
   GL_CURRENT_BINORMAL_EXT
   GL_TANGENT_ARRAY_TYPE_EXT
   GL_TANGENT_ARRAY_STRIDE_EXT
   GL_BINORMAL_ARRAY_TYPE_EXT
   GL_BINORMAL_ARRAY_STRIDE_EXT
   GL_TANGENT_ARRAY_POINTER_EXT
   GL_BINORMAL_ARRAY_POINTER_EXT
   GL_MAP1_TANGENT_EXT
   GL_MAP2_TANGENT_EXT
   GL_MAP1_BINORMAL_EXT
   GL_MAP2_BINORMAL_EXT
   GL_COMBINE_EXT
   GL_COMBINE_RGB_EXT
   GL_COMBINE_ALPHA_EXT
   GL_RGB_SCALE_EXT
   GL_ADD_SIGNED_EXT
   GL_INTERPOLATE_EXT
   GL_CONSTANT_EXT
   GL_PRIMARY_COLOR_EXT
   GL_PREVIOUS_EXT
   GL_SOURCE0_RGB_EXT
   GL_SOURCE1_RGB_EXT
   GL_SOURCE2_RGB_EXT
   GL_SOURCE0_ALPHA_EXT
   GL_SOURCE1_ALPHA_EXT
   GL_SOURCE2_ALPHA_EXT
   GL_OPERAND0_RGB_EXT
   GL_OPERAND1_RGB_EXT
   GL_OPERAND2_RGB_EXT
   GL_OPERAND0_ALPHA_EXT
   GL_OPERAND1_ALPHA_EXT
   GL_OPERAND2_ALPHA_EXT
   GL_LIGHT_MODEL_SPECULAR_VECTOR_APPLE
   GL_TRANSFORM_HINT_APPLE
   GL_UNPACK_CONSTANT_DATA_SUNX
   GL_TEXTURE_CONSTANT_DATA_SUNX
   GL_GLOBAL_ALPHA_SUN
   GL_GLOBAL_ALPHA_FACTOR_SUN
   GL_RESTART_SUN
   GL_REPLACE_MIDDLE_SUN
   GL_REPLACE_OLDEST_SUN
   GL_TRIANGLE_LIST_SUN
   GL_REPLACEMENT_CODE_SUN
   GL_REPLACEMENT_CODE_ARRAY_SUN
   GL_REPLACEMENT_CODE_ARRAY_TYPE_SUN
   GL_REPLACEMENT_CODE_ARRAY_STRIDE_SUN
   GL_REPLACEMENT_CODE_ARRAY_POINTER_SUN
   GL_R1UI_V3F_SUN
   GL_R1UI_C4UB_V3F_SUN
   GL_R1UI_C3F_V3F_SUN
   GL_R1UI_N3F_V3F_SUN
   GL_R1UI_C4F_N3F_V3F_SUN
   GL_R1UI_T2F_V3F_SUN
   GL_R1UI_T2F_N3F_V3F_SUN
   GL_R1UI_T2F_C4F_N3F_V3F_SUN
   GL_BLEND_DST_RGB_EXT
   GL_BLEND_SRC_RGB_EXT
   GL_BLEND_DST_ALPHA_EXT
   GL_BLEND_SRC_ALPHA_EXT
   GL_RED_MIN_CLAMP_INGR
   GL_GREEN_MIN_CLAMP_INGR
   GL_BLUE_MIN_CLAMP_INGR
   GL_ALPHA_MIN_CLAMP_INGR
   GL_RED_MAX_CLAMP_INGR
   GL_GREEN_MAX_CLAMP_INGR
   GL_BLUE_MAX_CLAMP_INGR
   GL_ALPHA_MAX_CLAMP_INGR
   GL_INTERLACE_READ_INGR
   GL_INCR_WRAP_EXT
   GL_DECR_WRAP_EXT
   GL_422_EXT
   GL_422_REV_EXT
   GL_422_AVERAGE_EXT
   GL_422_REV_AVERAGE_EXT
   GL_NORMAL_MAP_NV
   GL_REFLECTION_MAP_NV
   GL_NORMAL_MAP_EXT
   GL_REFLECTION_MAP_EXT
   GL_TEXTURE_CUBE_MAP_EXT
   GL_TEXTURE_BINDING_CUBE_MAP_EXT
   GL_TEXTURE_CUBE_MAP_POSITIVE_X_EXT
   GL_TEXTURE_CUBE_MAP_NEGATIVE_X_EXT
   GL_TEXTURE_CUBE_MAP_POSITIVE_Y_EXT
   GL_TEXTURE_CUBE_MAP_NEGATIVE_Y_EXT
   GL_TEXTURE_CUBE_MAP_POSITIVE_Z_EXT
   GL_TEXTURE_CUBE_MAP_NEGATIVE_Z_EXT
   GL_PROXY_TEXTURE_CUBE_MAP_EXT
   GL_MAX_CUBE_MAP_TEXTURE_SIZE_EXT
   GL_WRAP_BORDER_SUN
   GL_MAX_TEXTURE_LOD_BIAS_EXT
   GL_TEXTURE_FILTER_CONTROL_EXT
   GL_TEXTURE_LOD_BIAS_EXT
   GL_TEXTURE_MAX_ANISOTROPY_EXT
   GL_MAX_TEXTURE_MAX_ANISOTROPY_EXT
   GL_MODELVIEW0_STACK_DEPTH_EXT
   GL_MODELVIEW1_STACK_DEPTH_EXT
   GL_MODELVIEW0_MATRIX_EXT
   GL_MODELVIEW1_MATRIX_EXT
   GL_VERTEX_WEIGHTING_EXT
   GL_MODELVIEW0_EXT
   GL_MODELVIEW1_EXT
   GL_CURRENT_VERTEX_WEIGHT_EXT
   GL_VERTEX_WEIGHT_ARRAY_EXT
   GL_VERTEX_WEIGHT_ARRAY_SIZE_EXT
   GL_VERTEX_WEIGHT_ARRAY_TYPE_EXT
   GL_VERTEX_WEIGHT_ARRAY_STRIDE_EXT
   GL_VERTEX_WEIGHT_ARRAY_POINTER_EXT
   GL_MAX_SHININESS_NV
   GL_MAX_SPOT_EXPONENT_NV
   GL_VERTEX_ARRAY_RANGE_NV
   GL_VERTEX_ARRAY_RANGE_LENGTH_NV
   GL_VERTEX_ARRAY_RANGE_VALID_NV
   GL_MAX_VERTEX_ARRAY_RANGE_ELEMENT_NV
   GL_VERTEX_ARRAY_RANGE_POINTER_NV
   GL_REGISTER_COMBINERS_NV
   GL_VARIABLE_A_NV
   GL_VARIABLE_B_NV
   GL_VARIABLE_C_NV
   GL_VARIABLE_D_NV
   GL_VARIABLE_E_NV
   GL_VARIABLE_F_NV
   GL_VARIABLE_G_NV
   GL_CONSTANT_COLOR0_NV
   GL_CONSTANT_COLOR1_NV
   GL_PRIMARY_COLOR_NV
   GL_SECONDARY_COLOR_NV
   GL_SPARE0_NV
   GL_SPARE1_NV
   GL_DISCARD_NV
   GL_E_TIMES_F_NV
   GL_SPARE0_PLUS_SECONDARY_COLOR_NV
   GL_UNSIGNED_IDENTITY_NV
   GL_UNSIGNED_INVERT_NV
   GL_EXPAND_NORMAL_NV
   GL_EXPAND_NEGATE_NV
   GL_HALF_BIAS_NORMAL_NV
   GL_HALF_BIAS_NEGATE_NV
   GL_SIGNED_IDENTITY_NV
   GL_SIGNED_NEGATE_NV
   GL_SCALE_BY_TWO_NV
   GL_SCALE_BY_FOUR_NV
   GL_SCALE_BY_ONE_HALF_NV
   GL_BIAS_BY_NEGATIVE_ONE_HALF_NV
   GL_COMBINER_INPUT_NV
   GL_COMBINER_MAPPING_NV
   GL_COMBINER_COMPONENT_USAGE_NV
   GL_COMBINER_AB_DOT_PRODUCT_NV
   GL_COMBINER_CD_DOT_PRODUCT_NV
   GL_COMBINER_MUX_SUM_NV
   GL_COMBINER_SCALE_NV
   GL_COMBINER_BIAS_NV
   GL_COMBINER_AB_OUTPUT_NV
   GL_COMBINER_CD_OUTPUT_NV
   GL_COMBINER_SUM_OUTPUT_NV
   GL_MAX_GENERAL_COMBINERS_NV
   GL_NUM_GENERAL_COMBINERS_NV
   GL_COLOR_SUM_CLAMP_NV
   GL_COMBINER0_NV
   GL_COMBINER1_NV
   GL_COMBINER2_NV
   GL_COMBINER3_NV
   GL_COMBINER4_NV
   GL_COMBINER5_NV
   GL_COMBINER6_NV
   GL_COMBINER7_NV
   GL_FOG_DISTANCE_MODE_NV
   GL_EYE_RADIAL_NV
   GL_EYE_PLANE_ABSOLUTE_NV
   GL_EMBOSS_LIGHT_NV
   GL_EMBOSS_CONSTANT_NV
   GL_EMBOSS_MAP_NV
   GL_COMBINE4_NV
   GL_SOURCE3_RGB_NV
   GL_SOURCE3_ALPHA_NV
   GL_OPERAND3_RGB_NV
   GL_OPERAND3_ALPHA_NV
   GL_COMPRESSED_RGB_S3TC_DXT1_EXT
   GL_COMPRESSED_RGBA_S3TC_DXT1_EXT
   GL_COMPRESSED_RGBA_S3TC_DXT3_EXT
   GL_COMPRESSED_RGBA_S3TC_DXT5_EXT
   GL_CULL_VERTEX_IBM
   GL_VERTEX_ARRAY_LIST_IBM
   GL_NORMAL_ARRAY_LIST_IBM
   GL_COLOR_ARRAY_LIST_IBM
   GL_INDEX_ARRAY_LIST_IBM
   GL_TEXTURE_COORD_ARRAY_LIST_IBM
   GL_EDGE_FLAG_ARRAY_LIST_IBM
   GL_FOG_COORDINATE_ARRAY_LIST_IBM
   GL_SECONDARY_COLOR_ARRAY_LIST_IBM
   GL_VERTEX_ARRAY_LIST_STRIDE_IBM
   GL_NORMAL_ARRAY_LIST_STRIDE_IBM
   GL_COLOR_ARRAY_LIST_STRIDE_IBM
   GL_INDEX_ARRAY_LIST_STRIDE_IBM
   GL_TEXTURE_COORD_ARRAY_LIST_STRIDE_IBM
   GL_EDGE_FLAG_ARRAY_LIST_STRIDE_IBM
   GL_FOG_COORDINATE_ARRAY_LIST_STRIDE_IBM
   GL_SECONDARY_COLOR_ARRAY_LIST_STRIDE_IBM
   GL_PACK_SUBSAMPLE_RATE_SGIX
   GL_UNPACK_SUBSAMPLE_RATE_SGIX
   GL_PIXEL_SUBSAMPLE_4444_SGIX
   GL_PIXEL_SUBSAMPLE_2424_SGIX
   GL_PIXEL_SUBSAMPLE_4242_SGIX
   GL_YCRCB_SGIX
   GL_YCRCBA_SGIX
   GL_DEPTH_PASS_INSTRUMENT_SGIX
   GL_DEPTH_PASS_INSTRUMENT_COUNTERS_SGIX
   GL_DEPTH_PASS_INSTRUMENT_MAX_SGIX
   GL_COMPRESSED_RGB_FXT1_3DFX
   GL_COMPRESSED_RGBA_FXT1_3DFX
   GL_MULTISAMPLE_3DFX
   GL_SAMPLE_BUFFERS_3DFX
   GL_SAMPLES_3DFX
   GL_MULTISAMPLE_BIT_3DFX
   GL_MULTISAMPLE_EXT
   GL_SAMPLE_ALPHA_TO_MASK_EXT
   GL_SAMPLE_ALPHA_TO_ONE_EXT
   GL_SAMPLE_MASK_EXT
   GL_1PASS_EXT
   GL_2PASS_0_EXT
   GL_2PASS_1_EXT
   GL_4PASS_0_EXT
   GL_4PASS_1_EXT
   GL_4PASS_2_EXT
   GL_4PASS_3_EXT
   GL_SAMPLE_BUFFERS_EXT
   GL_SAMPLES_EXT
   GL_SAMPLE_MASK_VALUE_EXT
   GL_SAMPLE_MASK_INVERT_EXT
   GL_SAMPLE_PATTERN_EXT
   GL_MULTISAMPLE_BIT_EXT
   GL_VERTEX_PRECLIP_SGIX
   GL_VERTEX_PRECLIP_HINT_SGIX
   GL_CONVOLUTION_HINT_SGIX
   GL_PACK_RESAMPLE_SGIX
   GL_UNPACK_RESAMPLE_SGIX
   GL_RESAMPLE_REPLICATE_SGIX
   GL_RESAMPLE_ZERO_FILL_SGIX
   GL_RESAMPLE_DECIMATE_SGIX
   GL_EYE_DISTANCE_TO_POINT_SGIS
   GL_OBJECT_DISTANCE_TO_POINT_SGIS
   GL_EYE_DISTANCE_TO_LINE_SGIS
   GL_OBJECT_DISTANCE_TO_LINE_SGIS
   GL_EYE_POINT_SGIS
   GL_OBJECT_POINT_SGIS
   GL_EYE_LINE_SGIS
   GL_OBJECT_LINE_SGIS
   GL_TEXTURE_COLOR_WRITEMASK_SGIS
   GL_DOT3_RGB_EXT
   GL_DOT3_RGBA_EXT
   GL_MIRROR_CLAMP_ATI
   GL_MIRROR_CLAMP_TO_EDGE_ATI
   GL_ALL_COMPLETED_NV
   GL_FENCE_STATUS_NV
   GL_FENCE_CONDITION_NV
   GL_MIRRORED_REPEAT_IBM
   GL_EVAL_2D_NV
   GL_EVAL_TRIANGULAR_2D_NV
   GL_MAP_TESSELLATION_NV
   GL_MAP_ATTRIB_U_ORDER_NV
   GL_MAP_ATTRIB_V_ORDER_NV
   GL_EVAL_FRACTIONAL_TESSELLATION_NV
   GL_EVAL_VERTEX_ATTRIB0_NV
   GL_EVAL_VERTEX_ATTRIB1_NV
   GL_EVAL_VERTEX_ATTRIB2_NV
   GL_EVAL_VERTEX_ATTRIB3_NV
   GL_EVAL_VERTEX_ATTRIB4_NV
   GL_EVAL_VERTEX_ATTRIB5_NV
   GL_EVAL_VERTEX_ATTRIB6_NV
   GL_EVAL_VERTEX_ATTRIB7_NV
   GL_EVAL_VERTEX_ATTRIB8_NV
   GL_EVAL_VERTEX_ATTRIB9_NV
   GL_EVAL_VERTEX_ATTRIB10_NV
   GL_EVAL_VERTEX_ATTRIB11_NV
   GL_EVAL_VERTEX_ATTRIB12_NV
   GL_EVAL_VERTEX_ATTRIB13_NV
   GL_EVAL_VERTEX_ATTRIB14_NV
   GL_EVAL_VERTEX_ATTRIB15_NV
   GL_MAX_MAP_TESSELLATION_NV
   GL_MAX_RATIONAL_EVAL_ORDER_NV
   GL_DEPTH_STENCIL_NV
   GL_UNSIGNED_INT_24_8_NV
   GL_PER_STAGE_CONSTANTS_NV
   GL_TEXTURE_RECTANGLE_NV
   GL_TEXTURE_BINDING_RECTANGLE_NV
   GL_PROXY_TEXTURE_RECTANGLE_NV
   GL_MAX_RECTANGLE_TEXTURE_SIZE_NV
   GL_OFFSET_TEXTURE_RECTANGLE_NV
   GL_OFFSET_TEXTURE_RECTANGLE_SCALE_NV
   GL_DOT_PRODUCT_TEXTURE_RECTANGLE_NV
   GL_RGBA_UNSIGNED_DOT_PRODUCT_MAPPING_NV
   GL_UNSIGNED_INT_S8_S8_8_8_NV
   GL_UNSIGNED_INT_8_8_S8_S8_REV_NV
   GL_DSDT_MAG_INTENSITY_NV
   GL_SHADER_CONSISTENT_NV
   GL_TEXTURE_SHADER_NV
   GL_SHADER_OPERATION_NV
   GL_CULL_MODES_NV
   GL_OFFSET_TEXTURE_MATRIX_NV
   GL_OFFSET_TEXTURE_SCALE_NV
   GL_OFFSET_TEXTURE_BIAS_NV
   GL_OFFSET_TEXTURE_2D_MATRIX_NV
   GL_OFFSET_TEXTURE_2D_SCALE_NV
   GL_OFFSET_TEXTURE_2D_BIAS_NV
   GL_PREVIOUS_TEXTURE_INPUT_NV
   GL_CONST_EYE_NV
   GL_PASS_THROUGH_NV
   GL_CULL_FRAGMENT_NV
   GL_OFFSET_TEXTURE_2D_NV
   GL_DEPENDENT_AR_TEXTURE_2D_NV
   GL_DEPENDENT_GB_TEXTURE_2D_NV
   GL_DOT_PRODUCT_NV
   GL_DOT_PRODUCT_DEPTH_REPLACE_NV
   GL_DOT_PRODUCT_TEXTURE_2D_NV
   GL_DOT_PRODUCT_TEXTURE_CUBE_MAP_NV
   GL_DOT_PRODUCT_DIFFUSE_CUBE_MAP_NV
   GL_DOT_PRODUCT_REFLECT_CUBE_MAP_NV
   GL_DOT_PRODUCT_CONST_EYE_REFLECT_CUBE_MAP_NV
   GL_HILO_NV
   GL_DSDT_NV
   GL_DSDT_MAG_NV
   GL_DSDT_MAG_VIB_NV
   GL_HILO16_NV
   GL_SIGNED_HILO_NV
   GL_SIGNED_HILO16_NV
   GL_SIGNED_RGBA_NV
   GL_SIGNED_RGBA8_NV
   GL_SIGNED_RGB_NV
   GL_SIGNED_RGB8_NV
   GL_SIGNED_LUMINANCE_NV
   GL_SIGNED_LUMINANCE8_NV
   GL_SIGNED_LUMINANCE_ALPHA_NV
   GL_SIGNED_LUMINANCE8_ALPHA8_NV
   GL_SIGNED_ALPHA_NV
   GL_SIGNED_ALPHA8_NV
   GL_SIGNED_INTENSITY_NV
   GL_SIGNED_INTENSITY8_NV
   GL_DSDT8_NV
   GL_DSDT8_MAG8_NV
   GL_DSDT8_MAG8_INTENSITY8_NV
   GL_SIGNED_RGB_UNSIGNED_ALPHA_NV
   GL_SIGNED_RGB8_UNSIGNED_ALPHA8_NV
   GL_HI_SCALE_NV
   GL_LO_SCALE_NV
   GL_DS_SCALE_NV
   GL_DT_SCALE_NV
   GL_MAGNITUDE_SCALE_NV
   GL_VIBRANCE_SCALE_NV
   GL_HI_BIAS_NV
   GL_LO_BIAS_NV
   GL_DS_BIAS_NV
   GL_DT_BIAS_NV
   GL_MAGNITUDE_BIAS_NV
   GL_VIBRANCE_BIAS_NV
   GL_TEXTURE_BORDER_VALUES_NV
   GL_TEXTURE_HI_SIZE_NV
   GL_TEXTURE_LO_SIZE_NV
   GL_TEXTURE_DS_SIZE_NV
   GL_TEXTURE_DT_SIZE_NV
   GL_TEXTURE_MAG_SIZE_NV
   GL_DOT_PRODUCT_TEXTURE_3D_NV
   GL_VERTEX_ARRAY_RANGE_WITHOUT_FLUSH_NV
   GL_VERTEX_PROGRAM_NV
   GL_VERTEX_STATE_PROGRAM_NV
   GL_ATTRIB_ARRAY_SIZE_NV
   GL_ATTRIB_ARRAY_STRIDE_NV
   GL_ATTRIB_ARRAY_TYPE_NV
   GL_CURRENT_ATTRIB_NV
   GL_PROGRAM_LENGTH_NV
   GL_PROGRAM_STRING_NV
   GL_MODELVIEW_PROJECTION_NV
   GL_IDENTITY_NV
   GL_INVERSE_NV
   GL_TRANSPOSE_NV
   GL_INVERSE_TRANSPOSE_NV
   GL_MAX_TRACK_MATRIX_STACK_DEPTH_NV
   GL_MAX_TRACK_MATRICES_NV
   GL_MATRIX0_NV
   GL_MATRIX1_NV
   GL_MATRIX2_NV
   GL_MATRIX3_NV
   GL_MATRIX4_NV
   GL_MATRIX5_NV
   GL_MATRIX6_NV
   GL_MATRIX7_NV
   GL_CURRENT_MATRIX_STACK_DEPTH_NV
   GL_CURRENT_MATRIX_NV
   GL_VERTEX_PROGRAM_POINT_SIZE_NV
   GL_VERTEX_PROGRAM_TWO_SIDE_NV
   GL_PROGRAM_PARAMETER_NV
   GL_ATTRIB_ARRAY_POINTER_NV
   GL_PROGRAM_TARGET_NV
   GL_PROGRAM_RESIDENT_NV
   GL_TRACK_MATRIX_NV
   GL_TRACK_MATRIX_TRANSFORM_NV
   GL_VERTEX_PROGRAM_BINDING_NV
   GL_PROGRAM_ERROR_POSITION_NV
   GL_VERTEX_ATTRIB_ARRAY0_NV
   GL_VERTEX_ATTRIB_ARRAY1_NV
   GL_VERTEX_ATTRIB_ARRAY2_NV
   GL_VERTEX_ATTRIB_ARRAY3_NV
   GL_VERTEX_ATTRIB_ARRAY4_NV
   GL_VERTEX_ATTRIB_ARRAY5_NV
   GL_VERTEX_ATTRIB_ARRAY6_NV
   GL_VERTEX_ATTRIB_ARRAY7_NV
   GL_VERTEX_ATTRIB_ARRAY8_NV
   GL_VERTEX_ATTRIB_ARRAY9_NV
   GL_VERTEX_ATTRIB_ARRAY10_NV
   GL_VERTEX_ATTRIB_ARRAY11_NV
   GL_VERTEX_ATTRIB_ARRAY12_NV
   GL_VERTEX_ATTRIB_ARRAY13_NV
   GL_VERTEX_ATTRIB_ARRAY14_NV
   GL_VERTEX_ATTRIB_ARRAY15_NV
   GL_MAP1_VERTEX_ATTRIB0_4_NV
   GL_MAP1_VERTEX_ATTRIB1_4_NV
   GL_MAP1_VERTEX_ATTRIB2_4_NV
   GL_MAP1_VERTEX_ATTRIB3_4_NV
   GL_MAP1_VERTEX_ATTRIB4_4_NV
   GL_MAP1_VERTEX_ATTRIB5_4_NV
   GL_MAP1_VERTEX_ATTRIB6_4_NV
   GL_MAP1_VERTEX_ATTRIB7_4_NV
   GL_MAP1_VERTEX_ATTRIB8_4_NV
   GL_MAP1_VERTEX_ATTRIB9_4_NV
   GL_MAP1_VERTEX_ATTRIB10_4_NV
   GL_MAP1_VERTEX_ATTRIB11_4_NV
   GL_MAP1_VERTEX_ATTRIB12_4_NV
   GL_MAP1_VERTEX_ATTRIB13_4_NV
   GL_MAP1_VERTEX_ATTRIB14_4_NV
   GL_MAP1_VERTEX_ATTRIB15_4_NV
   GL_MAP2_VERTEX_ATTRIB0_4_NV
   GL_MAP2_VERTEX_ATTRIB1_4_NV
   GL_MAP2_VERTEX_ATTRIB2_4_NV
   GL_MAP2_VERTEX_ATTRIB3_4_NV
   GL_MAP2_VERTEX_ATTRIB4_4_NV
   GL_MAP2_VERTEX_ATTRIB5_4_NV
   GL_MAP2_VERTEX_ATTRIB6_4_NV
   GL_MAP2_VERTEX_ATTRIB7_4_NV
   GL_MAP2_VERTEX_ATTRIB8_4_NV
   GL_MAP2_VERTEX_ATTRIB9_4_NV
   GL_MAP2_VERTEX_ATTRIB10_4_NV
   GL_MAP2_VERTEX_ATTRIB11_4_NV
   GL_MAP2_VERTEX_ATTRIB12_4_NV
   GL_MAP2_VERTEX_ATTRIB13_4_NV
   GL_MAP2_VERTEX_ATTRIB14_4_NV
   GL_MAP2_VERTEX_ATTRIB15_4_NV
   GL_TEXTURE_MAX_CLAMP_S_SGIX
   GL_TEXTURE_MAX_CLAMP_T_SGIX
   GL_TEXTURE_MAX_CLAMP_R_SGIX
   GL_SCALEBIAS_HINT_SGIX
   GL_INTERLACE_OML
   GL_INTERLACE_READ_OML
   GL_FORMAT_SUBSAMPLE_24_24_OML
   GL_FORMAT_SUBSAMPLE_244_244_OML
   GL_PACK_RESAMPLE_OML
   GL_UNPACK_RESAMPLE_OML
   GL_RESAMPLE_REPLICATE_OML
   GL_RESAMPLE_ZERO_FILL_OML
   GL_RESAMPLE_AVERAGE_OML
   GL_RESAMPLE_DECIMATE_OML
   GL_DEPTH_STENCIL_TO_RGBA_NV
   GL_DEPTH_STENCIL_TO_BGRA_NV
   GL_BUMP_ROT_MATRIX_ATI
   GL_BUMP_ROT_MATRIX_SIZE_ATI
   GL_BUMP_NUM_TEX_UNITS_ATI
   GL_BUMP_TEX_UNITS_ATI
   GL_DUDV_ATI
   GL_DU8DV8_ATI
   GL_BUMP_ENVMAP_ATI
   GL_BUMP_TARGET_ATI
   GL_FRAGMENT_SHADER_ATI
   GL_REG_0_ATI
   GL_REG_1_ATI
   GL_REG_2_ATI
   GL_REG_3_ATI
   GL_REG_4_ATI
   GL_REG_5_ATI
   GL_REG_6_ATI
   GL_REG_7_ATI
   GL_REG_8_ATI
   GL_REG_9_ATI
   GL_REG_10_ATI
   GL_REG_11_ATI
   GL_REG_12_ATI
   GL_REG_13_ATI
   GL_REG_14_ATI
   GL_REG_15_ATI
   GL_REG_16_ATI
   GL_REG_17_ATI
   GL_REG_18_ATI
   GL_REG_19_ATI
   GL_REG_20_ATI
   GL_REG_21_ATI
   GL_REG_22_ATI
   GL_REG_23_ATI
   GL_REG_24_ATI
   GL_REG_25_ATI
   GL_REG_26_ATI
   GL_REG_27_ATI
   GL_REG_28_ATI
   GL_REG_29_ATI
   GL_REG_30_ATI
   GL_REG_31_ATI
   GL_CON_0_ATI
   GL_CON_1_ATI
   GL_CON_2_ATI
   GL_CON_3_ATI
   GL_CON_4_ATI
   GL_CON_5_ATI
   GL_CON_6_ATI
   GL_CON_7_ATI
   GL_CON_8_ATI
   GL_CON_9_ATI
   GL_CON_10_ATI
   GL_CON_11_ATI
   GL_CON_12_ATI
   GL_CON_13_ATI
   GL_CON_14_ATI
   GL_CON_15_ATI
   GL_CON_16_ATI
   GL_CON_17_ATI
   GL_CON_18_ATI
   GL_CON_19_ATI
   GL_CON_20_ATI
   GL_CON_21_ATI
   GL_CON_22_ATI
   GL_CON_23_ATI
   GL_CON_24_ATI
   GL_CON_25_ATI
   GL_CON_26_ATI
   GL_CON_27_ATI
   GL_CON_28_ATI
   GL_CON_29_ATI
   GL_CON_30_ATI
   GL_CON_31_ATI
   GL_MOV_ATI
   GL_ADD_ATI
   GL_MUL_ATI
   GL_SUB_ATI
   GL_DOT3_ATI
   GL_DOT4_ATI
   GL_MAD_ATI
   GL_LERP_ATI
   GL_CND_ATI
   GL_CND0_ATI
   GL_DOT2_ADD_ATI
   GL_SECONDARY_INTERPOLATOR_ATI
   GL_NUM_FRAGMENT_REGISTERS_ATI
   GL_NUM_FRAGMENT_CONSTANTS_ATI
   GL_NUM_PASSES_ATI
   GL_NUM_INSTRUCTIONS_PER_PASS_ATI
   GL_NUM_INSTRUCTIONS_TOTAL_ATI
   GL_NUM_INPUT_INTERPOLATOR_COMPONENTS_ATI
   GL_NUM_LOOPBACK_COMPONENTS_ATI
   GL_COLOR_ALPHA_PAIRING_ATI
   GL_SWIZZLE_STR_ATI
   GL_SWIZZLE_STQ_ATI
   GL_SWIZZLE_STR_DR_ATI
   GL_SWIZZLE_STQ_DQ_ATI
   GL_SWIZZLE_STRQ_ATI
   GL_SWIZZLE_STRQ_DQ_ATI
   GL_RED_BIT_ATI
   GL_GREEN_BIT_ATI
   GL_BLUE_BIT_ATI
   GL_2X_BIT_ATI
   GL_4X_BIT_ATI
   GL_8X_BIT_ATI
   GL_HALF_BIT_ATI
   GL_QUARTER_BIT_ATI
   GL_EIGHTH_BIT_ATI
   GL_SATURATE_BIT_ATI
   GL_COMP_BIT_ATI
   GL_NEGATE_BIT_ATI
   GL_BIAS_BIT_ATI
   GL_PN_TRIANGLES_ATI
   GL_MAX_PN_TRIANGLES_TESSELATION_LEVEL_ATI
   GL_PN_TRIANGLES_POINT_MODE_ATI
   GL_PN_TRIANGLES_NORMAL_MODE_ATI
   GL_PN_TRIANGLES_TESSELATION_LEVEL_ATI
   GL_PN_TRIANGLES_POINT_MODE_LINEAR_ATI
   GL_PN_TRIANGLES_POINT_MODE_CUBIC_ATI
   GL_PN_TRIANGLES_NORMAL_MODE_LINEAR_ATI
   GL_PN_TRIANGLES_NORMAL_MODE_QUADRATIC_ATI
   GL_STATIC_ATI
   GL_DYNAMIC_ATI
   GL_PRESERVE_ATI
   GL_DISCARD_ATI
   GL_OBJECT_BUFFER_SIZE_ATI
   GL_OBJECT_BUFFER_USAGE_ATI
   GL_ARRAY_OBJECT_BUFFER_ATI
   GL_ARRAY_OBJECT_OFFSET_ATI
   GL_VERTEX_SHADER_EXT
   GL_VERTEX_SHADER_BINDING_EXT
   GL_OP_INDEX_EXT
   GL_OP_NEGATE_EXT
   GL_OP_DOT3_EXT
   GL_OP_DOT4_EXT
   GL_OP_MUL_EXT
   GL_OP_ADD_EXT
   GL_OP_MADD_EXT
   GL_OP_FRAC_EXT
   GL_OP_MAX_EXT
   GL_OP_MIN_EXT
   GL_OP_SET_GE_EXT
   GL_OP_SET_LT_EXT
   GL_OP_CLAMP_EXT
   GL_OP_FLOOR_EXT
   GL_OP_ROUND_EXT
   GL_OP_EXP_BASE_2_EXT
   GL_OP_LOG_BASE_2_EXT
   GL_OP_POWER_EXT
   GL_OP_RECIP_EXT
   GL_OP_RECIP_SQRT_EXT
   GL_OP_SUB_EXT
   GL_OP_CROSS_PRODUCT_EXT
   GL_OP_MULTIPLY_MATRIX_EXT
   GL_OP_MOV_EXT
   GL_OUTPUT_VERTEX_EXT
   GL_OUTPUT_COLOR0_EXT
   GL_OUTPUT_COLOR1_EXT
   GL_OUTPUT_TEXTURE_COORD0_EXT
   GL_OUTPUT_TEXTURE_COORD1_EXT
   GL_OUTPUT_TEXTURE_COORD2_EXT
   GL_OUTPUT_TEXTURE_COORD3_EXT
   GL_OUTPUT_TEXTURE_COORD4_EXT
   GL_OUTPUT_TEXTURE_COORD5_EXT
   GL_OUTPUT_TEXTURE_COORD6_EXT
   GL_OUTPUT_TEXTURE_COORD7_EXT
   GL_OUTPUT_TEXTURE_COORD8_EXT
   GL_OUTPUT_TEXTURE_COORD9_EXT
   GL_OUTPUT_TEXTURE_COORD10_EXT
   GL_OUTPUT_TEXTURE_COORD11_EXT
   GL_OUTPUT_TEXTURE_COORD12_EXT
   GL_OUTPUT_TEXTURE_COORD13_EXT
   GL_OUTPUT_TEXTURE_COORD14_EXT
   GL_OUTPUT_TEXTURE_COORD15_EXT
   GL_OUTPUT_TEXTURE_COORD16_EXT
   GL_OUTPUT_TEXTURE_COORD17_EXT
   GL_OUTPUT_TEXTURE_COORD18_EXT
   GL_OUTPUT_TEXTURE_COORD19_EXT
   GL_OUTPUT_TEXTURE_COORD20_EXT
   GL_OUTPUT_TEXTURE_COORD21_EXT
   GL_OUTPUT_TEXTURE_COORD22_EXT
   GL_OUTPUT_TEXTURE_COORD23_EXT
   GL_OUTPUT_TEXTURE_COORD24_EXT
   GL_OUTPUT_TEXTURE_COORD25_EXT
   GL_OUTPUT_TEXTURE_COORD26_EXT
   GL_OUTPUT_TEXTURE_COORD27_EXT
   GL_OUTPUT_TEXTURE_COORD28_EXT
   GL_OUTPUT_TEXTURE_COORD29_EXT
   GL_OUTPUT_TEXTURE_COORD30_EXT
   GL_OUTPUT_TEXTURE_COORD31_EXT
   GL_OUTPUT_FOG_EXT
   GL_SCALAR_EXT
   GL_VECTOR_EXT
   GL_MATRIX_EXT
   GL_VARIANT_EXT
   GL_INVARIANT_EXT
   GL_LOCAL_CONSTANT_EXT
   GL_LOCAL_EXT
   GL_MAX_VERTEX_SHADER_INSTRUCTIONS_EXT
   GL_MAX_VERTEX_SHADER_VARIANTS_EXT
   GL_MAX_VERTEX_SHADER_INVARIANTS_EXT
   GL_MAX_VERTEX_SHADER_LOCAL_CONSTANTS_EXT
   GL_MAX_VERTEX_SHADER_LOCALS_EXT
   GL_MAX_OPTIMIZED_VERTEX_SHADER_INSTRUCTIONS_EXT
   GL_MAX_OPTIMIZED_VERTEX_SHADER_VARIANTS_EXT
   GL_MAX_OPTIMIZED_VERTEX_SHADER_LOCAL_CONSTANTS_EXT
   GL_MAX_OPTIMIZED_VERTEX_SHADER_INVARIANTS_EXT
   GL_MAX_OPTIMIZED_VERTEX_SHADER_LOCALS_EXT
   GL_VERTEX_SHADER_INSTRUCTIONS_EXT
   GL_VERTEX_SHADER_VARIANTS_EXT
   GL_VERTEX_SHADER_INVARIANTS_EXT
   GL_VERTEX_SHADER_LOCAL_CONSTANTS_EXT
   GL_VERTEX_SHADER_LOCALS_EXT
   GL_VERTEX_SHADER_OPTIMIZED_EXT
   GL_X_EXT
   GL_Y_EXT
   GL_Z_EXT
   GL_W_EXT
   GL_NEGATIVE_X_EXT
   GL_NEGATIVE_Y_EXT
   GL_NEGATIVE_Z_EXT
   GL_NEGATIVE_W_EXT
   GL_ZERO_EXT
   GL_ONE_EXT
   GL_NEGATIVE_ONE_EXT
   GL_NORMALIZED_RANGE_EXT
   GL_FULL_RANGE_EXT
   GL_CURRENT_VERTEX_EXT
   GL_MVP_MATRIX_EXT
   GL_VARIANT_VALUE_EXT
   GL_VARIANT_DATATYPE_EXT
   GL_VARIANT_ARRAY_STRIDE_EXT
   GL_VARIANT_ARRAY_TYPE_EXT
   GL_VARIANT_ARRAY_EXT
   GL_VARIANT_ARRAY_POINTER_EXT
   GL_INVARIANT_VALUE_EXT
   GL_INVARIANT_DATATYPE_EXT
   GL_LOCAL_CONSTANT_VALUE_EXT
   GL_LOCAL_CONSTANT_DATATYPE_EXT
   GL_MAX_VERTEX_STREAMS_ATI
   GL_VERTEX_STREAM0_ATI
   GL_VERTEX_STREAM1_ATI
   GL_VERTEX_STREAM2_ATI
   GL_VERTEX_STREAM3_ATI
   GL_VERTEX_STREAM4_ATI
   GL_VERTEX_STREAM5_ATI
   GL_VERTEX_STREAM6_ATI
   GL_VERTEX_STREAM7_ATI
   GL_VERTEX_SOURCE_ATI
   GL_ELEMENT_ARRAY_ATI
   GL_ELEMENT_ARRAY_TYPE_ATI
   GL_ELEMENT_ARRAY_POINTER_ATI
   GL_QUAD_MESH_SUN
   GL_TRIANGLE_MESH_SUN
   GL_SLICE_ACCUM_SUN
   GL_MULTISAMPLE_FILTER_HINT_NV
   GL_DEPTH_CLAMP_NV
   GL_PIXEL_COUNTER_BITS_NV
   GL_CURRENT_OCCLUSION_QUERY_ID_NV
   GL_PIXEL_COUNT_NV
   GL_PIXEL_COUNT_AVAILABLE_NV
   GL_POINT_SPRITE_NV
   GL_COORD_REPLACE_NV
   GL_POINT_SPRITE_R_MODE_NV
   GL_OFFSET_PROJECTIVE_TEXTURE_2D_NV
   GL_OFFSET_PROJECTIVE_TEXTURE_2D_SCALE_NV
   GL_OFFSET_PROJECTIVE_TEXTURE_RECTANGLE_NV
   GL_OFFSET_PROJECTIVE_TEXTURE_RECTANGLE_SCALE_NV
   GL_OFFSET_HILO_TEXTURE_2D_NV
   GL_OFFSET_HILO_TEXTURE_RECTANGLE_NV
   GL_OFFSET_HILO_PROJECTIVE_TEXTURE_2D_NV
   GL_OFFSET_HILO_PROJECTIVE_TEXTURE_RECTANGLE_NV
   GL_DEPENDENT_HILO_TEXTURE_2D_NV
   GL_DEPENDENT_RGB_TEXTURE_3D_NV
   GL_DEPENDENT_RGB_TEXTURE_CUBE_MAP_NV
   GL_DOT_PRODUCT_PASS_THROUGH_NV
   GL_DOT_PRODUCT_TEXTURE_1D_NV
   GL_DOT_PRODUCT_AFFINE_DEPTH_REPLACE_NV
   GL_HILO8_NV
   GL_SIGNED_HILO8_NV
   GL_FORCE_BLUE_TO_ONE_NV
   GL_STENCIL_TEST_TWO_SIDE_EXT
   GL_ACTIVE_STENCIL_FACE_EXT
   GL_TEXT_FRAGMENT_SHADER_ATI
   GL_UNPACK_CLIENT_STORAGE_APPLE
   GL_ELEMENT_ARRAY_APPLE
   GL_ELEMENT_ARRAY_TYPE_APPLE
   GL_ELEMENT_ARRAY_POINTER_APPLE
   GL_DRAW_PIXELS_APPLE
   GL_FENCE_APPLE
   GL_VERTEX_ARRAY_BINDING_APPLE
   GL_VERTEX_ARRAY_RANGE_APPLE
   GL_VERTEX_ARRAY_RANGE_LENGTH_APPLE
   GL_VERTEX_ARRAY_STORAGE_HINT_APPLE
   GL_VERTEX_ARRAY_RANGE_POINTER_APPLE
   GL_STORAGE_CACHED_APPLE
   GL_STORAGE_SHARED_APPLE
   GL_YCBCR_422_APPLE
   GL_UNSIGNED_SHORT_8_8_APPLE
   GL_UNSIGNED_SHORT_8_8_REV_APPLE
   GL_RGB_S3TC
   GL_RGB4_S3TC
   GL_RGBA_S3TC
   GL_RGBA4_S3TC
   GL_MAX_DRAW_BUFFERS_ATI
   GL_DRAW_BUFFER0_ATI
   GL_DRAW_BUFFER1_ATI
   GL_DRAW_BUFFER2_ATI
   GL_DRAW_BUFFER3_ATI
   GL_DRAW_BUFFER4_ATI
   GL_DRAW_BUFFER5_ATI
   GL_DRAW_BUFFER6_ATI
   GL_DRAW_BUFFER7_ATI
   GL_DRAW_BUFFER8_ATI
   GL_DRAW_BUFFER9_ATI
   GL_DRAW_BUFFER10_ATI
   GL_DRAW_BUFFER11_ATI
   GL_DRAW_BUFFER12_ATI
   GL_DRAW_BUFFER13_ATI
   GL_DRAW_BUFFER14_ATI
   GL_DRAW_BUFFER15_ATI
   GL_COLOR_CLEAR_UNCLAMPED_VALUE_ATI
   GL_MODULATE_ADD_ATI
   GL_MODULATE_SIGNED_ADD_ATI
   GL_MODULATE_SUBTRACT_ATI
   GL_RGBA_FLOAT32_ATI
   GL_RGB_FLOAT32_ATI
   GL_ALPHA_FLOAT32_ATI
   GL_INTENSITY_FLOAT32_ATI
   GL_LUMINANCE_FLOAT32_ATI
   GL_LUMINANCE_ALPHA_FLOAT32_ATI
   GL_RGBA_FLOAT16_ATI
   GL_RGB_FLOAT16_ATI
   GL_ALPHA_FLOAT16_ATI
   GL_INTENSITY_FLOAT16_ATI
   GL_LUMINANCE_FLOAT16_ATI
   GL_LUMINANCE_ALPHA_FLOAT16_ATI
   GL_FLOAT_R_NV
   GL_FLOAT_RG_NV
   GL_FLOAT_RGB_NV
   GL_FLOAT_RGBA_NV
   GL_FLOAT_R16_NV
   GL_FLOAT_R32_NV
   GL_FLOAT_RG16_NV
   GL_FLOAT_RG32_NV
   GL_FLOAT_RGB16_NV
   GL_FLOAT_RGB32_NV
   GL_FLOAT_RGBA16_NV
   GL_FLOAT_RGBA32_NV
   GL_TEXTURE_FLOAT_COMPONENTS_NV
   GL_FLOAT_CLEAR_COLOR_VALUE_NV
   GL_FLOAT_RGBA_MODE_NV
   GL_MAX_FRAGMENT_PROGRAM_LOCAL_PARAMETERS_NV
   GL_FRAGMENT_PROGRAM_NV
   GL_MAX_TEXTURE_COORDS_NV
   GL_MAX_TEXTURE_IMAGE_UNITS_NV
   GL_FRAGMENT_PROGRAM_BINDING_NV
   GL_PROGRAM_ERROR_STRING_NV
   GL_HALF_FLOAT_NV
   GL_WRITE_PIXEL_DATA_RANGE_NV
   GL_READ_PIXEL_DATA_RANGE_NV
   GL_WRITE_PIXEL_DATA_RANGE_LENGTH_NV
   GL_READ_PIXEL_DATA_RANGE_LENGTH_NV
   GL_WRITE_PIXEL_DATA_RANGE_POINTER_NV
   GL_READ_PIXEL_DATA_RANGE_POINTER_NV
   GL_PRIMITIVE_RESTART_NV
   GL_PRIMITIVE_RESTART_INDEX_NV
   GL_TEXTURE_UNSIGNED_REMAP_MODE_NV
   GL_STENCIL_BACK_FUNC_ATI
   GL_STENCIL_BACK_FAIL_ATI
   GL_STENCIL_BACK_PASS_DEPTH_FAIL_ATI
   GL_STENCIL_BACK_PASS_DEPTH_PASS_ATI
   GL_IMPLEMENTATION_COLOR_READ_TYPE_OES
   GL_IMPLEMENTATION_COLOR_READ_FORMAT_OES
   GL_DEPTH_BOUNDS_TEST_EXT
   GL_DEPTH_BOUNDS_EXT
   GL_MIRROR_CLAMP_EXT
   GL_MIRROR_CLAMP_TO_EDGE_EXT
   GL_MIRROR_CLAMP_TO_BORDER_EXT
   GL_BLEND_EQUATION_RGB_EXT
   GL_BLEND_EQUATION_ALPHA_EXT
   GL_PACK_INVERT_MESA
   GL_UNSIGNED_SHORT_8_8_MESA
   GL_UNSIGNED_SHORT_8_8_REV_MESA
   GL_YCBCR_MESA
   GL_PIXEL_PACK_BUFFER_EXT
   GL_PIXEL_UNPACK_BUFFER_EXT
   GL_PIXEL_PACK_BUFFER_BINDING_EXT
   GL_PIXEL_UNPACK_BUFFER_BINDING_EXT
   GL_MAX_PROGRAM_EXEC_INSTRUCTIONS_NV
   GL_MAX_PROGRAM_CALL_DEPTH_NV
   GL_MAX_PROGRAM_IF_DEPTH_NV
   GL_MAX_PROGRAM_LOOP_DEPTH_NV
   GL_MAX_PROGRAM_LOOP_COUNT_NV
   GL_INVALID_FRAMEBUFFER_OPERATION_EXT
   GL_MAX_RENDERBUFFER_SIZE_EXT
   GL_FRAMEBUFFER_BINDING_EXT
   GL_RENDERBUFFER_BINDING_EXT
   GL_FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE_EXT
   GL_FRAMEBUFFER_ATTACHMENT_OBJECT_NAME_EXT
   GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL_EXT
   GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE_EXT
   GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_3D_ZOFFSET_EXT
   GL_FRAMEBUFFER_COMPLETE_EXT
   GL_FRAMEBUFFER_INCOMPLETE_ATTACHMENT_EXT
   GL_FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT_EXT
   GL_FRAMEBUFFER_INCOMPLETE_DIMENSIONS_EXT
   GL_FRAMEBUFFER_INCOMPLETE_FORMATS_EXT
   GL_FRAMEBUFFER_INCOMPLETE_DRAW_BUFFER_EXT
   GL_FRAMEBUFFER_INCOMPLETE_READ_BUFFER_EXT
   GL_FRAMEBUFFER_UNSUPPORTED_EXT
   GL_DRAW_FRAMEBUFFER
   GL_DEPTH_ATTACHMENT
   GL_FRAMEBUFFER
   GL_FRAMEBUFFER_COMPLETE
   GL_MAX_COLOR_ATTACHMENTS_EXT
   GL_COLOR_ATTACHMENT0_EXT
   GL_COLOR_ATTACHMENT1_EXT
   GL_COLOR_ATTACHMENT2_EXT
   GL_COLOR_ATTACHMENT3_EXT
   GL_COLOR_ATTACHMENT4_EXT
   GL_COLOR_ATTACHMENT5_EXT
   GL_COLOR_ATTACHMENT6_EXT
   GL_COLOR_ATTACHMENT7_EXT
   GL_COLOR_ATTACHMENT8_EXT
   GL_COLOR_ATTACHMENT9_EXT
   GL_COLOR_ATTACHMENT10_EXT
   GL_COLOR_ATTACHMENT11_EXT
   GL_COLOR_ATTACHMENT12_EXT
   GL_COLOR_ATTACHMENT13_EXT
   GL_COLOR_ATTACHMENT14_EXT
   GL_COLOR_ATTACHMENT15_EXT
   GL_DEPTH_ATTACHMENT_EXT
   GL_STENCIL_ATTACHMENT_EXT
   GL_FRAMEBUFFER_EXT
   GL_RENDERBUFFER_EXT
   GL_RENDERBUFFER_WIDTH_EXT
   GL_RENDERBUFFER_HEIGHT_EXT
   GL_RENDERBUFFER_INTERNAL_FORMAT_EXT
   GL_STENCIL_INDEX1_EXT
   GL_STENCIL_INDEX4_EXT
   GL_STENCIL_INDEX8_EXT
   GL_STENCIL_INDEX16_EXT
   GL_RENDERBUFFER_RED_SIZE_EXT
   GL_RENDERBUFFER_GREEN_SIZE_EXT
   GL_RENDERBUFFER_BLUE_SIZE_EXT
   GL_RENDERBUFFER_ALPHA_SIZE_EXT
   GL_RENDERBUFFER_DEPTH_SIZE_EXT
   GL_RENDERBUFFER_STENCIL_SIZE_EXT
   GL_CURRENT_BIT
   GL_POINT_BIT
   GL_LINE_BIT
   GL_POLYGON_BIT
   GL_POLYGON_STIPPLE_BIT
   GL_PIXEL_MODE_BIT
   GL_LIGHTING_BIT
   GL_FOG_BIT
   GL_DEPTH_BUFFER_BIT
   GL_ACCUM_BUFFER_BIT
   GL_STENCIL_BUFFER_BIT
   GL_VIEWPORT_BIT
   GL_TRANSFORM_BIT
   GL_ENABLE_BIT
   GL_COLOR_BUFFER_BIT
   GL_HINT_BIT
   GL_EVAL_BIT
   GL_LIST_BIT
   GL_TEXTURE_BIT
   GL_SCISSOR_BIT
   GL_ALL_ATTRIB_BITS
   GL_CLIENT_PIXEL_STORE_BIT
   GL_CLIENT_VERTEX_ARRAY_BIT
   GL_ALL_CLIENT_ATTRIB_BITS
   GL_CLIENT_ALL_ATTRIB_BITS
   GL_CG_VERTEX_SHADER_EXT
   GL_CG_FRAGMENT_SHADER_EXT
   GL_BUFFER_SIZE_ARB
   GL_BUFFER_USAGE_ARB
   GL_ARRAY_BUFFER_ARB
   GL_ELEMENT_ARRAY_BUFFER_ARB
   GL_ARRAY_BUFFER_BINDING_ARB
   GL_ELEMENT_ARRAY_BUFFER_BINDING_ARB
   GL_VERTEX_ARRAY_BUFFER_BINDING_ARB
   GL_NORMAL_ARRAY_BUFFER_BINDING_ARB
   GL_COLOR_ARRAY_BUFFER_BINDING_ARB
   GL_INDEX_ARRAY_BUFFER_BINDING_ARB
   GL_TEXTURE_COORD_ARRAY_BUFFER_BINDING_ARB
   GL_EDGE_FLAG_ARRAY_BUFFER_BINDING_ARB
   GL_SECONDARY_COLOR_ARRAY_BUFFER_BINDING_ARB
   GL_FOG_COORDINATE_ARRAY_BUFFER_BINDING_ARB
   GL_WEIGHT_ARRAY_BUFFER_BINDING_ARB
   GL_VERTEX_ATTRIB_ARRAY_BUFFER_BINDING_ARB
   GL_READ_ONLY_ARB
   GL_WRITE_ONLY_ARB
   GL_READ_WRITE_ARB
   GL_BUFFER_ACCESS_ARB
   GL_BUFFER_MAPPED_ARB
   GL_BUFFER_MAP_POINTER_ARB
   GL_STREAM_DRAW_ARB
   GL_STREAM_READ_ARB
   GL_STREAM_COPY_ARB
   GL_STATIC_DRAW_ARB
   GL_STATIC_READ_ARB
   GL_STATIC_COPY_ARB
   GL_DYNAMIC_DRAW_ARB
   GL_DYNAMIC_READ_ARB
   GL_DYNAMIC_COPY_ARB
   GL_POINT_SIZE_MIN_ARB
   GL_POINT_SIZE_MAX_ARB
   GL_POINT_FADE_THRESHOLD_SIZE_ARB
   GL_POINT_DISTANCE_ATTENUATION_ARB
   GL_MULTISAMPLE_ARB
   GL_SAMPLE_ALPHA_TO_COVERAGE_ARB
   GL_SAMPLE_ALPHA_TO_ONE_ARB
   GL_SAMPLE_COVERAGE_ARB
   GL_SAMPLE_BUFFERS_ARB
   GL_SAMPLES_ARB
   GL_SAMPLE_COVERAGE_VALUE_ARB
   GL_SAMPLE_COVERAGE_INVERT_ARB
   GL_MULTISAMPLE_BIT_ARB
   GL_RGBA_FLOAT_MODE_ARB
   GL_CLAMP_VERTEX_COLOR_ARB
   GL_CLAMP_FRAGMENT_COLOR_ARB
   GL_CLAMP_READ_COLOR_ARB
   GL_FIXED_ONLY_ARB
   GL_FRAMEBUFFER_SRGB
   GL_SRGB_ALPHA
);
# gl_const

@glu_const = qw(
   GLU_SMOOTH
   GLU_FLAT
   GLU_NONE
   GLU_POINT
   GLU_LINE
   GLU_FILL
   GLU_SILHOUETTE
   GLU_OUTSIDE
   GLU_INSIDE
   GLU_BEGIN
   GLU_VERTEX
   GLU_END
   GLU_ERROR
   GLU_EDGE_FLAG
   GLU_CW
   GLU_CCW
   GLU_INTERIOR
   GLU_EXTERIOR
   GLU_UNKNOWN
   GLU_TESS_ERROR
   GLU_TESS_BEGIN
   GLU_TESS_EDGE_FLAG
   GLU_TESS_VERTEX
   GLU_TESS_COMBINE
   GLU_TESS_END
   GLU_TESS_ERROR_DATA
   GLU_TESS_BEGIN_DATA
   GLU_TESS_EDGE_FLAG_DATA
   GLU_TESS_VERTEX_DATA
   GLU_TESS_COMBINE_DATA
   GLU_TESS_END_DATA
   GLU_TESS_WINDING_RULE
   GLU_TESS_WINDING_ODD
   GLU_TESS_WINDING_NONZERO
   GLU_TESS_WINDING_POSITIVE
   GLU_TESS_WINDING_NEGATIVE
   GLU_TESS_WINDING_ABS_GEQ_TWO
   GLU_TESS_ERROR1
   GLU_TESS_ERROR2
   GLU_TESS_ERROR3
   GLU_TESS_ERROR4
   GLU_TESS_ERROR5
   GLU_TESS_ERROR6
   GLU_TESS_ERROR7
   GLU_TESS_ERROR8
   GLU_AUTO_LOAD_MATRIX
   GLU_CULLING
   GLU_SAMPLING_TOLERANCE
   GLU_DISPLAY_MODE
   GLU_PATH_LENGTH
   GLU_PARAMETRIC_ERROR
   GLU_DOMAIN_DISTANCE
   GLU_MAP1_TRIM_2
   GLU_MAP1_TRIM_3
   GLU_OUTLINE_POLYGON
   GLU_OUTLINE_PATCH
   GLU_NURBS_ERROR1
   GLU_NURBS_ERROR2
   GLU_NURBS_ERROR3
   GLU_NURBS_ERROR4
   GLU_NURBS_ERROR5
   GLU_NURBS_ERROR6
   GLU_NURBS_ERROR7
   GLU_NURBS_ERROR8
   GLU_NURBS_ERROR9
   GLU_NURBS_ERROR10
   GLU_NURBS_ERROR11
   GLU_NURBS_ERROR12
   GLU_NURBS_ERROR13
   GLU_NURBS_ERROR14
   GLU_NURBS_ERROR15
   GLU_NURBS_ERROR16
   GLU_NURBS_ERROR17
   GLU_NURBS_ERROR18
   GLU_NURBS_ERROR19
   GLU_NURBS_ERROR20
   GLU_NURBS_ERROR21
   GLU_NURBS_ERROR22
   GLU_NURBS_ERROR23
   GLU_NURBS_ERROR24
   GLU_NURBS_ERROR25
   GLU_NURBS_ERROR26
   GLU_NURBS_ERROR27
   GLU_NURBS_ERROR28
   GLU_NURBS_ERROR29
   GLU_NURBS_ERROR30
   GLU_NURBS_ERROR31
   GLU_NURBS_ERROR32
   GLU_NURBS_ERROR33
   GLU_NURBS_ERROR34
   GLU_NURBS_ERROR35
   GLU_NURBS_ERROR36
   GLU_NURBS_ERROR37
   GLU_INVALID_ENUM
   GLU_INVALID_VALUE
   GLU_OUT_OF_MEMORY
   GLU_INCOMPATIBLE_GL_VERSION
   GLU_VERSION
   GLU_EXTENSIONS
   GLU_SAMPLING_METHOD
   GLU_PARAMETRIC_TOLERANCE
   GLU_U_STEP
   GLU_V_STEP
   GLU_OBJECT_PARAMETRIC_ERROR_EXT
   GLU_OBJECT_PATH_LENGTH_EXT
);

@glut_const = qw(
   GLUT_API_VERSION
   GLUT_XLIB_IMPLEMENTATION
   GLUT_RGB
   GLUT_RGBA
   GLUT_INDEX
   GLUT_INIT_STATE
   GLUT_VERSION
   GLUT_SINGLE
   GLUT_DOUBLE
   GLUT_ACCUM
   GLUT_ALPHA
   GLUT_DEPTH
   GLUT_STENCIL
   GLUT_MULTISAMPLE
   GLUT_STEREO
   GLUT_LUMINANCE
   GLUT_LEFT_BUTTON
   GLUT_MIDDLE_BUTTON
   GLUT_RIGHT_BUTTON
   GLUT_DOWN
   GLUT_UP
   GLUT_KEY_F1
   GLUT_KEY_F2
   GLUT_KEY_F3
   GLUT_KEY_F4
   GLUT_KEY_F5
   GLUT_KEY_F6
   GLUT_KEY_F7
   GLUT_KEY_F8
   GLUT_KEY_F9
   GLUT_KEY_F10
   GLUT_KEY_F11
   GLUT_KEY_F12
   GLUT_KEY_LEFT
   GLUT_KEY_UP
   GLUT_KEY_RIGHT
   GLUT_KEY_DOWN
   GLUT_KEY_PAGE_UP
   GLUT_KEY_PAGE_DOWN
   GLUT_KEY_HOME
   GLUT_KEY_END
   GLUT_KEY_INSERT
   GLUT_KEY_DELETE
   GLUT_LEFT
   GLUT_ENTERED
   GLUT_MENU_NOT_IN_USE
   GLUT_MENU_IN_USE
   GLUT_NOT_VISIBLE
   GLUT_VISIBLE
   GLUT_HIDDEN
   GLUT_FULLY_RETAINED
   GLUT_PARTIALLY_RETAINED
   GLUT_FULLY_COVERED
   GLUT_RED
   GLUT_GREEN
   GLUT_BLUE
   GLUT_NORMAL
   GLUT_OVERLAY
   GLUT_STROKE_ROMAN
   GLUT_STROKE_MONO_ROMAN
   GLUT_BITMAP_9_BY_15
   GLUT_BITMAP_8_BY_13
   GLUT_BITMAP_TIMES_ROMAN_10
   GLUT_BITMAP_TIMES_ROMAN_24
   GLUT_BITMAP_HELVETICA_10
   GLUT_BITMAP_HELVETICA_12
   GLUT_BITMAP_HELVETICA_18
   GLUT_WINDOW_X
   GLUT_WINDOW_Y
   GLUT_WINDOW_WIDTH
   GLUT_WINDOW_HEIGHT
   GLUT_WINDOW_BUFFER_SIZE
   GLUT_WINDOW_STENCIL_SIZE
   GLUT_WINDOW_DEPTH_SIZE
   GLUT_WINDOW_RED_SIZE
   GLUT_WINDOW_GREEN_SIZE
   GLUT_WINDOW_BLUE_SIZE
   GLUT_WINDOW_ALPHA_SIZE
   GLUT_WINDOW_ACCUM_RED_SIZE
   GLUT_WINDOW_ACCUM_GREEN_SIZE
   GLUT_WINDOW_ACCUM_BLUE_SIZE
   GLUT_WINDOW_ACCUM_ALPHA_SIZE
   GLUT_WINDOW_DOUBLEBUFFER
   GLUT_WINDOW_RGBA
   GLUT_WINDOW_PARENT
   GLUT_WINDOW_NUM_CHILDREN
   GLUT_WINDOW_COLORMAP_SIZE
   GLUT_WINDOW_NUM_SAMPLES
   GLUT_WINDOW_STEREO
   GLUT_WINDOW_CURSOR
   GLUT_WINDOW_FORMAT_ID
   GLUT_SCREEN_WIDTH
   GLUT_SCREEN_HEIGHT
   GLUT_SCREEN_WIDTH_MM
   GLUT_SCREEN_HEIGHT_MM
   GLUT_MENU_NUM_ITEMS
   GLUT_DISPLAY_MODE_POSSIBLE
   GLUT_INIT_WINDOW_X
   GLUT_INIT_WINDOW_Y
   GLUT_INIT_WINDOW_WIDTH
   GLUT_INIT_WINDOW_HEIGHT
   GLUT_INIT_DISPLAY_MODE
   GLUT_ELAPSED_TIME
   GLUT_HAS_KEYBOARD
   GLUT_HAS_MOUSE
   GLUT_HAS_SPACEBALL
   GLUT_HAS_DIAL_AND_BUTTON_BOX
   GLUT_HAS_TABLET
   GLUT_NUM_MOUSE_BUTTONS
   GLUT_NUM_SPACEBALL_BUTTONS
   GLUT_NUM_BUTTON_BOX_BUTTONS
   GLUT_NUM_DIALS
   GLUT_NUM_TABLET_BUTTONS
   GLUT_OVERLAY_POSSIBLE
   GLUT_LAYER_IN_USE
   GLUT_HAS_OVERLAY
   GLUT_TRANSPARENT_INDEX
   GLUT_NORMAL_DAMAGED
   GLUT_OVERLAY_DAMAGED
   GLUT_NORMAL
   GLUT_OVERLAY
   GLUT_ACTIVE_SHIFT
   GLUT_ACTIVE_CTRL
   GLUT_ACTIVE_ALT
   GLUT_CURSOR_RIGHT_ARROW
   GLUT_CURSOR_LEFT_ARROW
   GLUT_CURSOR_INFO
   GLUT_CURSOR_DESTROY
   GLUT_CURSOR_HELP
   GLUT_CURSOR_CYCLE
   GLUT_CURSOR_SPRAY
   GLUT_CURSOR_WAIT
   GLUT_CURSOR_TEXT
   GLUT_CURSOR_CROSSHAIR
   GLUT_CURSOR_UP_DOWN
   GLUT_CURSOR_LEFT_RIGHT
   GLUT_CURSOR_TOP_SIDE
   GLUT_CURSOR_BOTTOM_SIDE
   GLUT_CURSOR_LEFT_SIDE
   GLUT_CURSOR_RIGHT_SIDE
   GLUT_CURSOR_TOP_LEFT_CORNER
   GLUT_CURSOR_TOP_RIGHT_CORNER
   GLUT_CURSOR_BOTTOM_RIGHT_CORNER
   GLUT_CURSOR_BOTTOM_LEFT_CORNER
   GLUT_CURSOR_INHERIT
   GLUT_CURSOR_NONE
   GLUT_CURSOR_FULL_CROSSHAIR
   GLUT_ACTION_EXIT
   GLUT_ACTION_GLUTMAINLOOP_RETURNS
   GLUT_ACTION_CONTINUE_EXECUTION
   GLUT_ACTION_ON_WINDOW_CLOSE
   GLUT_GAME_MODE_ACTIVE
   GLUT_GAME_MODE_POSSIBLE
   GLUT_GAME_MODE_WIDTH
   GLUT_GAME_MODE_HEIGHT
   GLUT_GAME_MODE_PIXEL_DEPTH
   GLUT_GAME_MODE_REFRESH_RATE
   GLUT_GAME_MODE_DISPLAY_CHANGED
   GLUT_CORE_PROFILE
   GLUT_DEBUG
);

@glx_const = qw(
   GLX_USE_GL
   GLX_BUFFER_SIZE
   GLX_LEVEL
   GLX_RGBA
   GLX_DOUBLEBUFFER
   GLX_STEREO
   GLX_AUX_BUFFERS
   GLX_RED_SIZE
   GLX_GREEN_SIZE
   GLX_BLUE_SIZE
   GLX_ALPHA_SIZE
   GLX_DEPTH_SIZE
   GLX_STENCIL_SIZE
   GLX_ACCUM_RED_SIZE
   GLX_ACCUM_GREEN_SIZE
   GLX_ACCUM_BLUE_SIZE
   GLX_ACCUM_ALPHA_SIZE
   GLX_X_VISUAL_TYPE_EXT
   GLX_TRANSPARENT_TYPE_EXT
   GLX_TRANSPARENT_INDEX_VALUE_EXT
   GLX_TRANSPARENT_RED_VALUE_EXT
   GLX_TRANSPARENT_GREEN_VALUE_EXT
   GLX_TRANSPARENT_BLUE_VALUE_EXT
   GLX_TRANSPARENT_ALPHA_VALUE_EXT
   X_PROTOCOL
   X_PROTOCOL_REVISION
   NoEventMask
   KeyPressMask
   KeyReleaseMask
   ButtonPressMask
   ButtonReleaseMask
   EnterWindowMask
   LeaveWindowMask
   PointerMotionMask
   PointerMotionHintMask
   Button1MotionMask
   Button2MotionMask
   Button3MotionMask
   Button4MotionMask
   Button5MotionMask
   ButtonMotionMask
   KeymapStateMask
   ExposureMask
   VisibilityChangeMask
   StructureNotifyMask
   ResizeRedirectMask
   SubstructureNotifyMask
   SubstructureRedirectMask
   FocusChangeMask
   PropertyChangeMask
   ColormapChangeMask
   OwnerGrabButtonMask
   KeyPress
   KeyRelease
   ButtonPress
   ButtonRelease
   MotionNotify
   EnterNotify
   LeaveNotify
   FocusIn
   FocusOut
   KeymapNotify
   Expose
   GraphicsExpose
   NoExpose
   VisibilityNotify
   CreateNotify
   DestroyNotify
   UnmapNotify
   MapNotify
   MapRequest
   ReparentNotify
   ConfigureNotify
   ConfigureRequest
   GravityNotify
   ResizeRequest
   CirculateNotify
   CirculateRequest
   PropertyNotify
   SelectionClear
   SelectionRequest
   SelectionNotify
   ColormapNotify
   ClientMessage
   MappingNotify
   LASTEvent
   ShiftMask
   LockMask
   ControlMask
   Mod1Mask
   Mod2Mask
   Mod3Mask
   Mod4Mask
   Mod5Mask
   ShiftMapIndex
   LockMapIndex
   ControlMapIndex
   Mod1MapIndex
   Mod2MapIndex
   Mod3MapIndex
   Mod4MapIndex
   Mod5MapIndex
   Button1Mask
   Button2Mask
   Button3Mask
   Button4Mask
   Button5Mask
   AnyModifier
   Button1
   Button2
   Button3
   Button4
   Button5
   NotifyNormal
   NotifyGrab
   NotifyUngrab
   NotifyWhileGrabbed
   NotifyHint
   NotifyAncestor
   NotifyVirtual
   NotifyInferior
   NotifyNonlinear
   NotifyNonlinearVirtual
   NotifyPointer
   NotifyPointerRoot
   NotifyDetailNone
   VisibilityUnobscured
   VisibilityPartiallyObscured
   VisibilityFullyObscured
   PlaceOnTop
   PlaceOnBottom
   FamilyInternet
   FamilyDECnet
   FamilyChaos
   PropertyNewValue
   PropertyDelete
   ColormapUninstalled
   ColormapInstalled
   GrabModeSync
   GrabModeAsync
   GrabSuccess
   AlreadyGrabbed
   GrabInvalidTime
   GrabNotViewable
   GrabFrozen
   AsyncPointer
   SyncPointer
   ReplayPointer
   AsyncKeyboard
   SyncKeyboard
   ReplayKeyboard
   AsyncBoth
   SyncBoth
   StaticGray
   GrayScale
   StaticColor
   PseudoColor
   TrueColor
   DirectColor
);


# Items to export into callers namespace by default. Note: do not export
# names by default without a very good reason. Use EXPORT_OK instead.
# Do not simply export all your public functions/methods/constants.

@oldfunctions = qw(
	glpOpenWindow
	glpMainLoop
	glpMoveResizeWindow
	glpMoveWindow
	glpResizeWindow
	glpDisplay
	glXSwapBuffers 
	XPending
	glpXNextEvent
	glpXQueryPointer

	glpFlush
	glpSolidSphere
	glpReadTex

	glpClipPlane
	glpGetClipPlane
	glpLoadMatrixf glpLoadMatrixd glpMultMatrixf glpMultMatrixd

	gluOrtho2D
	gluPerspective
	gluLookAt

	glAccum
	glAlphaFunc
	glBegin
	glBitmap
	glBlendColorEXT
	glBlendEquationEXT
	glBlendFunc
	glCallList
	glCallLists
	glClear
	glClearAccum
	glClearColor
	glClearDepth
	glClearIndex
	glClearStencil
	glClipPlane
	glColor3b
	glColor3bv
	glColor3d
	glColor3dv
	glColor3f
	glColor3fv
	glColor3i
	glColor3iv
	glColor3s
	glColor3sv
	glColor3ub
	glColor3ubv
	glColor3ui
	glColor3uiv
	glColor3us
	glColor3usv
	glColor4b
	glColor4bv
	glColor4d
	glColor4dv
	glColor4f
	glColor4fv
	glColor4i
	glColor4iv
	glColor4s
	glColor4sv
	glColor4ub
	glColor4ubv
	glColor4ui
	glColor4uiv
	glColor4us
	glColor4usv
	glColorMask
	glColorMaterial
	glConvolutionFilter1DEXT
	glConvolutionFilter2DEXT
	glConvolutionParameterfEXT
	glConvolutionParameterfvEXT
	glConvolutionParameteriEXT
	glConvolutionParameterivEXT
	glCopyConvolutionFilter1DEXT
	glCopyConvolutionFilter2DEXT
	glCopyPixels
	glCullFace
	glDeleteLists
	glDepthFunc
	glDepthMask
	glDepthRange
	glDetailTexFuncSGIS
	glDisable
	glDrawBuffer
	glDrawPixels
	glEdgeFlag
	glEdgeFlagv
	glEnable
	glEnd
	glEndList
	glEvalCoord1d
	glEvalCoord1dv
	glEvalCoord1f
	glEvalCoord1fv
	glEvalCoord2d
	glEvalCoord2dv
	glEvalCoord2f
	glEvalCoord2fv
	glEvalMesh1
	glEvalMesh2
	glEvalPoint1
	glEvalPoint2
	glFeedbackBuffer
	glFinish
	glFlush
	glFogf
	glFogfv
	glFogi
	glFogiv
	glFrontFace
	glFrustum
	glGenLists
	glGetBooleanv
	glGetClipPlane
	glGetConvolutionFilterEXT
	glGetConvolutionParameterfvEXT
	glGetConvolutionParameterivEXT
	glGetDetailTexFuncSGIS
	glGetDoublev
	glGetError
	glGetFloatv
	glGetHistogramEXT
	glGetHistogramParameterfvEXT
	glGetHistogramParameterivEXT
	glGetIntegerv
	glGetLightfv
	glGetLightiv
	glGetMapdv
	glGetMapfv
	glGetMapiv
	glGetMaterialfv
	glGetMaterialiv
	glGetMinmaxEXT
	glGetMinmaxParameterfvEXT
	glGetMinmaxParameterivEXT
	glGetPixelMapfv
	glGetPixelMapuiv
	glGetPixelMapusv
	glGetPolygonStipple
	glGetSeparableFilterEXT
	glGetSharpenTexFuncSGIS
	glGetTexEnvfv
	glGetTexEnviv
	glGetTexGendv
	glGetTexGenfv
	glGetTexGeniv
	glGetTexImage
	glGetTexLevelParameterfv
	glGetTexLevelParameteriv
	glGetTexParameterfv
	glGetTexParameteriv
	glHint
	glHistogramEXT
	glIndexMask
	glIndexd
	glIndexdv
	glIndexf
	glIndexfv
	glIndexi
	glIndexiv
	glIndexs
	glIndexsv
	glInitNames
	glIsEnabled
	glIsList
	glLightModelf
	glLightModelfv
	glLightModeli
	glLightModeliv
	glLightf
	glLightfv
	glLighti
	glLightiv
	glLineStipple
	glLineWidth
	glListBase
	glLoadIdentity
	glLoadMatrixd
	glLoadMatrixf
	glLoadName
	glLogicOp
	glMap1d
	glMap1f
	glMap2d
	glMap2f
	glMapGrid1d
	glMapGrid1f
	glMapGrid2d
	glMapGrid2f
	glMaterialf
	glMaterialfv
	glMateriali
	glMaterialiv
	glMatrixMode
	glMinmaxEXT
	glMultMatrixd
	glMultMatrixf
	glNewList
	glNormal3b
	glNormal3bv
	glNormal3d
	glNormal3dv
	glNormal3f
	glNormal3fv
	glNormal3i
	glNormal3iv
	glNormal3s
	glNormal3sv
	glOrtho
	glPassThrough
	glPixelMapfv
	glPixelMapuiv
	glPixelMapusv
	glPixelStoref
	glPixelStorei
	glPixelTransferf
	glPixelTransferi
	glPixelZoom
	glPointSize
	glPolygonMode
	glPolygonOffsetEXT
	glPolygonStipple
	glPopAttrib
	glPopMatrix
	glPopName
	glPushAttrib
	glPushMatrix
	glPushName
	glRasterPos2d
	glRasterPos2dv
	glRasterPos2f
	glRasterPos2fv
	glRasterPos2i
	glRasterPos2iv
	glRasterPos2s
	glRasterPos2sv
	glRasterPos3d
	glRasterPos3dv
	glRasterPos3f
	glRasterPos3fv
	glRasterPos3i
	glRasterPos3iv
	glRasterPos3s
	glRasterPos3sv
	glRasterPos4d
	glRasterPos4dv
	glRasterPos4f
	glRasterPos4fv
	glRasterPos4i
	glRasterPos4iv
	glRasterPos4s
	glRasterPos4sv
	glReadBuffer
	glReadPixels
	glRectd
	glRectdv
	glRectf
	glRectfv
	glRecti
	glRectiv
	glRects
	glRectsv
	glRenderMode
	glResetHistogramEXT
	glResetMinmaxEXT
	glRotated
	glRotatef
	glSampleMaskSGIS
	glSamplePatternSGIS
	glScaled
	glScalef
	glScissor
	glSelectBuffer
	glSeparableFilter2DEXT
	glShadeModel
	glSharpenTexFuncSGIS
	glStencilFunc
	glStencilMask
	glStencilOp
	glTagSampleBufferSGIX
	glTexCoord1d
	glTexCoord1dv
	glTexCoord1f
	glTexCoord1fv
	glTexCoord1i
	glTexCoord1iv
	glTexCoord1s
	glTexCoord1sv
	glTexCoord2d
	glTexCoord2dv
	glTexCoord2f
	glTexCoord2fv
	glTexCoord2i
	glTexCoord2iv
	glTexCoord2s
	glTexCoord2sv
	glTexCoord3d
	glTexCoord3dv
	glTexCoord3f
	glTexCoord3fv
	glTexCoord3i
	glTexCoord3iv
	glTexCoord3s
	glTexCoord3sv
	glTexCoord4d
	glTexCoord4dv
	glTexCoord4f
	glTexCoord4fv
	glTexCoord4i
	glTexCoord4iv
	glTexCoord4s
	glTexCoord4sv
	glTexEnvf
	glTexEnvfv
	glTexEnvi
	glTexEnviv
	glTexGend
	glTexGendv
	glTexGenf
	glTexGenfv
	glTexGeni
	glTexGeniv
	glTexImage1D
	glTexImage2D
	glTexImage3DEXT
	glTexParameterf
	glTexParameterfv
	glTexParameteri
	glTexParameteriv
	glTexSubImage1DEXT
	glTexSubImage2DEXT
	glTexSubImage3DEXT
	glTranslated
	glTranslatef
	glVertex2d
	glVertex2dv
	glVertex2f
	glVertex2fv
	glVertex2i
	glVertex2iv
	glVertex2s
	glVertex2sv
	glVertex3d
	glVertex3dv
	glVertex3f
	glVertex3fv
	glVertex3i
	glVertex3iv
	glVertex3s
	glVertex3sv
	glVertex4d
	glVertex4dv
	glVertex4f
	glVertex4fv
	glVertex4i
	glVertex4iv
	glVertex4s
	glVertex4sv
	glViewport

	X_PROTOCOL
	X_PROTOCOL_REVISION
	NoEventMask
	KeyPressMask
	KeyReleaseMask
	ButtonPressMask
	ButtonReleaseMask
	EnterWindowMask
	LeaveWindowMask
	PointerMotionMask
	PointerMotionHintMask
	Button1MotionMask
	Button2MotionMask
	Button3MotionMask
	Button4MotionMask
	Button5MotionMask
	ButtonMotionMask
	KeymapStateMask
	ExposureMask
	VisibilityChangeMask
	StructureNotifyMask
	ResizeRedirectMask
	SubstructureNotifyMask
	SubstructureRedirectMask
	FocusChangeMask
	PropertyChangeMask
	ColormapChangeMask
	OwnerGrabButtonMask
	KeyPress
	KeyRelease
	ButtonPress
	ButtonRelease
	MotionNotify
	EnterNotify
	LeaveNotify
	FocusIn
	FocusOut
	KeymapNotify
	Expose
	GraphicsExpose
	NoExpose
	VisibilityNotify
	CreateNotify
	DestroyNotify
	UnmapNotify
	MapNotify
	MapRequest
	ReparentNotify
	ConfigureNotify
	ConfigureRequest
	GravityNotify
	ResizeRequest
	CirculateNotify
	CirculateRequest
	PropertyNotify
	SelectionClear
	SelectionRequest
	SelectionNotify
	ColormapNotify
	ClientMessage
	MappingNotify
	LASTEvent
	ShiftMask
	LockMask
	ControlMask
	Mod1Mask
	Mod2Mask
	Mod3Mask
	Mod4Mask
	Mod5Mask
	ShiftMapIndex
	LockMapIndex
	ControlMapIndex
	Mod1MapIndex
	Mod2MapIndex
	Mod3MapIndex
	Mod4MapIndex
	Mod5MapIndex
	Button1Mask
	Button2Mask
	Button3Mask
	Button4Mask
	Button5Mask
	AnyModifier
	Button1
	Button2
	Button3
	Button4
	Button5
	NotifyNormal
	NotifyGrab
	NotifyUngrab
	NotifyWhileGrabbed
	NotifyHint
	NotifyAncestor
	NotifyVirtual
	NotifyInferior
	NotifyNonlinear
	NotifyNonlinearVirtual
	NotifyPointer
	NotifyPointerRoot
	NotifyDetailNone
	VisibilityUnobscured
	VisibilityPartiallyObscured
	VisibilityFullyObscured
	PlaceOnTop
	PlaceOnBottom
	FamilyInternet
	FamilyDECnet
	FamilyChaos
	PropertyNewValue
	PropertyDelete
	ColormapUninstalled
	ColormapInstalled
	GrabModeSync
	GrabModeAsync
	GrabSuccess
	AlreadyGrabbed
	GrabInvalidTime
	GrabNotViewable
	GrabFrozen
	AsyncPointer
	SyncPointer
	ReplayPointer
	AsyncKeyboard
	SyncKeyboard
	ReplayKeyboard
	AsyncBoth
	SyncBoth
	StaticGray
	GrayScale
	StaticColor
	PseudoColor
	TrueColor
	DirectColor
);

@oldconstants = qw(
	GL_CURRENT_BIT
	GL_POINT_BIT
	GL_LINE_BIT
	GL_POLYGON_BIT
	GL_POLYGON_STIPPLE_BIT
	GL_PIXEL_MODE_BIT
	GL_LIGHTING_BIT
	GL_FOG_BIT
	GL_DEPTH_BUFFER_BIT
	GL_ACCUM_BUFFER_BIT
	GL_STENCIL_BUFFER_BIT
	GL_VIEWPORT_BIT
	GL_TRANSFORM_BIT
	GL_ENABLE_BIT
	GL_COLOR_BUFFER_BIT
	GL_HINT_BIT
	GL_EVAL_BIT
	GL_LIST_BIT
	GL_TEXTURE_BIT
	GL_SCISSOR_BIT
	GL_ALL_ATTRIB_BITS
	GL_FALSE
	GL_TRUE
	GL_POINTS
	GL_LINES
	GL_LINE_LOOP
	GL_LINE_STRIP
	GL_TRIANGLES
	GL_TRIANGLE_STRIP
	GL_TRIANGLE_FAN
	GL_QUADS
	GL_QUAD_STRIP
	GL_POLYGON
	GL_ACCUM
	GL_LOAD
	GL_RETURN
	GL_MULT
	GL_ADD
	GL_NEVER
	GL_LESS
	GL_EQUAL
	GL_LEQUAL
	GL_GREATER
	GL_NOTEQUAL
	GL_GEQUAL
	GL_ALWAYS
	GL_ZERO
	GL_ONE
	GL_SRC_COLOR
	GL_ONE_MINUS_SRC_COLOR
	GL_SRC_ALPHA
	GL_ONE_MINUS_SRC_ALPHA
	GL_DST_ALPHA
	GL_ONE_MINUS_DST_ALPHA
	GL_DST_COLOR
	GL_ONE_MINUS_DST_COLOR
	GL_SRC_ALPHA_SATURATE
	GL_NONE
	GL_FRONT_LEFT
	GL_FRONT_RIGHT
	GL_BACK_LEFT
	GL_BACK_RIGHT
	GL_FRONT
	GL_BACK
	GL_LEFT
	GL_RIGHT
	GL_FRONT_AND_BACK
	GL_AUX0
	GL_AUX1
	GL_AUX2
	GL_AUX3
	GL_NO_ERROR
	GL_INVALID_ENUM
	GL_INVALID_VALUE
	GL_INVALID_OPERATION
	GL_STACK_OVERFLOW
	GL_STACK_UNDERFLOW
	GL_OUT_OF_MEMORY
	GL_2D
	GL_3D
	GL_3D_COLOR
	GL_3D_COLOR_TEXTURE
	GL_4D_COLOR_TEXTURE
	GL_PASS_THROUGH_TOKEN
	GL_POINT_TOKEN
	GL_LINE_TOKEN
	GL_POLYGON_TOKEN
	GL_BITMAP_TOKEN
	GL_DRAW_PIXEL_TOKEN
	GL_COPY_PIXEL_TOKEN
	GL_LINE_RESET_TOKEN
	GL_EXP
	GL_EXP2
	GL_CW
	GL_CCW
	GL_COEFF
	GL_ORDER
	GL_DOMAIN
	GL_PIXEL_MAP_I_TO_I
	GL_PIXEL_MAP_S_TO_S
	GL_PIXEL_MAP_I_TO_R
	GL_PIXEL_MAP_I_TO_G
	GL_PIXEL_MAP_I_TO_B
	GL_PIXEL_MAP_I_TO_A
	GL_PIXEL_MAP_R_TO_R
	GL_PIXEL_MAP_G_TO_G
	GL_PIXEL_MAP_B_TO_B
	GL_PIXEL_MAP_A_TO_A
	GL_CURRENT_COLOR
	GL_CURRENT_INDEX
	GL_CURRENT_NORMAL
	GL_CURRENT_TEXTURE_COORDS
	GL_CURRENT_RASTER_COLOR
	GL_CURRENT_RASTER_INDEX
	GL_CURRENT_RASTER_TEXTURE_COORDS
	GL_CURRENT_RASTER_POSITION
	GL_CURRENT_RASTER_POSITION_VALID
	GL_CURRENT_RASTER_DISTANCE
	GL_POINT_SMOOTH
	GL_POINT_SIZE
	GL_POINT_SIZE_RANGE
	GL_POINT_SIZE_GRANULARITY
	GL_LINE_SMOOTH
	GL_LINE_WIDTH
	GL_LINE_WIDTH_RANGE
	GL_LINE_WIDTH_GRANULARITY
	GL_LINE_STIPPLE
	GL_LINE_STIPPLE_PATTERN
	GL_LINE_STIPPLE_REPEAT
	GL_LIST_MODE
	GL_MAX_LIST_NESTING
	GL_LIST_BASE
	GL_LIST_INDEX
	GL_POLYGON_MODE
	GL_POLYGON_SMOOTH
	GL_POLYGON_STIPPLE
	GL_EDGE_FLAG
	GL_CULL_FACE
	GL_CULL_FACE_MODE
	GL_FRONT_FACE
	GL_LIGHTING
	GL_LIGHT_MODEL_LOCAL_VIEWER
	GL_LIGHT_MODEL_TWO_SIDE
	GL_LIGHT_MODEL_AMBIENT
	GL_SHADE_MODEL
	GL_COLOR_MATERIAL_FACE
	GL_COLOR_MATERIAL_PARAMETER
	GL_COLOR_MATERIAL
	GL_FOG
	GL_FOG_INDEX
	GL_FOG_DENSITY
	GL_FOG_START
	GL_FOG_END
	GL_FOG_MODE
	GL_FOG_COLOR
	GL_DEPTH_RANGE
	GL_DEPTH_TEST
	GL_DEPTH_WRITEMASK
	GL_DEPTH_CLEAR_VALUE
	GL_DEPTH_FUNC
	GL_ACCUM_CLEAR_VALUE
	GL_STENCIL_TEST
	GL_STENCIL_CLEAR_VALUE
	GL_STENCIL_FUNC
	GL_STENCIL_VALUE_MASK
	GL_STENCIL_FAIL
	GL_STENCIL_PASS_DEPTH_FAIL
	GL_STENCIL_PASS_DEPTH_PASS
	GL_STENCIL_REF
	GL_STENCIL_WRITEMASK
	GL_MATRIX_MODE
	GL_NORMALIZE
	GL_VIEWPORT
	GL_MODELVIEW_STACK_DEPTH
	GL_PROJECTION_STACK_DEPTH
	GL_TEXTURE_STACK_DEPTH
	GL_MODELVIEW_MATRIX
	GL_PROJECTION_MATRIX
	GL_TEXTURE_MATRIX
	GL_ATTRIB_STACK_DEPTH
	GL_ALPHA_TEST
	GL_ALPHA_TEST_FUNC
	GL_ALPHA_TEST_REF
	GL_DITHER
	GL_BLEND_DST
	GL_BLEND_SRC
	GL_BLEND
	GL_LOGIC_OP_MODE
	GL_LOGIC_OP
	GL_AUX_BUFFERS
	GL_DRAW_BUFFER
	GL_READ_BUFFER
	GL_SCISSOR_BOX
	GL_SCISSOR_TEST
	GL_INDEX_CLEAR_VALUE
	GL_INDEX_WRITEMASK
	GL_COLOR_CLEAR_VALUE
	GL_COLOR_WRITEMASK
	GL_INDEX_MODE
	GL_RGBA_MODE
	GL_DOUBLEBUFFER
	GL_STEREO
	GL_RENDER_MODE
	GL_PERSPECTIVE_CORRECTION_HINT
	GL_POINT_SMOOTH_HINT
	GL_LINE_SMOOTH_HINT
	GL_POLYGON_SMOOTH_HINT
	GL_FOG_HINT
	GL_TEXTURE_GEN_S
	GL_TEXTURE_GEN_T
	GL_TEXTURE_GEN_R
	GL_TEXTURE_GEN_Q
	GL_PIXEL_MAP_I_TO_I_SIZE
	GL_PIXEL_MAP_S_TO_S_SIZE
	GL_PIXEL_MAP_I_TO_R_SIZE
	GL_PIXEL_MAP_I_TO_G_SIZE
	GL_PIXEL_MAP_I_TO_B_SIZE
	GL_PIXEL_MAP_I_TO_A_SIZE
	GL_PIXEL_MAP_R_TO_R_SIZE
	GL_PIXEL_MAP_G_TO_G_SIZE
	GL_PIXEL_MAP_B_TO_B_SIZE
	GL_PIXEL_MAP_A_TO_A_SIZE
	GL_UNPACK_SWAP_BYTES
	GL_UNPACK_LSB_FIRST
	GL_UNPACK_ROW_LENGTH
	GL_UNPACK_SKIP_ROWS
	GL_UNPACK_SKIP_PIXELS
	GL_UNPACK_ALIGNMENT
	GL_PACK_SWAP_BYTES
	GL_PACK_LSB_FIRST
	GL_PACK_ROW_LENGTH
	GL_PACK_SKIP_ROWS
	GL_PACK_SKIP_PIXELS
	GL_PACK_ALIGNMENT
	GL_MAP_COLOR
	GL_MAP_STENCIL
	GL_INDEX_SHIFT
	GL_INDEX_OFFSET
	GL_RED_SCALE
	GL_RED_BIAS
	GL_ZOOM_X
	GL_ZOOM_Y
	GL_GREEN_SCALE
	GL_GREEN_BIAS
	GL_BLUE_SCALE
	GL_BLUE_BIAS
	GL_ALPHA_SCALE
	GL_ALPHA_BIAS
	GL_DEPTH_SCALE
	GL_DEPTH_BIAS
	GL_MAX_EVAL_ORDER
	GL_MAX_LIGHTS
	GL_MAX_CLIP_PLANES
	GL_MAX_TEXTURE_SIZE
	GL_MAX_PIXEL_MAP_TABLE
	GL_MAX_ATTRIB_STACK_DEPTH
	GL_MAX_MODELVIEW_STACK_DEPTH
	GL_MAX_NAME_STACK_DEPTH
	GL_MAX_PROJECTION_STACK_DEPTH
	GL_MAX_TEXTURE_STACK_DEPTH
	GL_MAX_VIEWPORT_DIMS
	GL_SUBPIXEL_BITS
	GL_INDEX_BITS
	GL_RED_BITS
	GL_GREEN_BITS
	GL_BLUE_BITS
	GL_ALPHA_BITS
	GL_DEPTH_BITS
	GL_STENCIL_BITS
	GL_ACCUM_RED_BITS
	GL_ACCUM_GREEN_BITS
	GL_ACCUM_BLUE_BITS
	GL_ACCUM_ALPHA_BITS
	GL_NAME_STACK_DEPTH
	GL_AUTO_NORMAL
	GL_MAP1_COLOR_4
	GL_MAP1_INDEX
	GL_MAP1_NORMAL
	GL_MAP1_TEXTURE_COORD_1
	GL_MAP1_TEXTURE_COORD_2
	GL_MAP1_TEXTURE_COORD_3
	GL_MAP1_TEXTURE_COORD_4
	GL_MAP1_VERTEX_3
	GL_MAP1_VERTEX_4
	GL_MAP2_COLOR_4
	GL_MAP2_INDEX
	GL_MAP2_NORMAL
	GL_MAP2_TEXTURE_COORD_1
	GL_MAP2_TEXTURE_COORD_2
	GL_MAP2_TEXTURE_COORD_3
	GL_MAP2_TEXTURE_COORD_4
	GL_MAP2_VERTEX_3
	GL_MAP2_VERTEX_4
	GL_MAP1_GRID_DOMAIN
	GL_MAP1_GRID_SEGMENTS
	GL_MAP2_GRID_DOMAIN
	GL_MAP2_GRID_SEGMENTS
	GL_TEXTURE_1D
	GL_TEXTURE_2D
	GL_TEXTURE_WIDTH
	GL_TEXTURE_HEIGHT
	GL_TEXTURE_COMPONENTS
	GL_TEXTURE_BORDER_COLOR
	GL_TEXTURE_BORDER
	GL_DONT_CARE
	GL_FASTEST
	GL_NICEST
	GL_AMBIENT
	GL_DIFFUSE
	GL_SPECULAR
	GL_POSITION
	GL_SPOT_DIRECTION
	GL_SPOT_EXPONENT
	GL_SPOT_CUTOFF
	GL_CONSTANT_ATTENUATION
	GL_LINEAR_ATTENUATION
	GL_QUADRATIC_ATTENUATION
	GL_COMPILE
	GL_COMPILE_AND_EXECUTE
	GL_BYTE
	GL_UNSIGNED_BYTE
	GL_SHORT
	GL_UNSIGNED_SHORT
	GL_INT
	GL_UNSIGNED_INT
	GL_FLOAT
	GL_2_BYTES
	GL_3_BYTES
	GL_4_BYTES
	GL_CLEAR
	GL_AND
	GL_AND_REVERSE
	GL_COPY
	GL_AND_INVERTED
	GL_NOOP
	GL_XOR
	GL_OR
	GL_NOR
	GL_EQUIV
	GL_INVERT
	GL_OR_REVERSE
	GL_COPY_INVERTED
	GL_OR_INVERTED
	GL_NAND
	GL_SET
	GL_EMISSION
	GL_SHININESS
	GL_AMBIENT_AND_DIFFUSE
	GL_COLOR_INDEXES
	GL_MODELVIEW
	GL_PROJECTION
	GL_TEXTURE
	GL_COLOR
	GL_DEPTH
	GL_STENCIL
	GL_COLOR_INDEX
	GL_STENCIL_INDEX
	GL_DEPTH_COMPONENT
	GL_RED
	GL_GREEN
	GL_BLUE
	GL_ALPHA
	GL_RGB
	GL_RGBA
	GL_LUMINANCE
	GL_LUMINANCE_ALPHA
	GL_BITMAP
	GL_POINT
	GL_LINE
	GL_FILL
	GL_RENDER
	GL_FEEDBACK
	GL_SELECT
	GL_FLAT
	GL_SMOOTH
	GL_KEEP
	GL_REPLACE
	GL_INCR
	GL_DECR
	GL_VENDOR
	GL_RENDERER
	GL_VERSION
	GL_EXTENSIONS
	GL_S
	GL_T
	GL_R
	GL_Q
	GL_MODULATE
	GL_DECAL
	GL_TEXTURE_ENV_MODE
	GL_TEXTURE_ENV_COLOR
	GL_TEXTURE_ENV
	GL_EYE_LINEAR
	GL_OBJECT_LINEAR
	GL_SPHERE_MAP
	GL_TEXTURE_GEN_MODE
	GL_OBJECT_PLANE
	GL_EYE_PLANE
	GL_NEAREST
	GL_LINEAR
	GL_NEAREST_MIPMAP_NEAREST
	GL_LINEAR_MIPMAP_NEAREST
	GL_NEAREST_MIPMAP_LINEAR
	GL_LINEAR_MIPMAP_LINEAR
	GL_TEXTURE_MAG_FILTER
	GL_TEXTURE_MIN_FILTER
	GL_TEXTURE_WRAP_S
	GL_TEXTURE_WRAP_T
	GL_CLAMP
	GL_REPEAT
	GL_CLIP_PLANE0
	GL_CLIP_PLANE1
	GL_CLIP_PLANE2
	GL_CLIP_PLANE3
	GL_CLIP_PLANE4
	GL_CLIP_PLANE5
	GL_LIGHT0
	GL_LIGHT1
	GL_LIGHT2
	GL_LIGHT3
	GL_LIGHT4
	GL_LIGHT5
	GL_LIGHT6
	GL_LIGHT7
	GL_EXT_abgr
	GL_EXT_blend_color
	GL_EXT_blend_logic_op
	GL_EXT_blend_minmax
	GL_EXT_blend_subtract
	GL_EXT_convolution
	GL_EXT_histogram
	GL_EXT_polygon_offset
	GL_EXT_subtexture
	GL_EXT_texture
	GL_EXT_texture3D
	GL_SGIS_detail_texture
	GL_SGIS_multisample
	GL_SGIS_sharpen_texture
	GL_ABGR_EXT
	GL_CONSTANT_COLOR_EXT
	GL_ONE_MINUS_CONSTANT_COLOR_EXT
	GL_CONSTANT_ALPHA_EXT
	GL_ONE_MINUS_CONSTANT_ALPHA_EXT
	GL_BLEND_COLOR_EXT
	GL_FUNC_ADD_EXT
	GL_MIN_EXT
	GL_MAX_EXT
	GL_BLEND_EQUATION_EXT
	GL_FUNC_SUBTRACT_EXT
	GL_FUNC_REVERSE_SUBTRACT_EXT
	GL_CONVOLUTION_1D_EXT
	GL_CONVOLUTION_2D_EXT
	GL_SEPARABLE_2D_EXT
	GL_CONVOLUTION_BORDER_MODE_EXT
	GL_CONVOLUTION_FILTER_SCALE_EXT
	GL_CONVOLUTION_FILTER_BIAS_EXT
	GL_REDUCE_EXT
	GL_CONVOLUTION_FORMAT_EXT
	GL_CONVOLUTION_WIDTH_EXT
	GL_CONVOLUTION_HEIGHT_EXT
	GL_MAX_CONVOLUTION_WIDTH_EXT
	GL_MAX_CONVOLUTION_HEIGHT_EXT
	GL_POST_CONVOLUTION_RED_SCALE_EXT
	GL_POST_CONVOLUTION_GREEN_SCALE_EXT
	GL_POST_CONVOLUTION_BLUE_SCALE_EXT
	GL_POST_CONVOLUTION_ALPHA_SCALE_EXT
	GL_POST_CONVOLUTION_RED_BIAS_EXT
	GL_POST_CONVOLUTION_GREEN_BIAS_EXT
	GL_POST_CONVOLUTION_BLUE_BIAS_EXT
	GL_POST_CONVOLUTION_ALPHA_BIAS_EXT
	GL_HISTOGRAM_EXT
	GL_PROXY_HISTOGRAM_EXT
	GL_HISTOGRAM_WIDTH_EXT
	GL_HISTOGRAM_FORMAT_EXT
	GL_HISTOGRAM_RED_SIZE_EXT
	GL_HISTOGRAM_GREEN_SIZE_EXT
	GL_HISTOGRAM_BLUE_SIZE_EXT
	GL_HISTOGRAM_ALPHA_SIZE_EXT
	GL_HISTOGRAM_LUMINANCE_SIZE_EXT
	GL_HISTOGRAM_SINK_EXT
	GL_MINMAX_EXT
	GL_MINMAX_FORMAT_EXT
	GL_MINMAX_SINK_EXT
	GL_TABLE_TOO_LARGE_EXT
	GL_POLYGON_OFFSET_EXT
	GL_POLYGON_OFFSET_FACTOR_EXT
	GL_POLYGON_OFFSET_BIAS_EXT
	GL_ALPHA4_EXT
	GL_ALPHA8_EXT
	GL_ALPHA12_EXT
	GL_ALPHA16_EXT
	GL_LUMINANCE4_EXT
	GL_LUMINANCE8_EXT
	GL_LUMINANCE12_EXT
	GL_LUMINANCE16_EXT
	GL_LUMINANCE4_ALPHA4_EXT
	GL_LUMINANCE6_ALPHA2_EXT
	GL_LUMINANCE8_ALPHA8_EXT
	GL_LUMINANCE12_ALPHA4_EXT
	GL_LUMINANCE12_ALPHA12_EXT
	GL_LUMINANCE16_ALPHA16_EXT
	GL_INTENSITY_EXT
	GL_INTENSITY4_EXT
	GL_INTENSITY8_EXT
	GL_INTENSITY12_EXT
	GL_INTENSITY16_EXT
	GL_RGB2_EXT
	GL_RGB4_EXT
	GL_RGB5_EXT
	GL_RGB8_EXT
	GL_RGB10_EXT
	GL_RGB12_EXT
	GL_RGB16_EXT
	GL_RGBA2_EXT
	GL_RGBA4_EXT
	GL_RGB5_A1_EXT
	GL_RGBA8_EXT
	GL_RGB10_A2_EXT
	GL_RGBA12_EXT
	GL_RGBA16_EXT
	GL_TEXTURE_RED_SIZE_EXT
	GL_TEXTURE_GREEN_SIZE_EXT
	GL_TEXTURE_BLUE_SIZE_EXT
	GL_TEXTURE_ALPHA_SIZE_EXT
	GL_TEXTURE_LUMINANCE_SIZE_EXT
	GL_TEXTURE_INTENSITY_SIZE_EXT
	GL_REPLACE_EXT
	GL_PROXY_TEXTURE_1D_EXT
	GL_PROXY_TEXTURE_2D_EXT
	GL_TEXTURE_TOO_LARGE_EXT
	GL_PACK_SKIP_IMAGES_EXT
	GL_PACK_IMAGE_HEIGHT_EXT
	GL_UNPACK_SKIP_IMAGES_EXT
	GL_UNPACK_IMAGE_HEIGHT_EXT
	GL_TEXTURE_3D_EXT
	GL_PROXY_TEXTURE_3D_EXT
	GL_TEXTURE_DEPTH_EXT
	GL_TEXTURE_WRAP_R_EXT
	GL_MAX_3D_TEXTURE_SIZE_EXT
	GL_DETAIL_TEXTURE_2D_SGIS
	GL_DETAIL_TEXTURE_2D_BINDING_SGIS
	GL_LINEAR_DETAIL_SGIS
	GL_LINEAR_DETAIL_ALPHA_SGIS
	GL_LINEAR_DETAIL_COLOR_SGIS
	GL_DETAIL_TEXTURE_LEVEL_SGIS
	GL_DETAIL_TEXTURE_MODE_SGIS
	GL_DETAIL_TEXTURE_FUNC_POINTS_SGIS
	GL_MULTISAMPLE_BIT_EXT
	GL_MULTISAMPLE_SGIS
	GL_SAMPLE_ALPHA_TO_MASK_SGIS
	GL_SAMPLE_ALPHA_TO_ONE_SGIS
	GL_SAMPLE_MASK_SGIS
	GL_1PASS_SGIS
	GL_2PASS_0_SGIS
	GL_2PASS_1_SGIS
	GL_4PASS_0_SGIS
	GL_4PASS_1_SGIS
	GL_4PASS_2_SGIS
	GL_4PASS_3_SGIS
	GL_SAMPLE_BUFFERS_SGIS
	GL_SAMPLES_SGIS
	GL_SAMPLE_MASK_VALUE_SGIS
	GL_SAMPLE_MASK_INVERT_SGIS
	GL_SAMPLE_PATTERN_SGIS
	GL_LINEAR_SHARPEN_SGIS
	GL_LINEAR_SHARPEN_ALPHA_SGIS
	GL_LINEAR_SHARPEN_COLOR_SGIS
	GL_SHARPEN_TEXTURE_FUNC_POINTS_SGIS

	GLX_USE_GL
	GLX_BUFFER_SIZE
	GLX_LEVEL
	GLX_RGBA
	GLX_DOUBLEBUFFER
	GLX_STEREO
	GLX_AUX_BUFFERS
	GLX_RED_SIZE
	GLX_GREEN_SIZE
	GLX_BLUE_SIZE
	GLX_ALPHA_SIZE
	GLX_DEPTH_SIZE
	GLX_STENCIL_SIZE
	GLX_ACCUM_RED_SIZE
	GLX_ACCUM_GREEN_SIZE
	GLX_ACCUM_BLUE_SIZE
	GLX_ACCUM_ALPHA_SIZE
	GLX_SAMPLES_SGIS
	GLX_SAMPLE_BUFFER_SGIS
	GLX_BAD_SCREEN
	GLX_BAD_ATTRIBUTE
	GLX_NO_EXTENSION
	GLX_BAD_VISUAL
	GLX_BAD_CONTEXT
	GLX_BAD_VALUE
	GLX_BAD_ENUM
	GLXBadContext
	GLXBadContextState
	GLXBadDrawable
	GLXBadPixmap
	GLXBadContextTag
	GLXBadCurrentWindow
	GLXBadRenderRequest
	GLXBadLargeRequest
	GLXUnsupportedPrivateRequest
	__GLX_NUMBER_ERRORS
	__GLX_NUMBER_EVENTS
	GLX_EXTENSION_NAME
	GLX_EXTENSION_ALIAS
	GLX_VENDOR
	GLX_VERSION
	GLX_EXTENSIONS
	GLX_SGI_swap_control
	GLX_SGI_video_sync
	GLX_SGIS_multisample
	GLX_SWAP_DEFAULT_SGI
	GLX_SWAP_MUXPIPE_SGI
	GLX_SWAP_GANG_SGI
	GLX_MUXPIPE0_SGI
	GLX_MUXPIPE1_SGI
	GLX_MUXPIPE2_SGI

	GLU_VERSION_1_1
	GLU_INVALID_ENUM
	GLU_INVALID_VALUE
	GLU_OUT_OF_MEMORY
	GLU_INCOMPATIBLE_GL_VERSION
	GLU_VERSION
	GLU_EXTENSIONS
	GLU_TRUE
	GLU_FALSE
	GLU_SMOOTH
	GLU_FLAT
	GLU_NONE
	GLU_POINT
	GLU_LINE
	GLU_FILL
	GLU_SILHOUETTE
	GLU_OUTSIDE
	GLU_INSIDE
	GLU_BEGIN
	GLU_VERTEX
	GLU_END
	GLU_ERROR
	GLU_EDGE_FLAG
	GLU_CW
	GLU_CCW
	GLU_INTERIOR
	GLU_EXTERIOR
	GLU_UNKNOWN
	GLU_TESS_ERROR1
	GLU_TESS_ERROR2
	GLU_TESS_ERROR3
	GLU_TESS_ERROR4
	GLU_TESS_ERROR5
	GLU_TESS_ERROR6
	GLU_TESS_ERROR7
	GLU_TESS_ERROR8
	GLU_AUTO_LOAD_MATRIX
	GLU_CULLING
	GLU_SAMPLING_TOLERANCE
	GLU_DISPLAY_MODE
	GLU_PARAMETRIC_TOLERANCE
	GLU_SAMPLING_METHOD
	GLU_U_STEP
	GLU_V_STEP
	GLU_PATH_LENGTH
	GLU_PARAMETRIC_ERROR
	GLU_DOMAIN_DISTANCE
	GLU_MAP1_TRIM_2
	GLU_MAP1_TRIM_3
	GLU_OUTLINE_POLYGON
	GLU_OUTLINE_PATCH
	GLU_NURBS_ERROR1
	GLU_NURBS_ERROR2
	GLU_NURBS_ERROR3
	GLU_NURBS_ERROR4
	GLU_NURBS_ERROR5
	GLU_NURBS_ERROR6
	GLU_NURBS_ERROR7
	GLU_NURBS_ERROR8
	GLU_NURBS_ERROR9
	GLU_NURBS_ERROR10
	GLU_NURBS_ERROR11
	GLU_NURBS_ERROR12
	GLU_NURBS_ERROR13
	GLU_NURBS_ERROR14
	GLU_NURBS_ERROR15
	GLU_NURBS_ERROR16
	GLU_NURBS_ERROR17
	GLU_NURBS_ERROR18
	GLU_NURBS_ERROR19
	GLU_NURBS_ERROR20
	GLU_NURBS_ERROR21
	GLU_NURBS_ERROR22
	GLU_NURBS_ERROR23
	GLU_NURBS_ERROR24
	GLU_NURBS_ERROR25
	GLU_NURBS_ERROR26
	GLU_NURBS_ERROR27
	GLU_NURBS_ERROR28
	GLU_NURBS_ERROR29
	GLU_NURBS_ERROR30
	GLU_NURBS_ERROR31
	GLU_NURBS_ERROR32
	GLU_NURBS_ERROR33
	GLU_NURBS_ERROR34
	GLU_NURBS_ERROR35
	GLU_NURBS_ERROR36
	GLU_NURBS_ERROR37
);

@EXPORT = (@oldfunctions, @oldconstants);

# Other items we are prepared to export if requested
@EXPORT_OK = (@gl_extensions, @gl_func, @glu_func, @glut_func, @glx_func, @gl_const, @glu_const, @glut_const, @glx_const);

@constants = (@gl_const, @glu_const, @glut_const, @glx_const);
@functions = (@gl_func, @glu_func, @glut_func, @glx_func);

%EXPORT_TAGS = ('constants' => \@constants, 'functions' => \@functions, 'all' => \@EXPORT_OK, 'old' => \@EXPORT,
	'glconstants' => \@gl_const, 'gluconstants' => \@glu_const, 'glutconstants' => \@glut_const, 'glxconstants' => \@glx_const,
	'glfunctions' => \@gl_func, 'glufunctions' => \@glu_func, 'glutfunctions' => \@glut_func, 'glxfunctions' => \@glx_func,
	'oldfunctions' => \@oldfunctions, 'oldconstants' => \@oldconstants,
);

@rename_old = qw(
	glBitmap
	glCallLists
	glClipPlane
	glColor3bv
	glColor3dv
	glColor3fv
	glColor3iv
	glColor3sv
	glColor3ubv
	glColor3uiv
	glColor3usv
	glColor4bv
	glColor4dv
	glColor4fv
	glColor4iv
	glColor4sv
	glColor4ubv
	glColor4uiv
	glColor4usv
	glConvolutionFilter1DEXT
	glConvolutionFilter2DEXT
	glConvolutionParameterfvEXT
	glConvolutionParameterivEXT
	glDetailTexFuncSGIS
	glDrawPixels
	glEvalCoord1dv
	glEvalCoord1fv
	glEvalCoord2dv
	glEvalCoord2fv
	glFeedbackBuffer
	glFogfv
	glFogiv
	glGetBooleanv
	glGetClipPlane
	glGetConvolutionFilterEXT
	glGetConvolutionParameterfvEXT
	glGetConvolutionParameterivEXT
	glGetDetailTexFuncSGIS
	glGetDoublev
	glGetFloatv
	glGetHistogramEXT
	glGetHistogramParameterfvEXT
	glGetHistogramParameterivEXT
	glGetIntegerv
	glGetLightfv
	glGetLightiv
	glGetMapdv
	glGetMapfv
	glGetMapiv
	glGetMaterialfv
	glGetMaterialiv
	glGetMinmaxEXT
	glGetMinmaxParameterfvEXT
	glGetMinmaxParameterivEXT
	glGetPixelMapfv
	glGetPixelMapuiv
	glGetPixelMapusv
	glGetPolygonStipple
	glGetSeparableFilterEXT
	glGetSharpenTexFuncSGIS
	glGetTexEnvfv
	glGetTexEnviv
	glGetTexGendv
	glGetTexGenfv
	glGetTexGeniv
	glGetTexImage
	glGetTexLevelParameterfv
	glGetTexLevelParameteriv
	glGetTexParameterfv
	glGetTexParameteriv
	glIndexdv
	glIndexfv
	glIndexiv
	glIndexsv
	glLightModelfv
	glLightModeliv
	glLightfv
	glLightiv
	glLoadMatrixd
	glLoadMatrixf
	glMap1d
	glMap1f
	glMap2d
	glMap2f
	glMaterialfv
	glMaterialiv
	glMultMatrixd
	glMultMatrixf
	glNormal3bv
	glNormal3dv
	glNormal3fv
	glNormal3iv
	glNormal3sv
	glPixelMapfv
	glPixelMapuiv
	glPixelMapusv
	glPolygonStipple
	glRasterPos2dv
	glRasterPos2fv
	glRasterPos2iv
	glRasterPos2sv
	glRasterPos3dv
	glRasterPos3fv
	glRasterPos3iv
	glRasterPos3sv
	glRasterPos4dv
	glRasterPos4fv
	glRasterPos4iv
	glRasterPos4sv
	glReadPixels
	glRectdv
	glRectfv
	glRectiv
	glRectsv
	glSeparableFilter2DEXT
	glSharpenTexFuncSGIS
	glTexCoord1dv
	glTexCoord1fv
	glTexCoord1iv
	glTexCoord1sv
	glTexCoord2dv
	glTexCoord2fv
	glTexCoord2iv
	glTexCoord2sv
	glTexCoord3dv
	glTexCoord3fv
	glTexCoord3iv
	glTexCoord3sv
	glTexCoord4dv
	glTexCoord4fv
	glTexCoord4iv
	glTexCoord4sv
	glTexEnvfv
	glTexEnviv
	glTexGendv
	glTexGenfv
	glTexGeniv
	glTexImage1D
	glTexImage2D
	glTexImage3DEXT
	glTexParameterfv
	glTexParameteriv
	glTexSubImage1DEXT
	glTexSubImage2DEXT
	glTexSubImage3DEXT
	glTranslated
	glTranslatef
	glVertex2dv
	glVertex2fv
	glVertex2iv
	glVertex2sv
	glVertex3dv
	glVertex3fv
	glVertex3iv
	glVertex3sv
	glVertex4dv
	glVertex4fv
	glVertex4iv
	glVertex4sv
	glViewport
);

sub AUTOLOAD {
    # This AUTOLOAD is used to 'autoload' constants from the constant()
    # XS function.  If a constant is not found then control is passed
    # to the AUTOLOAD in AutoLoader.

    # NOTE: THIS AUTOLOAD FUNCTION IS FLAWED (but is the best we can do for now).
    # Avoid old-style ``&CONST'' usage. Either remove the ``&'' or add ``()''.
    if (@_ > 0) {

	# Is it an old OpenGL-0.4 function? If so, remap it to newer variant
    local($constname);
    ($constname = $AUTOLOAD) =~ s/.*:://;
    if (grep ($_ eq $constname, @rename_old)) {
    	eval "sub $AUTOLOAD { $AUTOLOAD" . "_s(\@_) }";
    	goto &$AUTOLOAD;
    }
    
	$AutoLoader::AUTOLOAD = $AUTOLOAD;
	goto &AutoLoader::AUTOLOAD;
    }
    local($constname);
    ($constname = $AUTOLOAD) =~ s/.*:://;
    $val = constant($constname, @_ ? $_[0] : 0);
    if (not defined $val) {
	if ($! =~ /Invalid/) {
	    $AutoLoader::AUTOLOAD = $AUTOLOAD;
	    goto &AutoLoader::AUTOLOAD;
	}
	else {
	    ($pack,$file,$line) = caller;
	    die "Your vendor has not defined OpenGL macro $constname, used at $file line $line.
";
	}
    }
    eval "sub $AUTOLOAD { $val }";
    goto &$AUTOLOAD;
}

bootstrap Acme::MITHALDU::BleedingOpenGL;

*OpenGL::Array::CLONE_SKIP = sub { 1 };  # OpenGL::Array is not thread safe
*OpenGL::Matrix::CLONE_SKIP = sub { 1 };  # OpenGL::Matrix is not thread safe

# The following material is directly copied from Stan Melax's original OpenGL-0.4
# (with modifications for OS/2).

%window_defaults=(
   'x'         => 0,
   'y'         => 0,
   'width'     => 500,
   'height'    => 500,
   'parent'    => 0,
   'steal'     => 0,
   'mask'      => (_have_glx() ? StructureNotifyMask() : 0),
   'attributes'=> [],
);


sub glpOpenWindow {
        # default values
        my(%a) = @_;
        my(%p) = %window_defaults;
        foreach $k (keys(%a)){
                exists($p{$k}) || warn "Not a valid parameter to glpOpenWindow: `$k'\n";
                #print "parameter $k now ",$a{$k}," was ",$p{$k},"\n";  
                $p{$k} = $a{$k};
        }
        #
        # glpcOpenWindow() no longer exported.  Use fully qualified
        # package name or (better!) glpOpenWindow()
        #
        glpcOpenWindow($p{'x'},$p{'y'},$p{'width'},$p{'height'},
                       $p{'parent'},$p{'mask'},$p{'steal'},
                       @{$p{'attributes'}});
}

# The following material is original to OpenGL-0.5, and provides compatibility
# with some of Stan's functions.

sub glpClipPlane { glClipPlane_p(@_) }

sub glpGetClipPlane { glGetClipPlane_p(@_) }

sub glpLoadMatrixd { glLoadMatrixd_p(@_) }

sub glpMultMatrixd { glMultMatrixd_p(@_) }

sub glpLoadMatrixf { glLoadMatrixf_p(@_) }

sub glpMultMatrixf { glMultMatrixf_p(@_) }

sub glpMainLoop {
  if (_have_glx()) {
     ## print "Control-D to quit...\n";
     ## while(<>){;} # control-D to quit
    print "Type <Enter> to quit...\n";
    until(<>){;} # control-D to quit
  } else {				# OS/2 PM
    OS2::Process_Messages(0) while 1;  
  }
}

if (_have_glp() && !_have_glx()) { eval <<EOE } # OS2, take into account %ENV?
  sub Button1Mask () {Button1MaskOS2()}
  sub Button2Mask () {Button3MaskOS2()}
  sub Button3Mask () {Button2MaskOS2()}
EOE

sub glpFlush {
  &glFlush;
  glXSwapBuffers() if __had_dbuffer_hack();
}

sub Acme::MITHALDU::BleedingOpenGL::Quad::DESTROY ($) {gluDeleteQuadric(shift)}
@Acme::MITHALDU::BleedingOpenGL::Quad::ISA = 'GLUquadricObjPtr';
sub __new_gluQuad () {bless gluNewQuadric(), 'Acme::MITHALDU::BleedingOpenGL::Quad'}

sub glpSolidSphere ($$$) {
  gluSphere(__new_gluQuad, shift, shift, shift);
}
unless (_have_glut()) {
  *glutSolidSphere = \&glpSolidSphere;
}


sub glpFullScreen
{
  my $params = {};

  $params->{original_x} = glutGet(0x0064);	# GLUT_WINDOW_X
  $params->{original_y} = glutGet(0x0065);	# GLUT_WINDOW_Y
  $params->{original_w} = glutGet(0x0066);	# GLUT_WINDOW_WIDTH
  $params->{original_h} = glutGet(0x0067);	# GLUT_WINDOW_HEIGHT

  glutFullScreen();

  $params->{w} = glutGet(0x0066);		# GLUT_WINDOW_WIDTH
  $params->{h} = glutGet(0x0067);		# GLUT_WINDOW_HEIGHT

  return $params;
}

sub glpRestoreScreen
{
  my($params) = @_;

  glutPositionWindow($params->{original_x},$params->{original_y});
  glutReshapeWindow($params->{original_w},$params->{original_h});
  glutPostRedisplay();
}

sub glpCheckExtension
{
  my(@extensions) = @_;

  # Get/cache OpenGL Version
  if (!$gl_version)
  {
    $gl_version = glGetString(0x1F02); #GL_VERSION
    return 'Unable to retrieve OpenGL version; need context?' if (!$gl_version);
  }
  return "Not a numeric version: '$version'" if ($gl_version !~ m|^(\d+\.\d+)|);
  $gl_version = $1;

  # Get/cache OpenGL Extension Installations
  if (!scalar(%$glext_installed))
  {
    my $inst = glGetString(0x1F03); #GL_EXTENSIONS
    foreach my $ext (split(' ',$inst))
    {
      $glext_installed->{$ext} = $glext_dependencies->{$ext} || 0;
    }
  }
  if (!scalar(%$glext_installed))
  {
    return 'Unable to retrieve extensions; need context?' 
  }

  foreach my $ext (@extensions)
  {
    return "$ext not installed" if (!defined($glext_installed->{$ext}));

    # Check implementation
    my($ver,$deps) = split(';',$glext_installed->{$ext});
    return "$ext not implemented" if (!$ver);
    return "Needs at least OpenGL $ver" if ($gl_version < $ver);
    next if (!$deps);

    # Check dependencies
    foreach my $dep (split(',',$deps))
    {
      my $stat = glpCheckExtension("GL_$dep");
      return "Depends on $deps" if ($stat);
    }
  }
  return 0;
}
use Import::Into;
*OpenGL::import = sub {
   my %known = map { $_ => 1 } qw (OpenGL::Shader::Objects OpenGL::Shader::GLSL OpenGL::Shader::CG OpenGL::Shader::ARB OpenGL::Image::Magick OpenGL::Image::Targa);
   shift;
   my $target = caller;
   die "use Acme::MITHALDU::BleedingOpenGL" if !$known{$target};
   __PACKAGE__->import::into($target, @_);
};
$INC{"OpenGL.pm"} = 1;



#OpenGL::Array helper methods for normalizing names and chaining operations
@OpenGL::Matrix::ISA = 'OpenGL::Array';


1;
__END__

